@@ -1,4 +1,4 @@
-/* $Id: about.cpp,v 1.94 2005/01/25 00:33:04 isaaccp Exp $ */
+/* $Id: about.cpp,v 1.96 2005/02/12 22:19:58 ydirson Exp $ */
 /*
    Copyright (C) 2003 by David White <davidnwhite@optusnet.com.au>
    Part of the Battle for Wesnoth Project http://wesnoth.whitevine.net
@@ -179,6 +179,10 @@ std::vector<std::string> get_text() {
 		"-   Pieter Vermeylen (Onne)",
 		"+ ",
 
+		"_" N_("+English (GB) Translation"),
+		"-   ott",
+		"+ ",
+
 		"_" N_("+Finnish Translation"),
 		"-   paxed",
 		"+ ",
@@ -186,12 +190,13 @@ std::vector<std::string> get_text() {
 		"_" N_("+French Translation"),
 		"-   Benoit Astruc",
 		"-   Cédric Duval",
+		"-   DaringTremayne",
 		"-   Guillaume Duwelz-Rebert",
 		"-   Guillaume Melquiond (silene)",
 		"-   Jean-Luc Richard (Le Gnome)",
-		"-   DaringTremayne",
 		"-   Philippe Plantier (Ayin)",
 		"-   Tout",
+		"-   Yann Dirson",
 		"-   Zas",
 		"+ ",
 
@@ -241,8 +246,8 @@ std::vector<std::string> get_text() {
 
 		"_" N_("+Polish Translation"),
 		"-   Artur R. Czechowski",
-		"-   methinks",
 		"-   BOrsuk",
+		"-   methinks",
 		"-   Paweł Stradomski",
 		"-   Paweł Tomak",
 		"+ ",
