@@ -1,4 +1,4 @@
-/* $Id: ai_attack.cpp,v 1.51 2004/09/19 20:52:17 Sirp Exp $ */
+/* $Id: ai_attack.cpp,v 1.58 2004/12/31 21:01:37 isaaccp Exp $ */
 /*
    Copyright (C) 2003 by David White <davidnwhite@optusnet.com.au>
    Part of the Battle for Wesnoth Project http://wesnoth.whitevine.net
@@ -11,15 +11,17 @@
    See the COPYING file for more details.
 */
 
+#include "global.hpp"
+
 #include "actions.hpp"
 #include "ai_attack.hpp"
 #include "game_config.hpp"
 #include "log.hpp"
 #include "pathfind.hpp"
 #include "util.hpp"
+#include "wassert.hpp"
 
 #include <algorithm>
-#include <cassert>
 #include <cstdlib>
 #include <iostream>
 #include <set>
@@ -65,7 +67,7 @@ void ai::do_attack_analysis(
 	double rating_to_beat = cur_rating;
 
 	if(!cur_analysis.movements.empty()) {
-		assert(cur_analysis.movements.size() < 6);
+		wassert(cur_analysis.movements.size() < 6);
 		double& best_res = best_results[cur_analysis.movements.size()-1];
 		rating_to_beat = best_res = maximum(best_res,cur_rating);
 	}
@@ -74,7 +76,7 @@ void ai::do_attack_analysis(
 		const location current_unit = units[i];
 
 		const unit_map::const_iterator unit_itor = units_.find(current_unit);
-		assert(unit_itor != units_.end());
+		wassert(unit_itor != units_.end());
 
 		//see if the unit has the backstab ability -- units with backstab
 		//will want to try to have a friendly unit opposite the position they move to
@@ -179,7 +181,7 @@ void ai::do_attack_analysis(
 
 			cur_analysis.support += best_support;
 
-			cur_analysis.analyze(map_,units_,state_,gameinfo_,50,*this,dstsrc,srcdst,enemy_dstsrc,enemy_srcdst);
+			cur_analysis.analyze(map_, units_, 50, *this, dstsrc, srcdst, enemy_dstsrc, enemy_srcdst);
 
 			if(cur_analysis.rating(current_team().aggression(),*this) > rating_to_beat) {
 
@@ -249,7 +251,7 @@ int ai::choose_weapon(const location& att, const location& def,
 	const std::set<battle_type>::const_iterator cache_itor = weapon_choice_cache.find(battle);
 
 	if(cache_itor != weapon_choice_cache.end()) {
-		assert(*cache_itor == battle);
+		wassert(*cache_itor == battle);
 
 		++cache_hits;
 		cur_stats = cache_itor->stats;
@@ -259,7 +261,7 @@ int ai::choose_weapon(const location& att, const location& def,
 			          << "/" << itor->second.attacks().size() << "\n";
 		}
 
-		assert(size_t(cache_itor->weapon) < itor->second.attacks().size());
+		wassert(size_t(cache_itor->weapon) < itor->second.attacks().size());
 		return cache_itor->weapon;
 	}
 
@@ -272,15 +274,15 @@ int ai::choose_weapon(const location& att, const location& def,
 	int current_choice = -1;
 	double current_rating = 0.0;
 	const std::vector<attack_type>& attacks = itor->second.attacks();
-	assert(!attacks.empty());
+	wassert(!attacks.empty());
 
 	const unit_map::const_iterator d_itor = units_.find(def);
 	int d_hitpoints = d_itor->second.hitpoints();
 	int a_hitpoints = itor->second.hitpoints();
 	
 	for(size_t a = 0; a != attacks.size(); ++a) {
-		const battle_stats stats = evaluate_battle_stats(map_,att,def,a,units_,
-		                                                 state_,gameinfo_,terrain,false);
+		const battle_stats stats = evaluate_battle_stats(map_, att, def, a, units_,
+		                                                 state_, terrain);
 
 		//TODO: improve this rating formula!
 		const double rating =
@@ -295,7 +297,7 @@ int ai::choose_weapon(const location& att, const location& def,
 		}
 	}
 
-	assert(size_t(current_choice) < attacks.size());
+	wassert(size_t(current_choice) < attacks.size());
 
 	battle.stats = cur_stats;
 	battle.weapon = current_choice;
@@ -304,15 +306,12 @@ int ai::choose_weapon(const location& att, const location& def,
 	return current_choice;
 }
 
-void ai::attack_analysis::analyze(const gamemap& map,
-                                  unit_map& units,
-						 	      const gamestatus& status,
-							      const game_data& info, int num_sims, ai& ai_obj,
-								  const ai::move_map& dstsrc, const ai::move_map& srcdst,
-								  const ai::move_map& enemy_dstsrc, const ai::move_map& enemy_srcdst)
+void ai::attack_analysis::analyze(const gamemap& map, unit_map& units, int num_sims, ai& ai_obj,
+                                  const ai::move_map& dstsrc, const ai::move_map& srcdst,
+                                  const ai::move_map& enemy_dstsrc, const ai::move_map& enemy_srcdst)
 {
 	const unit_map::const_iterator defend_it = units.find(target);
-	assert(defend_it != units.end());
+	wassert(defend_it != units.end());
 
 	//see if the target is a threat to our leader or an ally's leader
 	gamemap::location adj[6];
@@ -355,7 +354,7 @@ void ai::attack_analysis::analyze(const gamemap& map,
 		battle_stats bat_stats;
 		const int weapon = ai_obj.choose_weapon(m->first,target, bat_stats, map[m->second.x][m->second.y],true);
 
-		assert(weapon != -1);
+		wassert(weapon != -1);
 		weapons.push_back(weapon);
 
 		stats.push_back(bat_stats);
@@ -559,7 +558,7 @@ double ai::attack_analysis::rating(double aggression, ai& ai_obj) const
 		const double exposure_mod = uses_leader ? 2.0 : ai_obj.current_team().caution();
 		const double exposure = exposure_mod*resources_used*(terrain_quality - alternative_terrain_quality)*vulnerability/maximum<double>(0.01,support);
 		LOG_AI << "attack option has base value " << value << " with exposure " << exposure << ": "
-			<< vulnerability << "/" << support << " = " << (vulnerability/support) << "\n";
+			<< vulnerability << "/" << support << " = " << (vulnerability/maximum<double>(support,0.1)) << "\n";
 		if(uses_leader) {
 			ai_obj.log_message("attack option has value " + str_cast(value) + " with exposure " + str_cast(exposure) + ": " + str_cast(vulnerability) + "/" + str_cast(support));
 		}
