@@ -1,4 +1,4 @@
-/* $Id: builder.cpp,v 1.35 2004/09/19 07:24:59 silene Exp $ */
+/* $Id: builder.cpp,v 1.40 2004/12/31 21:01:37 isaaccp Exp $ */
 /*
    Copyright (C) 2004 by Philippe Plantier <ayin@anathas.org>
    Part of the Battle for Wesnoth Project http://www.wesnoth.org
@@ -11,16 +11,16 @@
    See the COPYING file for more details.
 */
 
-//disable the very annoying VC++ warning 4786
-#ifdef WIN32
-#pragma warning(disable:4786)
-#endif
+#include "global.hpp"
 
 #include "array.hpp"
 #include "display.hpp"
 #include "log.hpp"
 #include "terrain.hpp"
 #include "util.hpp"
+#include "wassert.hpp"
+
+#define ERR_NG lg::err(lg::engine)
 
 namespace {
 
@@ -123,14 +123,14 @@ bool terrain_builder::tilemap::on_map(const gamemap::location &loc) const
 
 terrain_builder::tile& terrain_builder::tilemap::operator[](const gamemap::location &loc)
 {
-	assert(on_map(loc));
+	wassert(on_map(loc));
 		
 	return map_[(loc.x+1) + (loc.y+1)*(x_+2)];
 }
 
 const terrain_builder::tile& terrain_builder::tilemap::operator[] (const gamemap::location &loc) const
 {
-	assert(on_map(loc));
+	wassert(on_map(loc));
 	
 	return map_[(loc.x+1) + (loc.y+1)*(x_+2)];
 }
@@ -205,7 +205,7 @@ void terrain_builder::rebuild_terrain(const gamemap::location &loc)
 		btile.images_foreground.clear();
 		btile.images_background.clear();
 		const std::string filename =
-			map_.get_terrain_info(map_.get_terrain(loc)).default_image();
+			map_.get_terrain_info(map_.get_terrain(loc)).symbol_image();
 		animated<image::locator> img_loc("terrain/" + filename + ".png");
 		img_loc.start_animation(0, animated<image::locator>::INFINITE_CYCLES);
 		btile.images_background.push_back(img_loc);
@@ -332,7 +332,7 @@ terrain_builder::terrain_constraint terrain_builder::rotate(const terrain_builde
 		{ 1./2. ,  3./4., -1., 1./2. },
 	};
 
-	assert(angle >= 0);
+	wassert(angle >= 0);
 
 	angle %= 6;	
 	terrain_constraint ret = constraint;
@@ -373,7 +373,7 @@ void terrain_builder::replace_token(std::string &s, const std::string &token, co
 	size_t pos;
 	
 	if(token.empty()) {
-		std::cerr << "Error: empty token in replace_token\n";
+		ERR_NG << "empty token in replace_token\n";
 		return;
 	}
 	while((pos = s.find(token)) != std::string::npos) {
@@ -432,7 +432,7 @@ terrain_builder::building_rule terrain_builder::rotate_rule(const terrain_builde
 {
 	building_rule ret;
 	if(rot.size() != 6) {
-		std::cerr << "Error: invalid rotations\n";
+		ERR_NG << "invalid rotations\n";
 		return ret;
 	}
 	ret.location_constraints = rule.location_constraints;
@@ -700,7 +700,7 @@ void terrain_builder::parse_config(const config &cfg)
 			if((**tc)["pos"].size()) {
 				int pos = atoi((**tc)["pos"].c_str());
 				if(anchors.find(pos) == anchors.end()) {
-					std::cerr << "Invalid anchor!\n";
+					lg::warn(lg::engine) << "Invalid anchor!\n";
 					continue;
 				}
 
