@@ -1,6 +1,12 @@
+#include "global.hpp"
+
 #include "cavegen.hpp"
+#include "log.hpp"
 #include "pathfind.hpp"
 #include "util.hpp"
+#include "wassert.hpp"
+
+#define LOG_NG lg::info(lg::engine)
 
 cave_map_generator::cave_map_generator(const config* cfg) : wall_('W'), clear_('u'), village_('D'), castle_('o'),
                                                             cfg_(cfg), width_(50), height_(50), village_density_(0),
@@ -20,7 +26,7 @@ cave_map_generator::cave_map_generator(const config* cfg) : wall_('W'), clear_('
 
 	flipx_ = r < chance;
 
-	std::cerr << "flipx: " << r << " < " << chance << " = " << (flipx_ ? "true" : "false") << "\n";
+	LOG_NG << "flipx: " << r << " < " << chance << " = " << (flipx_ ? "true" : "false") << "\n";
 	flipy_ = (rand()%100) < atoi((*cfg_)["flipy_chance"].c_str());
 
 
@@ -68,21 +74,21 @@ config cave_map_generator::create_scenario(const std::vector<std::string>& args)
 		res_ = *settings;
 	}
 
-	std::cerr << "creating scenario....\n";
+	LOG_NG << "creating scenario....\n";
 	generate_chambers();
 
-	std::cerr << "placing chambers...\n";
+	LOG_NG << "placing chambers...\n";
 	for(std::vector<chamber>::const_iterator c = chambers_.begin(); c != chambers_.end(); ++c) {
 		place_chamber(*c);
 	}
 
-	std::cerr << "placing passages...\n";
+	LOG_NG << "placing passages...\n";
 
 	for(std::vector<passage>::const_iterator p = passages_.begin(); p != passages_.end(); ++p) {
 		place_passage(*p);
 	}
 
-	std::cerr << "outputting map....\n";
+	LOG_NG << "outputting map....\n";
 	std::stringstream out;
 	for(size_t y = 0; y != height_; ++y) {
 		for(size_t x = 0; x != width_; ++x) {
@@ -94,7 +100,7 @@ config cave_map_generator::create_scenario(const std::vector<std::string>& args)
 
 	res_["map_data"] = out.str();
 
-	std::cerr << "returning result...\n";
+	LOG_NG << "returning result...\n";
 
 	return res_;
 }
@@ -183,7 +189,7 @@ void cave_map_generator::generate_chambers()
 			if(itor == chamber_ids_.end())
 				continue;
 
-			assert(itor->second < chambers_.size());
+			wassert(itor->second < chambers_.size());
 
 			passages_.push_back(passage(new_chamber.center,chambers_[itor->second].center,**p));
 		}
@@ -257,13 +263,13 @@ void cave_map_generator::place_items(const chamber& c, config::all_children_iter
 	}
 }
 
-struct passage_path_calculator
+struct passage_path_calculator : cost_calculator
 {
 	passage_path_calculator(const std::vector<std::vector<gamemap::TERRAIN> >& mapdata, gamemap::TERRAIN wall, double laziness, size_t windiness)
 		        : map_(mapdata), wall_(wall), laziness_(laziness), windiness_(windiness)
 	{}
 	
-	double cost(const gamemap::location& loc, double so_far) const;
+	virtual double cost(const gamemap::location& loc, const double so_far, const bool is_dest) const;
 private:
 	const std::vector<std::vector<gamemap::TERRAIN> >& map_;
 	gamemap::TERRAIN wall_;
@@ -271,11 +277,10 @@ private:
 	size_t windiness_;
 };
 
-double passage_path_calculator::cost(const gamemap::location& loc, double so_far) const
+double passage_path_calculator::cost(const gamemap::location& loc, const double, const bool) const
 {
-	if(loc.x < 0 || loc.y < 0 || size_t(loc.x) >= map_.size() || map_.empty() || size_t(loc.y) >= map_.front().size()) {
-		return 100000.0;
-	}
+	wassert(loc.x >= 0 && loc.y >= 0 && size_t(loc.x) < map_.size() &&
+	        !map_.empty() && size_t(loc.y) < map_.front().size());
 
 	double res = 1.0;
 	if(map_[loc.x][loc.y] == wall_) {
@@ -302,9 +307,10 @@ void cave_map_generator::place_passage(const passage& p)
 	
 	passage_path_calculator calc(map_,wall_,laziness,windiness);
 	
-	const paths::route rt = a_star_search(p.src,p.dst,10000.0,calc);
+	const paths::route rt = a_star_search(p.src, p.dst, 10000.0, &calc, width_, height_);
 
 	const size_t width = maximum<size_t>(1,atoi(p.cfg["width"].c_str()));
+
 	const size_t jagged = atoi(p.cfg["jagged"].c_str());
 	
 	for(std::vector<gamemap::location>::const_iterator i = rt.steps.begin(); i != rt.steps.end(); ++i) {
