@@ -2,8 +2,13 @@
 #define CLIPBOARD_HPP_INCLUDED
 
 #include <string>
+#include "SDL.h"
 
 void copy_to_clipboard(const std::string& text);
 std::string copy_from_clipboard();
 
-#endif
\ No newline at end of file
+#if defined(_X11) && !defined(__APPLE__)
+void handle_system_event(const SDL_Event& ev);
+#endif
+
+#endif
