@@ -1,4 +1,4 @@
-/* $Id: config.hpp,v 1.46 2004/08/23 06:40:59 gakusho Exp $ */
+/* $Id: config.hpp,v 1.52 2004/12/31 21:01:37 isaaccp Exp $ */
 /*
    Copyright (C) 2003 by David White <davidnwhite@optusnet.com.au>
    Part of the Battle for Wesnoth Project http://wesnoth.whitevine.net
@@ -13,12 +13,6 @@
 #ifndef CONFIG_HPP_INCLUDED
 #define CONFIG_HPP_INCLUDED
 
-//disable the very annoying VC++ warning 4786
-#ifdef WIN32
-#pragma warning(disable:4786)
-#endif
-
-#include <cassert>
 #include <map>
 #include <sstream>
 #include <string>
@@ -58,12 +52,6 @@ private:
 	std::string message;
 };
 
-//basic disk I/O
-std::string read_file(const std::string& fname);
-//throws io_exception if an error occurs
-void write_file(const std::string& fname, const std::string& data);
-std::string read_stdin();
-
 struct preproc_define {
 	preproc_define() {}
 	explicit preproc_define(const std::string& val) : value(val) {}
@@ -75,6 +63,9 @@ struct preproc_define {
 
 typedef std::map<std::string,preproc_define> preproc_map;
 
+inline bool operator==(const preproc_define& a, const preproc_define& b) { return a.value == b.value && a.arguments == b.arguments; }
+inline bool operator!=(const preproc_define& a, const preproc_define& b) { return !operator==(a,b); }
+
 //function to use the WML preprocessor on a file, and returns the resulting
 //preprocessed file data. defines is a map of symbols defined. src is used
 //internally and should be set to NULL
@@ -141,6 +132,7 @@ public:
 	const config* child(const std::string& key) const;
 	config& add_child(const std::string& key);
 	config& add_child(const std::string& key, const config& val);
+	config& add_child_at(const std::string& key, const config& val, size_t index);
 	std::string& operator[](const std::string& key);
 	const std::string& operator[](const std::string& key) const;
 
