@@ -1,4 +1,4 @@
-/* $Id: dialogs.cpp,v 1.58 2004/09/25 19:46:33 ydirson Exp $ */
+/* $Id: dialogs.cpp,v 1.80 2005/01/19 20:11:34 silene Exp $ */
 /*
    Copyright (C) 2003 by David White <davidnwhite@optusnet.com.au>
    Part of the Battle for Wesnoth Project http://wesnoth.whitevine.net
@@ -11,8 +11,11 @@
    See the COPYING file for more details.
 */
 
+#include "global.hpp"
+
 #include "dialogs.hpp"
 #include "events.hpp"
+#include "filesystem.hpp"
 #include "font.hpp"
 #include "game_config.hpp"
 #include "help.hpp"
@@ -23,7 +26,8 @@
 #include "replay.hpp"
 #include "show_dialog.hpp"
 #include "util.hpp"
-#include "widgets/file_chooser.hpp"
+#include "wassert.hpp"
+#include "widgets/menu.hpp"
 #include "widgets/progressbar.hpp"
 
 #include <cstdio>
@@ -33,6 +37,9 @@
 #include <time.h>
 #include <vector>
 
+#define LOG_DP lg::info(lg::display)
+#define ERR_G  lg::err(lg::general)
+
 namespace dialogs
 {
 
@@ -46,7 +53,7 @@ void advance_unit(const game_data& info,
 	if(u == units.end() || u->second.advances() == false)
 		return;
 
-	std::cerr << "advance_unit: " << u->second.type().name() << "\n";
+	LOG_DP << "advance_unit: " << u->second.type().name() << "\n";
 
 	const std::vector<std::string>& options = u->second.type().advances_to();
 
@@ -56,7 +63,7 @@ void advance_unit(const game_data& info,
 	for(std::vector<std::string>::const_iterator op = options.begin(); op != options.end(); ++op) {
 		sample_units.push_back(::get_advanced_unit(info,units,loc,*op));
 		const unit_type& type = sample_units.back().type();
-		lang_options.push_back("&" + type.image() + "," + type.language_name());
+		lang_options.push_back(IMAGE_PREFIX + type.image() + COLUMN_SEPARATOR + type.language_name());
 	}
 
 	const config::child_list& mod_options = u->second.get_modification_advances();
@@ -65,11 +72,10 @@ void advance_unit(const game_data& info,
 		sample_units.push_back(::get_advanced_unit(info,units,loc,u->second.type().name()));
 		sample_units.back().add_modification("advance",**mod);
 		const unit_type& type = sample_units.back().type();
-		// lang_options.push_back("&" + type.image() + "," + translate_string_default("advance_" + (**mod)["id"],(**mod)["description"]));
-		lang_options.push_back("&" + type.image() + "," + (**mod)["description"]);
+		lang_options.push_back(IMAGE_PREFIX + type.image() + COLUMN_SEPARATOR + (**mod)["description"]);
 	}
 
-	std::cerr << "options: " << options.size() << "\n";
+	LOG_DP << "options: " << options.size() << "\n";
 
 	int res = 0;
 
@@ -91,13 +97,13 @@ void advance_unit(const game_data& info,
 
 	recorder.choose_option(res);
 
-	std::cerr << "animating advancement...\n";
+	LOG_DP << "animating advancement...\n";
 	animate_unit_advancement(info,units,loc,gui,size_t(res));
 }
 
 bool animate_unit_advancement(const game_data& info,unit_map& units, gamemap::location loc, display& gui, size_t choice)
 {
-	const command_disabler cmd_disabler(&gui);
+	const command_disabler cmd_disabler;
 	
 	std::map<gamemap::location,unit>::iterator u = units.find(loc);
 	if(u == units.end() || u->second.advances() == false) {
@@ -206,10 +212,10 @@ gui::dialog_button_action::RESULT delete_save::button_pressed(int menu_selection
 			options.push_back(gui::check_item(_("Don't ask me again!"),false));
 
 			const int res = gui::show_dialog(disp_,NULL,"",_("Do you really want to delete this game?"),gui::YES_NO,
-			                                 NULL,NULL,"",NULL,NULL,&options);
+			                                 NULL,NULL,"",NULL,-1,NULL,&options);
 
 			//see if the user doesn't want to be asked this again
-			assert(options.empty() == false);
+			wassert(options.empty() == false);
 			if(options.front().checked) {
 				preferences::set_ask_delete_saves(false);
 			}
@@ -235,7 +241,6 @@ gui::dialog_button_action::RESULT delete_save::button_pressed(int menu_selection
 	}
 }
 
-static const SDL_Rect save_preview_pane_area = {-200,-400,200,400};
 static const int save_preview_border = 10;
 
 class save_preview_pane : public gui::preview_pane
@@ -245,10 +250,10 @@ public:
 	                  const std::vector<save_info>& info, const std::vector<config*>& summaries)
 		: gui::preview_pane(disp), game_config_(&game_config), map_(map), data_(&data), info_(&info), summaries_(&summaries), index_(0)
 	{
-		set_location(save_preview_pane_area);
+		set_measurements(200, 400);
 	}
 
-	void draw();
+	void draw_contents();
 	void set_selection(int index) {
 		index_ = index;
 		set_dirty();
@@ -266,26 +271,19 @@ private:
 	std::map<std::string,surface> map_cache_;
 };
 
-void save_preview_pane::draw()
+void save_preview_pane::draw_contents()
 {
-	if(!dirty()) {
-		return;
-	}
-
-	bg_restore();
-
 	if(index_ < 0 || index_ >= int(summaries_->size()) || info_->size() != summaries_->size()) {
 		return;
 	}
 
-	set_dirty(false);
-
 	const config& summary = *(*summaries_)[index_];
 
 	surface const screen = disp().video().getSurface();
 
-	const SDL_Rect area = { location().x+save_preview_border, location().y+save_preview_border,
-	                        location().w-save_preview_border*2, location().h-save_preview_border*2 };
+	SDL_Rect const &loc = location();
+	const SDL_Rect area = { loc.x + save_preview_border, loc.y + save_preview_border,
+	                        loc.w - save_preview_border * 2, loc.h - save_preview_border * 2 };
 	SDL_Rect clip_area = area;
 	const clip_rect_setter clipper(screen,clip_area);
 
@@ -312,7 +310,7 @@ void save_preview_pane::draw()
 				try {
 					map_data = read_map((*scenario)["map"]);
 				} catch(io_exception& e) {
-					std::cerr << "could not read map '" << (*scenario)["map"] << "': " << e.what() << "\n";
+					ERR_G << "could not read map '" << (*scenario)["map"] << "': " << e.what() << "\n";
 				}
 			}
 		}
@@ -328,7 +326,7 @@ void save_preview_pane::draw()
 			try {
 				map_->read(map_data);
 
-				map_surf = image::getMinimap(100,100,*map_,0,NULL);
+				map_surf = image::getMinimap(100, 100, *map_);
 				if(map_surf != NULL) {
 					map_cache_.insert(std::pair<std::string,surface>(map_data,surface(map_surf)));
 				}
@@ -382,9 +380,12 @@ void save_preview_pane::draw()
 		}
 
 		str << "\n" << _("Difficulty") << ": " << string_table[summary["difficulty"]];
+		if(!summary["version"].empty()) {
+			str << "\n" << _("Version") << ": " << summary["version"];
+		}
 	}
 
-	font::draw_text(&disp(),area,font::SIZE_SMALL,font::NORMAL_COLOUR,str.str(),area.x,ypos,NULL,true);
+	font::draw_text(&disp(), area, font::SIZE_SMALL, font::NORMAL_COLOUR, str.str(), area.x, ypos, true);
 }
 
 } //end anon namespace
@@ -442,7 +443,7 @@ std::string load_game_dialog(display& disp, const config& game_config, const gam
 			std::vector<gui::check_item> options;
 			options.push_back(gui::check_item(_("Don't ask me again!"),false));
 			const int res = gui::show_dialog(disp,NULL,_(caption),_(message),
-			                                 gui::YES_NO,NULL,NULL,"",NULL,NULL,&options);
+			                                 gui::YES_NO,NULL,NULL,"",NULL,-1,NULL,&options);
 
 			generate_summaries = res == 0;
 			if(options.front().checked) {
@@ -475,13 +476,13 @@ std::string load_game_dialog(display& disp, const config& game_config, const gam
 				extract_summary_data_from_save(state,summary);
 			} catch(io_exception&) {
 				summary["corrupt"] = "yes";
-				std::cerr << "save '" << games[*s].name << "' could not be loaded (io_exception)\n";
+				ERR_G << "save '" << games[*s].name << "' could not be loaded (io_exception)\n";
 			} catch(config::error&) {
 				summary["corrupt"] = "yes";
-				std::cerr << "save '" << games[*s].name << "' could not be loaded (config parse error)\n";
+				ERR_G << "save '" << games[*s].name << "' could not be loaded (config parse error)\n";
 			} catch(gamestatus::load_game_failed&) {
 				summary["corrupt"] = "yes";
-				std::cerr << "save '" << games[*s].name << "' could not be loaded (load_game_failed exception)\n";
+				ERR_G << "save '" << games[*s].name << "' could not be loaded (load_game_failed exception)\n";
 			}
 		}
 
@@ -511,7 +512,7 @@ std::string load_game_dialog(display& disp, const config& game_config, const gam
 	const int res = gui::show_dialog(disp,NULL,
 					 _("Load Game"),
 					 _("Choose the game to load"),
-			         gui::OK_CANCEL,&items,&preview_panes,"",NULL,NULL,&options,-1,-1,NULL,&buttons);
+			         gui::OK_CANCEL,&items,&preview_panes,"",NULL,-1,NULL,&options,-1,-1,NULL,&buttons);
 
 	if(res == -1)
 		return "";
@@ -541,8 +542,6 @@ void unit_speak(const config& message_info, display& disp, const unit_map& units
 
 
 namespace {
-	static const SDL_Rect unit_preview_size = {-200,-370,200,370};
-	static const SDL_Rect weaponless_unit_preview_size = {-190,-140,190,140};
 	static const int unit_preview_border = 10;
 }
 
@@ -551,7 +550,9 @@ unit_preview_pane::unit_preview_pane(display& disp, const gamemap* map, const un
 										  map_(map), units_(&unit_store_), index_(0), left_(on_left_side),
 										  weapons_(type == SHOW_ALL)
 {
-	set_location(weapons_ ? unit_preview_size : weaponless_unit_preview_size);
+	unsigned w = font::relative_size(weapons_ ? 200 : 190);
+	unsigned h = font::relative_size(weapons_ ? 370 : 140);
+	set_measurements(w, h);
 	unit_store_.push_back(u);
 }
 
@@ -560,7 +561,7 @@ unit_preview_pane::unit_preview_pane(display& disp, const gamemap* map, const st
 										  map_(map), units_(&units), index_(0), left_(on_left_side),
 										  weapons_(type == SHOW_ALL)
 {
-	set_location(unit_preview_size);
+	set_measurements(font::relative_size(200), font::relative_size(370));
 }
 
 bool unit_preview_pane::show_above() const
@@ -585,28 +586,21 @@ void unit_preview_pane::set_selection(int index)
 	}
 }
 
-void unit_preview_pane::draw()
+void unit_preview_pane::draw_contents()
 {
-	if(!dirty()) {
-		return;
-	}
-
-	bg_restore();
-
 	if(index_ < 0 || index_ >= int(units_->size())) {
 		return;
 	}
 
 	const unit& u = (*units_)[index_];
 
-	set_dirty(false);
-
 	const bool right_align = left_side();
 
 	surface const screen = disp().video().getSurface();
 
-	const SDL_Rect area = { location().x+unit_preview_border, location().y+unit_preview_border,
-	                        location().w-unit_preview_border*2, location().h-unit_preview_border*2 };
+	SDL_Rect const &loc = location();
+	const SDL_Rect area = { loc.x + unit_preview_border, loc.y + unit_preview_border,
+	                        loc.w - unit_preview_border * 2, loc.h - unit_preview_border * 2 };
 	SDL_Rect clip_area = area;
 	const clip_rect_setter clipper(screen,clip_area);
 
@@ -645,14 +639,14 @@ void unit_preview_pane::draw()
 	details << u.type().language_name()
 			<< "\n" << _("level") << " "
 			<< u.type().level() << "\n"
-			<< string_table[unit_type::alignment_description(u.type().alignment())] << "\n"
+			<< unit_type::alignment_description(u.type().alignment()) << "\n"
 			<< u.traits_description() << " \n";
 
 	const std::vector<std::string>& abilities = u.type().abilities();
 	for(std::vector<std::string>::const_iterator a = abilities.begin(); a != abilities.end(); ++a) {
-		details << *a;
+		details << gettext(a->c_str());
 		if(a+1 != abilities.end()) {
-			details << ",";
+			details << ", ";
 		}
 	}
 
@@ -690,16 +684,13 @@ void unit_preview_pane::draw()
 		    at_it != attacks.end(); ++at_it) {
 
 			details << "\n"
-				<< at_it->name() << " (" << at_it->type() << ")\n"
-				<< at_it->special() << "\n"
-				<< at_it->damage() << "-" << at_it->num_attacks() << " -- "
-			        << (at_it->range() == attack_type::SHORT_RANGE ?
-			            _("melee") :
-						_("ranged"));
-	
-			if(at_it->hexes() > 1) {
-				details << " (" << at_it->hexes() << ")";
-			}
+			        << gettext(at_it->name().c_str())
+			        << " (" << gettext(at_it->type().c_str()) << ")\n";
+			if (!at_it->special().empty())
+				details << gettext(at_it->special().c_str());
+			details << "\n"
+			        << at_it->damage() << "-" << at_it->num_attacks() << " -- "
+			        << (at_it->range() == attack_type::SHORT_RANGE ? _("melee") : _("ranged"));
 		}
 	}
 	
@@ -725,28 +716,27 @@ void unit_preview_pane::draw()
 	}
 }
 
-void unit_preview_pane::process()
+void unit_preview_pane::process_event()
 {
 	if(map_ != NULL && details_button_.pressed() && index_ >= 0 && index_ < int(units_->size())) {
 
-		show_unit_description(disp(),*map_,(*units_)[index_]);
+		show_unit_description(disp(), (*units_)[index_]);
 	}
 }
 
-void show_unit_description(display& disp, const gamemap& map, const unit& u)
+void show_unit_description(display& disp, const unit& u)
 {
 	help::show_help(disp,"unit_" + u.type().id());
 }
 
 
 namespace {
-	static const SDL_Rect campaign_preview_size = {-350,-400,350,400};
 	static const int campaign_preview_border = 10;
 }
 
 campaign_preview_pane::campaign_preview_pane(display& disp,std::vector<std::pair<std::string,std::string> >* desc) : gui::preview_pane(disp),descriptions_(desc),index_(0)
 {
-	set_location(campaign_preview_size);
+	set_measurements(350, 400);
 }
 
 bool campaign_preview_pane::show_above() const { return false; }
@@ -761,20 +751,12 @@ void campaign_preview_pane::set_selection(int index)
 	}
 }
 
-void campaign_preview_pane::draw()
+void campaign_preview_pane::draw_contents()
 {
-	if(!dirty()) {
-		return;
-	}
-
-	bg_restore();
-
 	if(index_ < 0 || index_ >= descriptions_->size()) {
 		return;
 	}
 
-	set_dirty(false);
-
 	const SDL_Rect area = {
 		location().x+campaign_preview_border,
 		location().y+campaign_preview_border*5,
