@@ -13,17 +13,17 @@
 
 #include "editor.hpp"
 #include "../config.hpp"
-#include "../game_config.hpp"
-#include "../gettext.hpp"
+#include "../cursor.hpp"
 #include "../filesystem.hpp"
 #include "../font.hpp"
+#include "../game_config.hpp"
+#include "../gettext.hpp"
 #include "../image.hpp"
+#include "../language.hpp"
 #include "../map.hpp"
+#include "../preferences.hpp"
 #include "../team.hpp"
 #include "../util.hpp"
-#include "../preferences.hpp"
-#include "../language.hpp"
-#include "../cursor.hpp"
 #include "../wesconfig.h"
 
 #include <cctype>
@@ -34,16 +34,6 @@
 
 int main(int argc, char** argv)
 {
-	setlocale (LC_ALL, "");
-
-	const std::string& intl_dir = get_intl_dir();
-	bindtextdomain (PACKAGE "-editor", intl_dir.c_str());
-	bind_textdomain_codeset (PACKAGE "-editor", "UTF-8");
-	bindtextdomain (PACKAGE "-lib", intl_dir.c_str());
-	bind_textdomain_codeset (PACKAGE "-lib", "UTF-8");
-
-	textdomain (PACKAGE "-editor");
-
 	game_config::editor = true;
 
 	int arg;
@@ -108,7 +98,6 @@ int main(int argc, char** argv)
 			preferences::set_fullscreen(true);
 		} else if(val == "--datadir") {
 			if (arg+1 != argc) {
-				char buf[256];
 				const std::string val(argv[++arg]);
 
 				const std::string cwd = get_cwd();
@@ -141,6 +130,20 @@ int main(int argc, char** argv)
 			}
 		}
 	}
+
+	setlocale (LC_ALL, "");
+	const std::string& intl_dir = get_intl_dir();
+	bindtextdomain (PACKAGE "-editor", intl_dir.c_str());
+	bind_textdomain_codeset (PACKAGE "-editor", "UTF-8");
+	bindtextdomain (PACKAGE "-lib", intl_dir.c_str());
+	bind_textdomain_codeset (PACKAGE "-lib", "UTF-8");
+	textdomain (PACKAGE "-editor");
+
+        if (!filesystem_init()) {
+		std::cerr << "cannot init filesystem code\n";
+		return 1;
+	}
+
 	// Blatant cut and paste from game.cpp
 	image::set_wm_icon();
 	int video_flags = preferences::fullscreen() ? FULL_SCREEN : 0;
@@ -238,7 +241,6 @@ int main(int argc, char** argv)
 			std::cerr << "creating map...\n";
 			gamemap map(cfg, mapdata);
 
-			std::cerr << "Using theme cfg: " << std::endl << theme_cfg->write() << std::endl;
 			const config dummy_cfg("");
 			display gui(units, video, map, status, teams,
 				    *theme_cfg, cfg, dummy_cfg);
