@@ -21,8 +21,8 @@
 #include "../reports.hpp"
 #include "../language.hpp"
 #include "../util.hpp"
+#include "../wassert.hpp"
 
-#include <cassert>
 
 
 namespace map_editor {
@@ -36,7 +36,7 @@ terrain_palette::terrain_palette(display &gui, const size_specs &sizes,
 	: gui::widget(gui), size_specs_(sizes), gui_(gui), tstart_(0), map_(map),
 	  top_button_(gui, "", gui::button::TYPE_PRESS, "uparrow-button"),
 	  bot_button_(gui, "", gui::button::TYPE_PRESS, "downarrow-button") {
-	terrains_ = map_.get_terrain_precedence();
+	terrains_ = map_.get_terrain_list();
 	terrains_.erase(std::remove_if(terrains_.begin(), terrains_.end(), is_invalid_terrain),
 					terrains_.end());
 	if(terrains_.empty()) {
@@ -54,14 +54,16 @@ void terrain_palette::adjust_size() {
 	scroll_top();
 	const size_t button_height = 24;
 	const size_t button_palette_padding = 8;
-	set_location(size_specs_.palette_x, size_specs_.palette_y);
-	set_width(size_specs_.palette_w);
-	set_height(size_specs_.palette_h);
+	SDL_Rect rect = { size_specs_.palette_x, size_specs_.palette_y, size_specs_.palette_w, size_specs_.palette_h };
+	set_location(rect);
 	top_button_y_ = size_specs_.palette_y;
 	button_x_ = size_specs_.palette_x + size_specs_.palette_w/2 - button_height/2;
 	terrain_start_ = top_button_y_ + button_height + button_palette_padding;
 	const size_t space_for_terrains = size_specs_.palette_h -
 		(button_height + button_palette_padding) * 2;
+	rect.y = terrain_start_;
+	rect.h = space_for_terrains;
+	bg_register(rect);
 	const unsigned terrains_fitting =
 		(unsigned)(space_for_terrains / size_specs_.terrain_space) * 2;
 	const unsigned total_terrains = num_terrains();
@@ -72,7 +74,6 @@ void terrain_palette::adjust_size() {
 	bot_button_.set_location(button_x_, bot_button_y_);
 	top_button_.set_dirty();
 	bot_button_.set_dirty();
-	bg_backup();
 	set_dirty();
 }
 
@@ -150,16 +151,16 @@ void terrain_palette::select_bg_terrain(gamemap::TERRAIN terrain) {
 
 std::string terrain_palette::get_terrain_string(const gamemap::TERRAIN t) {
 	std::stringstream str;
-	const std::string& name = map_.terrain_name(t);
-	const std::vector<std::string>& underlying_names =
-		map_.underlying_terrain_name(t);
-	str << translate_string(name);
-	if(underlying_names.size() != 1 || underlying_names.front() != name) {
+	const std::string& name = map_.get_terrain_info(t).name();
+	const std::string& underlying = map_.underlying_terrain(t);
+	str << name;
+	if(underlying.size() != 1 || underlying[0] != t) {
 		str << " (";
-		for(std::vector<std::string>::const_iterator i = underlying_names.begin();
-			i != underlying_names.end(); ++i) {
-			str << translate_string(*i);
-			if(i+1 != underlying_names.end()) {
+		for(std::string::const_iterator i = underlying.begin();
+			i != underlying.end(); ++i) {
+
+			str << map_.get_terrain_info(*i).name();
+			if(i+1 != underlying.end()) {
 				str << ",";
 			}
 		}
@@ -254,7 +255,7 @@ void terrain_palette::draw(bool force) {
 	for(unsigned int counter = starting; counter < ending; counter++){
 		const gamemap::TERRAIN terrain = terrains_[counter];
 		const std::string filename = "terrain/" +
-			map_.get_terrain_info(terrain).default_image() + ".png";
+			map_.get_terrain_info(terrain).symbol_image() + ".png";
 		surface image(image::get_image(filename, image::UNSCALED));
 		if(image == NULL) {
 			std::cerr << "image for terrain " << counter << ": '" << filename << "' not found\n";
@@ -295,6 +296,7 @@ void terrain_palette::draw(bool force) {
 	update_rect(loc);
 	set_dirty(false);
 }
+
 int terrain_palette::tile_selected(const int x, const int y) const {
 	for(unsigned int i = 0; i != nterrains_; i++) {
 		const int px = size_specs_.palette_x +
@@ -334,8 +336,7 @@ brush_bar::brush_bar(display &gui, const size_specs &sizes)
 
 void brush_bar::adjust_size() {
 	set_location(size_specs_.brush_x, size_specs_.brush_y);
-	set_width(size_ * total_brush_);
-	set_height(size_);
+	set_measurements(size_ * total_brush_, size_);
 	set_dirty();
 }
 
