@@ -1,4 +1,4 @@
-/* $Id: filesystem.hpp,v 1.29 2004/09/18 21:42:13 Sirp Exp $ */
+/* $Id: filesystem.hpp,v 1.31 2004/12/31 02:21:00 ydirson Exp $ */
 /*
    Copyright (C) 2003 by David White <davidnwhite@optusnet.com.au>
    Part of the Battle for Wesnoth Project http://wesnoth.whitevine.net
@@ -44,6 +44,13 @@ std::string get_cwd();
 
 void make_directory(const std::string& dirname);
 
+//basic disk I/O
+bool filesystem_init();
+std::string read_file(const std::string& fname);
+//throws io_exception if an error occurs
+void write_file(const std::string& fname, const std::string& data);
+std::string read_stdin();
+
 std::string read_map(const std::string& name);
 
 //function which returns true iff the given file is a directory
