@@ -1,4 +1,4 @@
-/* $Id: font.cpp,v 1.97 2005/01/08 21:49:29 silene Exp $ */
+/* $Id: font.cpp,v 1.98 2005/02/09 23:32:01 ydirson Exp $ */
 /*
    Copyright (C) 2003 by David White <davidnwhite@optusnet.com.au>
    Part of the Battle for Wesnoth Project http://wesnoth.whitevine.net
@@ -841,7 +841,7 @@ surface floating_label::create_surface()
 		} else {
 			surface background = font::render_text(get_font(font_size_), text_, font::BLACK_COLOUR, 0);
 			background = blur_surface(background,4);
-			background = adjust_surface_alpha(background, 4);
+			background = adjust_surface_alpha(background, ftofxp(4.0));
 
 			surf_.assign(background);
 		}
