@@ -1,4 +1,4 @@
-/* $Id: font.hpp,v 1.44 2004/10/04 23:34:51 ydirson Exp $ */
+/* $Id: font.hpp,v 1.47 2004/11/27 10:24:50 silene Exp $ */
 /*
    Copyright (C) 2003 by David White <davidnwhite@optusnet.com.au>
    Part of the Battle for Wesnoth Project http://wesnoth.whitevine.net
@@ -37,8 +37,6 @@ void set_font();
 extern const SDL_Color NORMAL_COLOUR, GOOD_COLOUR, BAD_COLOUR, BLACK_COLOUR,
                        DARK_COLOUR, YELLOW_COLOUR, BUTTON_COLOUR, TITLE_COLOUR;
 
-enum MARKUP { USE_MARKUP, NO_MARKUP };
-
 //standard markups
 extern const char LARGE_TEXT, SMALL_TEXT, GOOD_TEXT, BAD_TEXT, NORMAL_TEXT, BLACK_TEXT, BOLD_TEXT, IMAGE, NULL_MARKUP;
 
@@ -49,23 +47,26 @@ const int SIZE_NORMAL = 8;
 #else
 const int SIZE_NORMAL = 14;
 #endif
+inline int relative_size(int size)
+{
+  return (SIZE_NORMAL * size / 14);
+}
 // automatic computation of other font sizes, to be made a default for theme-provided values
 const int
-  SIZE_TINY	= SIZE_NORMAL * 10 / 14,
-  SIZE_SMALL	= SIZE_NORMAL * 12 / 14,
+  SIZE_TINY	= relative_size(10),
+  SIZE_SMALL	= relative_size(12),
 
-  SIZE_15	= SIZE_NORMAL * 15 / 14,
-  SIZE_PLUS	= SIZE_NORMAL * 16 / 14,
-  SIZE_LARGE	= SIZE_NORMAL * 18 / 14,
-  SIZE_XLARGE	= SIZE_NORMAL * 24 / 14
+  SIZE_15	= relative_size(15),
+  SIZE_PLUS	= relative_size(16),
+  SIZE_LARGE	= relative_size(18),
+  SIZE_XLARGE	= relative_size(24)
   ;  
 //function to draw text on the screen. The text will be clipped to area.
 //If the text runs outside of area horizontally, an ellipsis will be displayed
 //at the end of it. If use_tooltips is true, then text with an ellipsis will
 //have a tooltip set for it equivalent to the entire contents of the text.
 //
-//if use_markup is equal to USE_MARKUP, then some very basic 'markup' will
-//be done on the text:
+//some very basic 'markup' will be done on the text:
 // - any line beginning in # will be displayed in BAD_COLOUR
 // - any line beginning in @ will be displayed in GOOD_COLOUR
 // - any line beginning in + will be displayed with size increased by 2
@@ -79,8 +80,7 @@ const int
 
 SDL_Rect draw_text(display* gui, const SDL_Rect& area, int size,
                    const SDL_Color& colour, const std::string& text,
-                   int x, int y, surface bg=NULL,
-                   bool use_tooltips=false, MARKUP use_markup=USE_MARKUP, int style=0);
+                   int x, int y, bool use_tooltips = false, int style = 0);
 
 //function which returns the size of text if it were to be drawn.
 SDL_Rect text_area(const std::string& text, int size, int style=0);
@@ -123,7 +123,7 @@ std::string make_text_ellipsis(const std::string& text, int font_size, int max_w
 /// 
 SDL_Rect draw_wrapped_text(display* gui, const SDL_Rect& area, int font_size,
 			     const SDL_Color& colour, const std::string& text,
-			     int x, int y, int max_width, surface bg = NULL);
+			     int x, int y, int max_width);
 
 
 /// structure which will hide all current floating labels, and cause floating labels
@@ -149,8 +149,10 @@ enum LABEL_SCROLL_MODE { ANCHOR_LABEL_SCREEN, ANCHOR_LABEL_MAP };
 ///
 /// @returns a handle to the label which can be used with other label functions
 int add_floating_label(const std::string& text, int font_size, const SDL_Color& colour,
-					   double xpos, double ypos, double xmove, double ymove, int lifetime, const SDL_Rect& clip_rect, ALIGN alignment=CENTER_ALIGN,
-					   const SDL_Color* bg_colour=NULL, int border_size=0, LABEL_SCROLL_MODE scroll_mode=ANCHOR_LABEL_SCREEN);
+		double xpos, double ypos, double xmove, double ymove, int lifetime,
+		const SDL_Rect& clip_rect, ALIGN alignment=CENTER_ALIGN,
+		const SDL_Color* bg_colour=NULL, int border_size=0, 
+		LABEL_SCROLL_MODE scroll_mode=ANCHOR_LABEL_SCREEN);
 
 /// moves the floating label given by 'handle' by (xmove,ymove)
 void move_floating_label(int handle, double xmove, double ymove);
