@@ -1,4 +1,4 @@
-/* $Id: game.cpp,v 1.188 2005/02/06 10:40:12 isaaccp Exp $ */
+/* $Id: game.cpp,v 1.191 2005/02/19 09:26:31 isaaccp Exp $ */
 /*
    Copyright (C) 2003 by David White <davidnwhite@optusnet.com.au>
    Part of the Battle for Wesnoth Project http://wesnoth.whitevine.net
@@ -1514,7 +1514,8 @@ int play_game(int argc, char** argv)
 	// initialized to have get_intl_dir() to work.  Note: this
 	// setlocale() but this does not take GUI language setting
 	// into account.
-	setlocale (LC_ALL, "");
+	setlocale(LC_ALL, "C");
+	setlocale(LC_MESSAGES, "");
 	const std::string& intl_dir = get_intl_dir();
 	bindtextdomain (PACKAGE, intl_dir.c_str());
 	bind_textdomain_codeset (PACKAGE, "UTF-8");
@@ -1648,6 +1649,8 @@ int main(int argc, char** argv)
 		//just means the game should quit
 	} catch(end_level_exception&) {
 		std::cerr << "caught end_level_exception (quitting)\n";
+	} catch(std::bad_alloc&) {
+		std::cerr << "ran out of memory: game aborted\n";
 	} /*catch(...) {
 		std::cerr << "Unhandled exception. Exiting\n";
 	}*/
