@@ -1,4 +1,4 @@
-/* $Id: game_events.cpp,v 1.109 2004/10/03 19:28:43 Sirp Exp $ */
+/* $Id: game_events.cpp,v 1.118 2005/01/21 20:07:30 Sirp Exp $ */
 /*
    Copyright (C) 2003 by David White <davidnwhite@optusnet.com.au>
    Part of the Battle for Wesnoth Project http://wesnoth.whitevine.net
@@ -11,6 +11,8 @@
    See the COPYING file for more details.
 */
 
+#include "global.hpp"
+
 #include "game_events.hpp"
 #include "image.hpp"
 #include "language.hpp"
@@ -22,6 +24,7 @@
 #include "sound.hpp"
 #include "unit_display.hpp"
 #include "util.hpp"
+#include "wassert.hpp"
 
 #include <cstdlib>
 #include <deque>
@@ -185,10 +188,10 @@ public:
 		return cfg_->get_children("filter_second");
 	}
 
-	void handle_event(const queued_event& event_info, const config* cfg=NULL);
+	bool handle_event(const queued_event& event_info, const config* cfg=NULL);
 
 private:
-	bool handle_event_command(const queued_event& event_info, const std::string& cmd, const config& cfg);
+	bool handle_event_command(const queued_event& event_info, const std::string& cmd, const config& cfg, bool& mutated);
 
 	std::string name_;
 	bool first_time_only_;
@@ -205,7 +208,7 @@ std::multimap<std::string,event_handler> events_map;
 
 //this function handles all the different types of actions that can be triggered
 //by an event.
-bool event_handler::handle_event_command(const queued_event& event_info, const std::string& cmd, const config& cfg)
+bool event_handler::handle_event_command(const queued_event& event_info, const std::string& cmd, const config& cfg, bool& mutated)
 {
 	log_scope2(engine, "handle_event_command");
 	LOG_NG << "handling command: '" << cmd << "'\n";
@@ -216,6 +219,10 @@ bool event_handler::handle_event_command(const queued_event& event_info, const s
 		handle_event(event_info,&cfg);
 	}
 
+	//allow undo sets the flag saying whether the event has mutated the game to false
+	else if(cmd == "allow_undo") {
+		mutated = false;
+	}
 	//change shroud settings for portions of the map
 	else if(cmd == "remove_shroud" || cmd == "place_shroud") {
 		const bool remove = cmd == "remove_shroud";
@@ -475,7 +482,7 @@ bool event_handler::handle_event_command(const queued_event& event_info, const s
 				dst.x = atoi(xvals[i].c_str())-1;
 				dst.y = atoi(yvals[i].c_str())-1;
 
-				paths::route route=a_star_search(src,dst,10000,calc,0);
+				paths::route route = a_star_search(src, dst, 10000, &calc, game_map->x(), game_map->y());
 				unit_display::move_unit(*screen, *game_map, route.steps,
 						dummy_unit,status_ptr->get_time_of_day(), *units, *teams);
 
@@ -819,10 +826,6 @@ bool event_handler::handle_event_command(const queued_event& event_info, const s
 		const std::string image = cfg["image"];
 		std::string caption = cfg["name"];
 
-		const std::string& caption_lang = string_table[id + "_name"];
-		if(caption_lang.empty() == false)
-			caption = caption_lang;
-
 		std::string text;
 
 		gamemap::location loc;
@@ -844,11 +847,7 @@ bool event_handler::handle_event_command(const queued_event& event_info, const s
 		std::string command_type = "then";
 
 		if(u != units->end() && (filter == NULL || game_events::unit_matches_filter(u,*filter))) {
-			const std::string& lang = string_table[id];
-			if(!lang.empty())
-				text = lang;
-			else
-				text = cfg["description"];
+			text = cfg["description"];
 
 			u->second.add_modification("object",cfg);
 
@@ -858,11 +857,7 @@ bool event_handler::handle_event_command(const queued_event& event_info, const s
 			//mark that this item won't be used again
 			used_items.insert(id);
 		} else {
-			const std::string& lang = string_table[id + "_cannot_use"];
-			if(!lang.empty())
-				text = lang;
-			else
-				text = cfg["cannot_use_message"];
+			text = cfg["cannot_use_message"];
 
 			command_type = "else";
 		}
@@ -938,16 +933,8 @@ bool event_handler::handle_event_command(const queued_event& event_info, const s
 			sound::play_sound(sfx);
 		}
 
-		const std::string& id = cfg["id"];
-
 		std::string image = cfg["image"];
-		std::string caption;
-
-		const std::string& lang_caption = string_table[id + "_caption"];
-		if(!lang_caption.empty())
-			caption = lang_caption;
-		else
-			caption = cfg["caption"];
+		std::string caption = cfg["caption"];
 
 		if(speaker != units->end()) {
 			LOG_DP << "scrolling to speaker..\n";
@@ -983,7 +970,6 @@ bool event_handler::handle_event_command(const queued_event& event_info, const s
 			surface.assign(image::get_image(image,image::UNSCALED));
 		}
 
-		const std::string& lang_message = string_table[id];
 		int option_chosen = -1;
 
 		LOG_DP << "showing dialog...\n";
@@ -991,7 +977,7 @@ bool event_handler::handle_event_command(const queued_event& event_info, const s
 		//if we're not replaying, or if we are replaying and there is no choice
 		//to be made, show the dialog.
 		if(get_replay_source().at_end() || options.empty()) {
-			const std::string msg = config::interpolate_variables_into_string(lang_message.empty() ? cfg["message"] : lang_message);
+			const std::string msg = config::interpolate_variables_into_string(cfg["message"]);
 			option_chosen = gui::show_dialog(*screen,surface,caption,msg,
 		                        options.empty() ? gui::MESSAGE : gui::OK_ONLY,
 		                        options.empty() ? NULL : &options);
@@ -1025,7 +1011,7 @@ bool event_handler::handle_event_command(const queued_event& event_info, const s
 
 		//implement the consequences of the choice
 		if(options.empty() == false) {
-			assert(size_t(option_chosen) < menu_items.size());
+			wassert(size_t(option_chosen) < menu_items.size());
 			
 			for(config::const_child_itors events = option_events[option_chosen];
 			    events.first != events.second; ++events.first) {
@@ -1261,11 +1247,13 @@ bool event_handler::handle_event_command(const queued_event& event_info, const s
 	return rval;
 }
 
-void event_handler::handle_event(const queued_event& event_info, const config* cfg)
+bool event_handler::handle_event(const queued_event& event_info, const config* cfg)
 {
 	if(cfg == NULL)
 		cfg = cfg_;
 
+	bool mutated = true;
+
 	bool skip_messages = false;
 	for(config::all_children_iterator i = cfg->ordered_begin();
 		i != cfg->ordered_end(); ++i) {
@@ -1279,13 +1267,15 @@ void event_handler::handle_event(const queued_event& event_info, const config* c
 			}
 		}
 
-		if (!handle_event_command(event_info,*item.first,*item.second))  {
+		if (!handle_event_command(event_info,*item.first,*item.second,mutated))  {
 			skip_messages = true;
 		}
 		else { 
 			skip_messages = false;
 		}
 	}
+
+	return mutated;
 }
 
 bool filter_loc_impl(const gamemap::location& loc, const std::string& xloc,
@@ -1381,13 +1371,13 @@ bool process_event(event_handler& handler, const queued_event& ev)
 	}
 
 	//the event hasn't been filtered out, so execute the handler
-	handler.handle_event(ev);
+	const bool res = handler.handle_event(ev);
 
 	if(handler.first_time_only()) {
 		handler.disable();
 	}
 
-	return true;
+	return res;
 }
 
 void get_variable_internal(const std::string& key, config& cfg,
