@@ -1,4 +1,4 @@
-/* $Id: gamestatus.cpp,v 1.44 2004/09/21 20:35:48 gruikya Exp $ */
+/* $Id: gamestatus.cpp,v 1.53 2005/01/28 20:17:46 silene Exp $ */
 /*
    Copyright (C) 2003 by David White <davidnwhite@optusnet.com.au>
    Part of the Battle for Wesnoth Project http://wesnoth.whitevine.net
@@ -10,6 +10,9 @@
 
    See the COPYING file for more details.
 */
+
+#include "global.hpp"
+
 #include "filesystem.hpp"
 #include "game_config.hpp"
 #include "gamestatus.hpp"
@@ -31,9 +34,6 @@ time_of_day::time_of_day(const config& cfg)
                    green(atoi(cfg["green"].c_str())),
                    blue(atoi(cfg["blue"].c_str()))
 {
-	const std::string& lang_name = string_table[cfg["id"]];
-	if(lang_name.empty() == false)
-		name = lang_name;
 }
 
 void time_of_day::write(config& cfg) const
@@ -102,12 +102,12 @@ gamestatus::gamestatus(config& time_cfg, int num_turns) :
 
 void gamestatus::write(config& cfg) const
 {
-	char buf[50];
-	sprintf(buf,"%d",turn_);
-	cfg["turn_at"] = buf;
-
-	sprintf(buf,"%d",numTurns_);
-	cfg["turns"] = buf;
+	std::stringstream buf;
+	buf << turn_;
+	cfg["turn_at"] = buf.str();
+	buf.str(std::string());
+	buf << numTurns_;
+	cfg["turns"] = buf.str();
 
 	std::vector<time_of_day>::const_iterator t;
 	for(t = times_.begin(); t != times_.end(); ++t) {
@@ -406,9 +406,8 @@ void delete_game(const std::string& name)
 	remove((get_saves_dir() + "/" + modified_name).c_str());
 }
 
-void load_game(const game_data& data, const std::string& name, game_state& state)
+void read_save_file(const std::string& name, config& cfg)
 {
-	log_scope("load_game");
 	std::string modified_name = name;
 	std::replace(modified_name.begin(),modified_name.end(),' ','_');
 
@@ -418,12 +417,21 @@ void load_game(const game_data& data, const std::string& name, game_state& state
 		file_data = read_file(get_saves_dir() + "/" + name);
 	}
 
-	config cfg(file_data);
+	cfg.clear();
+	cfg.read(file_data);
 
 	if(cfg.empty()) {
 		std::cerr << "Could not parse file data into config\n";
 		throw gamestatus::load_game_failed();
 	}
+}
+
+void load_game(const game_data& data, const std::string& name, game_state& state)
+{
+	log_scope("load_game");
+
+	config cfg;
+	read_save_file(name,cfg);
 	
 	state = read_game(data,&cfg);
 }
@@ -469,7 +477,7 @@ config& save_index()
 			save_index_cfg.read(read_file(get_save_index_file()));
 		} catch(io_exception& e) {
 			std::cerr << "error reading save index: '" << e.what() << "'\n";
-		} catch(config::error& e) {
+		} catch(config::error&) {
 			std::cerr << "error parsing save index config file\n";
 			save_index_cfg.clear();
 		}
@@ -524,6 +532,7 @@ void extract_summary_data_from_save(const game_state& state, config& out)
 	out["campaign_type"] = state.campaign_type;
 	out["scenario"] = state.scenario;
 	out["difficulty"] = state.difficulty;
+	out["version"] = state.version;
 	out["corrupt"] = "";
 
 	if(has_snapshot) {
