@@ -1,4 +1,4 @@
-/* $Id: gamestatus.hpp,v 1.33 2004/10/03 18:00:15 gruikya Exp $ */
+/* $Id: gamestatus.hpp,v 1.36 2004/12/04 23:44:09 isaaccp Exp $ */
 /*
    Copyright (C) 2003 by David White <davidnwhite@optusnet.com.au>
    Part of the Battle for Wesnoth Project http://wesnoth.whitevine.net
@@ -13,6 +13,7 @@
 #ifndef GAME_STATUS_HPP_INCLUDED
 #define GAME_STATUS_HPP_INCLUDED
 
+#include "log.hpp"
 #include "unit.hpp"
 #include "unit_types.hpp"
 
@@ -147,11 +148,10 @@ struct game_state
 
 	// Return the Nth player, or NULL if no such player exists
 	player_info* get_player(const std::string& id) {
-		std::cerr << "get_player('" << id << "')\n";
 		std::map<std::string, player_info>::iterator found=players.find(id);
 
 		if(found==players.end()) {
-			std::cerr << "WARNING: player " << id << " does not exist." << std::endl;
+			lg::warn(lg::engine) << "player " << id << " does not exist." << std::endl;
 			return NULL;
 		} else {
 			return &found->second;
@@ -189,6 +189,8 @@ std::vector<save_info> get_saves_list();
 
 enum WRITE_GAME_MODE { WRITE_SNAPSHOT_ONLY, WRITE_FULL_GAME };
 
+void read_save_file(const std::string& name, config& cfg);
+
 game_state read_game(const game_data& data, const config* cfg);
 void write_game(const game_state& game, config& cfg, WRITE_GAME_MODE mode=WRITE_FULL_GAME);
 
