@@ -1,7 +1,14 @@
+#include "global.hpp"
+
 #include "gettext.hpp"
 
 #include <cstring>
 
+char const *egettext(char const *msgid)
+{
+	return msgid[0] == '\0' ? msgid : gettext(msgid);
+}
+
 const char* sgettext (const char *msgid)
 {
 	const char *msgval = gettext (msgid);
@@ -28,10 +35,10 @@ const char* dsgettext (const char * domainname, const char *msgid)
 	return msgval;
 }
 
-const char* vgettext (const char *msgid, const string_map& symbols)
+std::string vgettext (const char *msgid, const string_map& symbols)
 {
 	const std::string orig(gettext(msgid));
 	const std::string msg = config::interpolate_variables_into_string(orig,
 			&symbols);
-	return msg.c_str();
+	return msg;
 }
