@@ -5,9 +5,11 @@
 
 // gettext-related declarations
 #include <libintl.h>
+
+const char* egettext (const char*);
 const char* sgettext (const char*);
 const char* dsgettext (const char * domainname, const char *msgid);
-const char* vgettext (const char*,const string_map&);
+std::string vgettext (const char*,const string_map&);
 
 #ifdef GETTEXT_DOMAIN
 # define _(String) dgettext(GETTEXT_DOMAIN,String)
