@@ -202,25 +202,25 @@ bool locator::value::operator<(const value& a) const
 
 surface locator::load_image_file() const
 {
+	surface res;
+
+	std::string const &location = get_binary_file_location("images", val_.filename_);
+	if (!location.empty()) {
 #ifdef USE_ZIPIOS
-	std::string s = read_file("images/" + val_.filename_);
-	if (s.empty())
-		return surface(NULL);
-
-	SDL_RWops* ops = SDL_RWFromMem((void*)s.c_str(), s.size());
-	const surface res(IMG_Load_RW(ops, 0));
-	SDL_FreeRW(ops);
+		std::string const &s = read_file(location);
+		if (!s.empty()) {
+			SDL_RWops* ops = SDL_RWFromMem((void*)s.c_str(), s.size());
+			res = IMG_Load_RW(ops, 0);
+			SDL_FreeRW(ops);
+		}
 #else
-	const std::string& location = get_binary_file_location("images", val_.filename_);
-	if(location.empty())
-		return surface(NULL);
-
-	const surface res(IMG_Load(location.c_str()));
+		res = IMG_Load(location.c_str());
 #endif
-	if(res == NULL) {
-		ERR_DP << "could not open image '" << val_.filename_ << "'\n";
 	}
 
+	if (res.null())
+		ERR_DP << "could not open image '" << val_.filename_ << "'\n";
+
 	return res;
 }
 
@@ -464,13 +464,13 @@ surface get_greyed(const locator i_locator, COLOUR_ADJUSTMENT adj)
 surface get_brightened(const locator i_locator, COLOUR_ADJUSTMENT adj)
 {
 	surface image(get_image(i_locator, SCALED, adj));
-	return surface(brighten_image(image, 1.5));
+	return surface(brighten_image(image, ftofxp(1.5)));
 }
 
 surface get_semi_brightened(const locator i_locator, COLOUR_ADJUSTMENT adj)
 {
 	surface image(get_image(i_locator, SCALED, adj));
-	return surface(brighten_image(image, 1.25));
+	return surface(brighten_image(image, ftofxp(1.25)));
 }
 
 surface get_image(const image::locator& i_locator, TYPE type, COLOUR_ADJUSTMENT adj)
@@ -622,26 +622,18 @@ void register_image(const image::locator& id, const surface& surf)
 
 bool exists(const image::locator& i_locator)
 {
-	bool ret=false;
-
-	if(i_locator.get_type() != image::locator::FILE && 
-			i_locator.get_type() != image::locator::SUB_FILE) 
+	typedef image::locator loc;
+	loc::type type = i_locator.get_type();
+	if (type != loc::FILE && type != loc::SUB_FILE) 
 		return false;
 
-	if(image_existance_map.find(i_locator) != image_existance_map.end())
-		return image_existance_map[i_locator];
-
-#ifdef USE_ZIPIOS
-	if(file_exists("images/" + i_locator.get_filename()))
-		ret = true;
-#else
-	if(get_binary_file_location("images",i_locator.get_filename()).empty() == false) {
-		ret = true;
-	}
-#endif
-	image_existance_map[i_locator] = ret;
-
-	return ret;
+	// the insertion will fail if there is already an element in the cache
+	std::pair< std::map< image::locator, bool >::iterator, bool >
+		it = image_existance_map.insert(std::make_pair(i_locator, false));
+	bool &cache = it.first->second;
+	if (it.second)
+		cache = !get_binary_file_location("images", i_locator.get_filename()).empty();
+	return cache;
 }
 
 surface getMinimap(int w, int h, const gamemap& map, const team* tm)
