@@ -185,7 +185,7 @@ namespace image {
 
 	///function to create the minimap for a given map
 	///the surface returned must be freed by the user
-	surface getMinimap(int w, int h, const gamemap& map_, int lawful_bonus, const team* tm=NULL);
+	surface getMinimap(int w, int h, const gamemap& map_, const team* tm=NULL);
 }
 
 #endif
