@@ -1,4 +1,4 @@
-/* $Id: intro.cpp,v 1.60 2004/09/25 19:46:33 ydirson Exp $ */
+/* $Id: intro.cpp,v 1.65 2004/11/27 10:24:50 silene Exp $ */
 /*
    Copyright (C) 2003 by David White <davidnwhite@optusnet.com.au>
    Part of the Battle for Wesnoth Project http://wesnoth.whitevine.net
@@ -11,6 +11,8 @@
    See the COPYING file for more details.
 */
 
+#include "global.hpp"
+
 #include "events.hpp"
 #include "font.hpp"
 #include "game_config.hpp"
@@ -116,17 +118,21 @@ bool show_intro_part(display& screen, const config& part,
 
 		SDL_BlitSurface(background,NULL,screen.video().getSurface(),&dstrect);
 
+#ifdef USE_TINY_GUI
+		textx = 10;
+		int xbuttons = screen.x() - 50;
+#else
 		textx = dstrect.x;
+		int xbuttons = dstrect.x+dstrect.w-40;
+#endif
 		texty = dstrect.y + dstrect.h + 10;
 
-		next_button.set_location(dstrect.x+dstrect.w-40,dstrect.y+dstrect.h+20);
-		skip_button.set_location(dstrect.x+dstrect.w-40,dstrect.y+dstrect.h+70);
+		next_button.set_location(xbuttons,dstrect.y+dstrect.h+20);
+		skip_button.set_location(xbuttons,dstrect.y+dstrect.h+70);
 	} else {
 		next_button.set_location(screen.x()-200,screen.y()-150);
 		skip_button.set_location(screen.x()-200,screen.y()-100);
 	}
-	next_button.draw();
-	skip_button.draw();
 
 	//draw title if needed
 	if(show_title) {
@@ -239,8 +245,7 @@ bool show_intro_part(display& screen, const config& part,
 				}
 				const SDL_Rect rect = font::draw_text(NULL,screen.screen_area(),
 						font::SIZE_PLUS,font::NORMAL_COLOUR,
-						word,xpos,ypos,NULL,
-						false,font::NO_MARKUP);
+						word, xpos, ypos, false);
 
 				if(xpos + rect.w >= max_xpos) {
 					xpos = textx;
@@ -254,7 +259,7 @@ bool show_intro_part(display& screen, const config& part,
 			const SDL_Rect rect = font::draw_text(&screen,
 					screen.screen_area(),font::SIZE_PLUS,
 					font::NORMAL_COLOUR,*j,xpos,ypos,
-					NULL,false,font::NO_MARKUP);
+					false);
 
 			if(rect.h > height)
 				height = rect.h;
@@ -267,10 +272,6 @@ bool show_intro_part(display& screen, const config& part,
 
 		}
 
-		int mousex, mousey;
-		const int mouse_flags = SDL_GetMouseState(&mousex,&mousey);
-		const bool left_button = mouse_flags&SDL_BUTTON_LMASK;
-
 		const bool keydown = key[SDLK_SPACE] || key[SDLK_RETURN];
 
 		if(keydown && !last_key || next_button.pressed()) {
@@ -283,7 +284,7 @@ bool show_intro_part(display& screen, const config& part,
 
 		last_key = keydown;
 
-		if(key[SDLK_ESCAPE] || skip_button.process(mousex,mousey,left_button))
+		if(key[SDLK_ESCAPE] || skip_button.pressed())
 			return false;
 
 		events::pump();
