@@ -1,4 +1,4 @@
-/* $Id: intro.hpp,v 1.12 2004/03/02 03:53:31 kmj Exp $ */
+/* $Id: intro.hpp,v 1.17 2004/08/28 23:00:13 Sirp Exp $ */
 /*
    Copyright (C) 2003 by David White <davidnwhite@optusnet.com.au>
    Part of the Battle for Wesnoth Project http://wesnoth.whitevine.net
@@ -32,23 +32,8 @@
 //
 //each part of the sequence will be displayed in turn, with the
 //user able to go to the next part, or skip it entirely.
-void show_intro(display& screen, const config& data, game_state& state_of_game);
+void show_intro(display& screen, const config& data, const config& level);
 
-//function to show the map before each scenario.
-//data is in a format that looks like,
-//[bigmap]
-//image='map-image'
-//	[dot]
-//	x='x'
-//	y='y'
-//	type=cross (optional)
-//	[/dot]
-//  ... more 'dot' nodes'
-//[/bigmap]
-//
-//where 'map-image' is the image of the map. dots are displayed
-//at 'x','y' on the image in sequence. type=cross should be used
-//for the last dot, to show where the battle takes place.
-void show_map_scene(display& screen, config& data);
+void the_end(display& screen);
 
 #endif
