@@ -1,4 +1,4 @@
-/* $Id: language.cpp,v 1.63 2005/01/16 10:44:29 ydirson Exp $ */
+/* $Id: language.cpp,v 1.68 2005/02/12 22:24:12 ydirson Exp $ */
 /*
    Copyright (C) 2003 by David White <davidnwhite@optusnet.com.au>
    Part of the Battle for Wesnoth Project http://wesnoth.whitevine.net
@@ -31,27 +31,28 @@ namespace {
 }
 
 language_def known_languages[] = {
- 	language_def("", N_("System default language")),
-	language_def("bg_BG", "Български"),
+	language_def("", N_("System default language")),
+	language_def("bg_BG", "Български (Bulgarski)"),
 	language_def("es_ES", "Castellano"),
 	language_def("ca_ES", "Català"),
 	language_def("cs_CZ", "Čeština"),
 	language_def("da_DK", "Dansk"),
 	language_def("de_DE", "Deutsch"),
- 	language_def("C", "English"),
+	language_def("el_GR", "Ελληνικά (Ellinika)"),
+	language_def("en_GB", "English (GB)"),
+	language_def("C",     "English (hm... nearly US)"),
 	language_def("eu_ES", "Euskera"),
- 	language_def("fr_FR", "Français"),
- 	language_def("el_GR", "Greek"),
-	language_def("hu_HU", "Hungarian"),
+	language_def("fr_FR", "Français"),
 	language_def("it_IT", "Italiano"),
 	language_def("la_IT", "Latina"),
+	language_def("hu_HU", "Magyar"),
 	language_def("nl_NL", "Nederlands"),
 	language_def("no_NO", "Norsk"),
 	language_def("pl_PL", "Polski"),
 	language_def("pt_BR", "Português do Brasil"),
-	language_def("ru_RU", "Русский (Russian)"),
+	language_def("ru_RU", "Русский (Russkij)"),
 	language_def("sk_SK", "Slovenčina"),
-	language_def("sl_SL", "Slovenščina"),
+	language_def("sl_SI", "Slovenščina"),
 	language_def("fi_FI", "Suomi"),
 	language_def("sv_SE", "Svenska"),
 
