@@ -1,4 +1,4 @@
-/* $Id: language.hpp,v 1.29 2004/08/23 06:40:59 gakusho Exp $ */
+/* $Id: language.hpp,v 1.30 2004/11/30 21:41:18 silene Exp $ */
 /*
    Copyright (C) 2003 by David White <davidnwhite@optusnet.com.au>
    Part of the Battle for Wesnoth Project http://wesnoth.whitevine.net
@@ -49,14 +49,6 @@ struct symbol_table
 //displayed on screen.
 extern symbol_table string_table;
 
-//function which translates a string if the string is available in
-//the string table, and otherwise simply returns the string itself
-const std::string& translate_string(const std::string& str);
-
-//version of translate_string which will look up key in the string table,
-//and otherwise returns default_val
-const std::string& translate_string_default(const std::string& key, const std::string& default_val);
-
 //function which, given the main configuration object, will return
 //a list of the translations of the game available.
 std::vector<language_def> get_languages();
