@@ -1,7 +1,8 @@
-/* $Id: log.cpp,v 1.15 2004/09/19 11:13:56 silene Exp $ */
+/* $Id: log.cpp,v 1.19 2004/12/31 21:01:37 isaaccp Exp $ */
 /*
    Copyright (C) 2003 by David White <davidnwhite@optusnet.com.au>
-   Part of the Battle for Wesnoth Project http://wesnoth.whitevine.net
+                 2004 by Guillaume Melquiond <guillaume.melquiond@gmail.com>
+   Part of the Battle for Wesnoth Project http://www.wesnoth.org/
 
    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License.
@@ -11,12 +12,13 @@
    See the COPYING file for more details.
 */
 
+#include "global.hpp"
+
 #include "SDL.h"
 
 #include "log.hpp"
 
 #include <algorithm>
-#include <cassert>
 #include <iostream>
 #include <sstream>
 #include <vector>
