@@ -1,4 +1,4 @@
-/* $Id: map.hpp,v 1.30 2005/01/21 22:21:54 Sirp Exp $ */
+/* $Id: map.hpp,v 1.32 2005/02/19 09:26:31 isaaccp Exp $ */
 /*
    Copyright (C) 2003 by David White <davidnwhite@optusnet.com.au>
    Part of the Battle for Wesnoth Project http://wesnoth.whitevine.net
@@ -52,7 +52,9 @@ public:
 	struct location {
 		//any valid direction which can be moved in in our hexagonal world.
 		enum DIRECTION { NORTH, NORTH_EAST, SOUTH_EAST, SOUTH,
-		                 SOUTH_WEST, NORTH_WEST };
+		                 SOUTH_WEST, NORTH_WEST, NDIRECTIONS };
+
+		static DIRECTION parse_direction(const std::string& str);
 
 		location() : x(-1), y(-1) {}
 		location(int x, int y) : x(x), y(y) {}
