@@ -1,4 +1,4 @@
-/* $Id: multiplayer.cpp,v 1.120 2004/09/25 19:46:33 ydirson Exp $ */
+/* $Id: multiplayer.cpp,v 1.134 2005/01/02 21:28:05 silene Exp $ */
 /*
    Copyright (C) 2003 by David White <davidnwhite@optusnet.com.au>
    Part of the Battle for Wesnoth Project http://wesnoth.whitevine.net
@@ -11,6 +11,8 @@
    See the COPYING file for more details.
 */
 
+#include "global.hpp"
+
 #include "cursor.hpp"
 #include "events.hpp"
 #include "filesystem.hpp"
@@ -19,6 +21,7 @@
 #include "log.hpp"
 #include "image.hpp"
 #include "key.hpp"
+#include "log.hpp"
 #include "mapgen.hpp"
 #include "multiplayer.hpp"
 #include "multiplayer_connect.hpp"
@@ -42,82 +45,82 @@
 #include <string>
 #include <vector>
 
+#define LOG_G lg::info(lg::general)
+#define LOG_NW lg::info(lg::network)
+#define LOG_DP lg::info(lg::display)
+#define ERR_CF lg::err(lg::config)
+
 network_game_manager::~network_game_manager()
 {
 	if(network::nconnections() > 0) {
-		std::cerr << "sending leave_game\n";
+		LOG_NW << "sending leave_game\n";
 		config cfg;
 		cfg.add_child("leave_game");
 		network::send_data(cfg);
-		std::cerr << "sent leave_game\n";
+		LOG_NW << "sent leave_game\n";
 	}
 }
 
 multiplayer_game_setup_dialog::multiplayer_game_setup_dialog(
                               display& disp, game_data& units_data,
-                              const config& cfg, game_state& state, bool server)
+                              const config& cfg, game_state& state, bool server, const std::string& controller)
         : disp_(disp), units_data_(units_data), cfg_(cfg), state_(state), server_(server), level_(NULL), map_selection_(-1),
 		  maps_menu_(NULL), turns_slider_(NULL), village_gold_slider_(NULL), xp_modifier_slider_(NULL),
 		  fog_game_(NULL), shroud_game_(NULL), observers_game_(NULL),
           cancel_game_(NULL), launch_game_(NULL), regenerate_map_(NULL), generator_settings_(NULL),
-		  era_combo_(NULL), vision_combo_(NULL), name_entry_(NULL), generator_(NULL)
+		  era_combo_(NULL), vision_combo_(NULL), name_entry_(NULL), generator_(NULL), controller_(controller)
 {
-	std::cerr << "setup dialog ctor\n";
+	LOG_DP << "setup dialog ctor\n";
 
-        for(std::map<std::string, player_info>::iterator i=state_.players.begin();
-            i!=state_.players.end(); ++i) {
-          i->second.available_units.clear();
-          i->second.can_recruit.clear();
-        }
+	state_.players.clear();
 	state_.variables.clear();
 
 	//build the list of scenarios to play
 	get_files_in_dir(get_user_data_dir() + "/editor/maps",&user_maps_,NULL,FILE_NAME_ONLY);
 
-	std::vector<std::string> options = user_maps_;
+	map_options_ = user_maps_;
 
 	const config::child_list& levels = cfg.get_children("multiplayer");
-	for(config::child_list::const_iterator i = levels.begin(); i != levels.end(); ++i){
-		options.push_back((**i)["name"]);
+	for(config::child_list::const_iterator j = levels.begin(); j != levels.end(); ++j){
+		map_options_.push_back((**j)["name"]);
 	}
 
 	//add the 'load game' option
-	options.push_back(_("Load Game") + std::string("..."));
+	map_options_.push_back(_("Load Game..."));
 
 	//create the scenarios menu
-	maps_menu_.assign(new gui::menu(disp_,options));
+	maps_menu_.assign(new gui::menu(disp_,map_options_));
 	maps_menu_->set_numeric_keypress_selection(false);
 
-	SDL_Rect rect = {0,0,0,0};
-
-	turns_slider_.assign(new gui::slider(disp_,rect));
+	turns_slider_.assign(new gui::slider(disp_));
 	turns_slider_->set_min(20);
 	turns_slider_->set_max(100);
-	turns_slider_->set_value(50);
+	turns_slider_->set_value(preferences::turns());
 	turns_slider_->set_help_string(_("The maximum turns the game will go for"));
 
-	village_gold_slider_.assign(new gui::slider(disp_,rect));
+	village_gold_slider_.assign(new gui::slider(disp_));
 	village_gold_slider_->set_min(1);
 	village_gold_slider_->set_max(5);
-	village_gold_slider_->set_value(1);
+	village_gold_slider_->set_value(preferences::village_gold());
 	village_gold_slider_->set_help_string(_("The amount of income each village yields per turn"));
 
-	xp_modifier_slider_.assign(new gui::slider(disp_,rect));
+	xp_modifier_slider_.assign(new gui::slider(disp_));
 	xp_modifier_slider_->set_min(25);
 	xp_modifier_slider_->set_max(200);
-	xp_modifier_slider_->set_value(100);
+	xp_modifier_slider_->set_value(preferences::xp_modifier());
+	xp_modifier_slider_->set_increment(10);
 	xp_modifier_slider_->set_help_string(_("The amount of experience a unit needs to advance"));
 
 	fog_game_.assign(new gui::button(disp_,_("Fog Of War"),gui::button::TYPE_CHECK));
-	fog_game_->set_check(false);
+	fog_game_->set_check(preferences::fog());
 	fog_game_->set_help_string(_("Enemy units cannot be seen unless they are in range of your units"));
 
 	shroud_game_.assign(new gui::button(disp_,_("Shroud"),gui::button::TYPE_CHECK));
-	shroud_game_->set_check(false);
+	shroud_game_->set_check(preferences::shroud());
 	shroud_game_->set_help_string(_("The map is unknown until your units explore it"));
 
 	observers_game_.assign(new gui::button(disp_,_("Observers"),gui::button::TYPE_CHECK));
-	observers_game_->set_check(true);
+	observers_game_->set_check(preferences::allow_observers());
 	observers_game_->set_help_string(_("Allow users who are not playing to watch the game"));
 
 	cancel_game_.assign(new gui::button(disp_,_("Cancel")));
@@ -143,18 +146,19 @@ multiplayer_game_setup_dialog::multiplayer_game_setup_dialog(
 
 	if(eras.empty()) {
 		gui::show_dialog(disp_,NULL,"",_("No multiplayer sides."),gui::OK_ONLY);
-		std::cerr << "ERROR: no eras found\n";
+		ERR_CF << "no eras found\n";
 		throw config::error("no eras found");
 	}
 
 	era_combo_.assign(new gui::combo(disp_,eras));
+	era_combo_->set_selected(preferences::era());
 
-	std::cerr << "end setup dialog ctor\n";
+	LOG_DP << "end setup dialog ctor\n";
 }
 
 void multiplayer_game_setup_dialog::set_area(const SDL_Rect& area)
 {
-	std::cerr << "setup dialog set_area\n";
+	LOG_DP << "setup dialog set_area\n";
 
 	area_ = area;
 
@@ -174,11 +178,10 @@ void multiplayer_game_setup_dialog::set_area(const SDL_Rect& area)
 
 	//Name Entry
 	ypos += font::draw_text(&disp_,disp_.screen_area(),font::SIZE_SMALL,font::GOOD_COLOUR,
-	                        _("Name of game") + std::string(":"),xpos,ypos).h + border_size;
+	                        _("Name of game:"),xpos,ypos).h + border_size;
 	string_map i18n_symbols;
 	i18n_symbols["login"] = preferences::login();
-	name_entry_.assign(new gui::textbox(disp_,width-20,
-		vgettext("$login's game", i18n_symbols)));
+	name_entry_.assign(new gui::textbox(disp_,width-20,vgettext("$login's game", i18n_symbols)));
 	name_entry_->set_location(xpos,ypos);
 	name_entry_->set_dirty();
 
@@ -189,9 +192,13 @@ void multiplayer_game_setup_dialog::set_area(const SDL_Rect& area)
 	//the map selection menu goes near the middle of the dialog, to the right of
 	//the minimap
 	const int map_label_height = font::draw_text(&disp_,disp_.screen_area(),font::SIZE_SMALL,font::GOOD_COLOUR,
-	                                             _("Map to play") + std::string(":"),xpos + minimap_width + border_size,ypos).h;
+	                                             _("Map to play:"),xpos + minimap_width + border_size,ypos).h;
 
-	maps_menu_->set_loc(xpos + minimap_width + border_size,ypos + map_label_height + border_size);
+	maps_menu_->set_max_width(area.x + area.w - (xpos + minimap_width) - 250);
+	maps_menu_->set_max_height(area.y + area.h - (ypos + map_label_height));
+	maps_menu_->set_items(map_options_);
+	maps_menu_->set_location(xpos + minimap_width + border_size,ypos + map_label_height + border_size);
+	maps_menu_->move_selection(preferences::map());
 	maps_menu_->set_dirty();
 
 	SDL_Rect rect;
@@ -252,7 +259,6 @@ void multiplayer_game_setup_dialog::set_area(const SDL_Rect& area)
 
 	//Ally shared view settings
 	vision_combo_->set_location(rect.x,rect.y);
-	vision_combo_->set_dirty();
 
 	rect.y += vision_combo_->height() + border_size;
 
@@ -272,107 +278,124 @@ void multiplayer_game_setup_dialog::set_area(const SDL_Rect& area)
 	
 
 	regenerate_map_->set_location(rect.x,rect.y);
-	regenerate_map_->bg_backup();
-	regenerate_map_->set_dirty();
 
 	rect.y += regenerate_map_->location().h + border_size;
 
 	generator_settings_->set_location(rect.x,rect.y);
-	generator_settings_->bg_backup();
-	generator_settings_->set_dirty();
 
 	//player amount number background
 	SDL_Rect player_num_rect = {xpos+minimap_width/2 - 30,ypos+minimap_width,100,25};
 	playernum_restorer_ = surface_restorer(&disp_.video(),player_num_rect);
 
 	SDL_Rect era_rect = {xpos,player_num_rect.y+player_num_rect.h + border_size,50,20};
-	era_rect = font::draw_text(&disp_,era_rect,font::SIZE_SMALL,font::GOOD_COLOUR,_("Era") + std::string(":"),
+	era_rect = font::draw_text(&disp_,era_rect,font::SIZE_SMALL,font::GOOD_COLOUR,_("Era:"),
 	                           era_rect.x,era_rect.y);
 	
 	era_combo_->set_location(era_rect.x+era_rect.w+border_size,era_rect.y);
-	era_combo_->set_dirty();
 
 	SDL_Rect minimap_rect = {xpos,ypos,minimap_width,minimap_width};
 	minimap_restorer_ = surface_restorer(&disp_.video(),minimap_rect);
 
-	std::cerr << "setup dialog end set_area\n";
+	name_entry_->hide(false);
+	maps_menu_->hide(false);
+	turns_slider_->hide(false);
+	village_gold_slider_->hide(false);
+	xp_modifier_slider_->hide(false);
+	fog_game_->hide(false);
+	shroud_game_->hide(false);
+	observers_game_->hide(false);
+	vision_combo_->hide(false);
+	right_button->hide(false);
+	left_button->hide(false);
+	regenerate_map_->hide(false);
+	generator_settings_->hide(false);
+	era_combo_->hide(false);
+
+	LOG_DP << "setup dialog end set_area\n";
+}
+
+void multiplayer_game_setup_dialog::clear_area()
+{
+	name_entry_->hide();
+	maps_menu_->hide();
+	turns_slider_->hide();
+	village_gold_slider_->hide();
+	xp_modifier_slider_->hide();
+	fog_game_->hide();
+	shroud_game_->hide();
+	observers_game_->hide();
+	vision_combo_->hide();
+	launch_game_->hide();
+	cancel_game_->hide();
+	regenerate_map_->hide();
+	generator_settings_->hide();
+	era_combo_->hide();
 }
 
 lobby::RESULT multiplayer_game_setup_dialog::process()
 {
 	CKey key;
 
-	int mousex, mousey;
-	const int mouse_flags = SDL_GetMouseState(&mousex,&mousey);
-	const bool left_button = mouse_flags&SDL_BUTTON_LMASK;
-
 	name_entry_->process();
-	turns_slider_->process();
-	village_gold_slider_->process();
-	xp_modifier_slider_->process();
-	era_combo_->process(mousex,mousey,left_button);
-	vision_combo_->process(mousex,mousey,left_button);
-	maps_menu_->process(mousex,mousey,left_button,
-	                    key[SDLK_UP],key[SDLK_DOWN],
-	                    key[SDLK_PAGEUP],key[SDLK_PAGEDOWN]);
+	maps_menu_->process();
 
 	if(cancel_game_->pressed() || key[SDLK_ESCAPE]) 
 		return lobby::QUIT;
 
 	if(launch_game_->pressed() || maps_menu_->double_clicked()) {
-		if(name_entry_->text() != "") {
+		if (!name_entry_->text().empty())
 			return lobby::CREATE;
-		} else {
-			gui::show_dialog(disp_,NULL,"","You must enter a name.",gui::OK_ONLY);
-		}
+		else
+			gui::show_dialog(disp_, NULL, "", _("You must enter a name."), gui::OK_ONLY);
 	}
 
-	fog_game_->pressed();
-	fog_game_->draw();
-	shroud_game_->pressed();
-	shroud_game_->draw();
-	observers_game_->pressed();
-	observers_game_->draw();
-
 	events::raise_process_event();
 	events::raise_draw_event();
+	SDL_Rect const &screen_area = disp_.screen_area();
+	display *disp = &disp_;
 
 	//Turns per game
-	const int cur_turns = turns_slider_->value();
-	turns_restorer_.restore();
+	{
+		const int cur_turns = turns_slider_->value();
+		turns_restorer_.restore();
 
-	std::string turns_str;
+		std::stringstream turns_str;
+		turns_str << _("Turns: ");
+		if (cur_turns < 100)
+			turns_str << cur_turns;
+		else
+			turns_str << _("unlimited");
 
-	char buf[100];
-	if(cur_turns < 100) {
-		sprintf(buf,"%d", cur_turns);
-		turns_str = buf;
-	} else {
-		turns_str = _("Unlimited");
+		SDL_Rect const &rect = turns_restorer_.area();
+		font::draw_text(disp, screen_area, font::SIZE_SMALL, font::GOOD_COLOUR,
+		                turns_str.str(), rect.x, rect.y);
 	}
 
-	font::draw_text(&disp_,disp_.screen_area(),font::SIZE_SMALL,font::GOOD_COLOUR,
-	                _("Turns") + std::string(": ") + turns_str,
-					turns_restorer_.area().x,turns_restorer_.area().y);
-
 	//Villages can produce between 1 and 10 gold a turn
-	const int village_gold = village_gold_slider_->value();
-	village_gold_restorer_.restore();
-	sprintf(buf,": %d", village_gold);
-	font::draw_text(&disp_,disp_.screen_area(),font::SIZE_SMALL,font::GOOD_COLOUR,
-	                _("Village Gold") + std::string(buf),
-					village_gold_restorer_.area().x,village_gold_restorer_.area().y);
+	{
+		const int village_gold = village_gold_slider_->value();
+		village_gold_restorer_.restore();
 
+		std::stringstream gold_str;
+		gold_str << _("Village Gold: ") << village_gold;
 
+		SDL_Rect const &rect = village_gold_restorer_.area();
+		font::draw_text(disp, screen_area, font::SIZE_SMALL, font::GOOD_COLOUR,
+		                gold_str.str(), rect.x, rect.y);
+	}
 
-	//experience modifier
-	const int xpmod = xp_modifier_slider_->value();
-	xp_restorer_.restore();
-	sprintf(buf,": %d%%", xpmod);
+	//Experience modifier
+	{
+		const int xpmod = xp_modifier_slider_->value();
+		xp_restorer_.restore();
 
-	const SDL_Rect& xp_rect = xp_restorer_.area();
-	font::draw_text(&disp_,disp_.screen_area(),font::SIZE_SMALL,font::GOOD_COLOUR,
-	                _("Experience Requirements") + std::string(buf),xp_rect.x,xp_rect.y);
+		std::stringstream xp_str;
+		xp_str << _("Experience Requirements: ") << xpmod << '%';
+
+		SDL_Rect const &rect = xp_restorer_.area();
+		font::draw_text(disp, screen_area, font::SIZE_SMALL, font::GOOD_COLOUR,
+		                xp_str.str(), rect.x, rect.y);
+	}
 
 	bool map_changed = map_selection_ != maps_menu_->selection();
 	map_selection_ = maps_menu_->selection();
@@ -380,6 +403,9 @@ lobby::RESULT multiplayer_game_setup_dialog::process()
 	if(map_changed) {
 		generator_.assign(NULL);
 
+		SDL_Rect minimap_rect = minimap_restorer_.area();
+		tooltips::clear_tooltips(minimap_rect);
+
 		const size_t select = size_t(maps_menu_->selection());
 
 		if(select < user_maps_.size()) {
@@ -400,13 +426,18 @@ lobby::RESULT multiplayer_game_setup_dialog::process()
 				level_ = &scenario_data_;
 
 				std::string& map_data = scenario_data_["map_data"];
-				if(map_data == "" && scenario_data_["map"] != "") {
+				if (map_data.empty() && !scenario_data_["map"].empty()) {
 					map_data = read_map(scenario_data_["map"]);
 				}
 
 				//if the map should be randomly generated
-				if(scenario_data_["map_generation"] != "") {
-					generator_.assign(create_map_generator(scenario_data_["map_generation"],scenario_data_.child("generator")));
+				if (!scenario_data_["map_generation"].empty()) {
+					generator_.assign(create_map_generator(scenario_data_["map_generation"],
+					                  scenario_data_.child("generator")));
+				}
+
+				if (!scenario_data_["description"].empty()) {
+					tooltips::add_tooltip(minimap_rect,scenario_data_["description"]);
 				}
 			}
 		} else {
@@ -415,9 +446,10 @@ lobby::RESULT multiplayer_game_setup_dialog::process()
 
 			playernum_restorer_.restore();
 			minimap_restorer_.restore();
-			const SDL_Rect& player_num_rect = playernum_restorer_.area();
-			font::draw_text(&disp_,disp_.screen_area(),font::SIZE_SMALL,font::GOOD_COLOUR,
-				                " Load Map ",player_num_rect.x,player_num_rect.y);
+
+			SDL_Rect const &rect = playernum_restorer_.area();
+			font::draw_text(disp, screen_area, font::SIZE_SMALL, font::GOOD_COLOUR,
+				        _("Players: ") + std::string(1, '?'), rect.x, rect.y);
 		}
 	}
 
@@ -438,7 +470,8 @@ lobby::RESULT multiplayer_game_setup_dialog::process()
 		(*level_)["modify_placing"] = "true";
 	}
 
-	if(map_changed) {
+	//if the map has changed and "Load Map" is not selected
+	if(map_changed && level_ != NULL) {
 		generator_settings_->hide(generator_ == NULL);
 		regenerate_map_->hide(generator_ == NULL);
 
@@ -466,24 +499,23 @@ lobby::RESULT multiplayer_game_setup_dialog::process()
 			level_->remove_child("side",level_->get_children("side").size()-1);
 		}
 
-		SDL_Rect rect = minimap_restorer_.area();
-		const surface mini(image::getMinimap(rect.w,rect.h,map,0));
+		SDL_Rect minimap_rect = minimap_restorer_.area();
+		const surface mini(image::getMinimap(minimap_rect.w, minimap_rect.h, map, 0));
 
 		if(mini != NULL) {
-			SDL_BlitSurface(mini, NULL, disp_.video().getSurface(), &rect);
-			update_rect(rect);
+			SDL_BlitSurface(mini, NULL, disp_.video().getSurface(), &minimap_rect);
+			update_rect(minimap_rect);
 		
 			//Display the number of players
-			SDL_Rect players_rect = playernum_restorer_.area();
-
-			playernum_restorer_.restore();			
-
 			const int nsides = level_->get_children("side").size();
+			playernum_restorer_.restore();
 
 			std::stringstream players;
-			players << _("Players") << ": " << nsides;
-			font::draw_text(&disp_,disp_.screen_area(),font::SIZE_SMALL,font::GOOD_COLOUR,
-			                players.str(),players_rect.x,players_rect.y);
+			players << _("Players: ") << nsides;
+
+			SDL_Rect const &rect = playernum_restorer_.area();
+			font::draw_text(disp, screen_area, font::SIZE_SMALL, font::GOOD_COLOUR,
+			                players.str(), rect.x, rect.y);
 		}
 	}
 
@@ -492,7 +524,7 @@ lobby::RESULT multiplayer_game_setup_dialog::process()
 
 void multiplayer_game_setup_dialog::start_game()
 {
-	std::cerr << "calling start_game()\n";
+	LOG_G << "calling start_game()\n";
 	const network::manager net_manager;
 	const network::server_manager server_man(15000,server_ ? network::server_manager::TRY_CREATE_SERVER : network::server_manager::NO_SERVER);
 
@@ -509,7 +541,7 @@ void multiplayer_game_setup_dialog::start_game()
 
 	std::cerr << "loading connector...\n";
 	//Connector
-	mp_connect connector(disp_, name_entry_->text(), cfg_, units_data_, state_);
+	mp_connect connector(disp_, name_entry_->text(), cfg_, units_data_, state_, false, controller_);
 
 	std::cerr << "done loading connector...\n";
 
@@ -519,6 +551,17 @@ void multiplayer_game_setup_dialog::start_game()
 	const config::child_list& era_list = cfg_.get_children("era");
 
 	const int share = vision_combo_->selected();
+
+	//Save values for next game
+	preferences::set_allow_observers(observers_game_->checked());
+	preferences::set_fog(fog_game_->checked());
+	preferences::set_shroud(shroud_game_->checked());
+	preferences::set_turns(turns_slider_->value());
+	preferences::set_village_gold(village_gold_slider_->value());
+	preferences::set_xp_modifier(xp_modifier_slider_->value());
+	preferences::set_era(era_combo_->selected());
+	preferences::set_map(maps_menu_->selection());
+	
 	const int res = connector.load_map((*era_list[era_combo_->selected()])["id"],
 	                   scenario_data_, turns, village_gold_slider_->value(),
 					   xp_modifier_slider_->value(), fog_game_->checked(),
