@@ -1,4 +1,4 @@
-/* $Id: multiplayer_connect.hpp,v 1.18 2004/09/18 18:52:20 gruikya Exp $ */
+/* $Id: multiplayer_connect.hpp,v 1.24 2005/02/06 10:40:12 isaaccp Exp $ */
 /*
    Copyright (C) 2003 by David White <davidnwhite@optusnet.com.au>
    Part of the Battle for Wesnoth Project http://wesnoth.whitevine.net
@@ -21,6 +21,8 @@
 #include "widgets/combo.hpp"
 #include "widgets/menu.hpp"
 #include "widgets/slider.hpp"
+#include "widgets/scrollpane.hpp"
+#include "widgets/label.hpp"
 
 #include <deque>
 #include <iostream>
@@ -34,7 +36,8 @@ class mp_connect : public lobby::dialog
 public:
 	mp_connect(display& disp, std::string game_name,
 		   const config &cfg, game_data& units_data,
-		   game_state& state, bool join = false);
+		   game_state& state, bool join = false,
+	       const std::string& default_controller="ai");
 	~mp_connect();
 
 	int load_map(const std::string& era, config& scenario, int num_turns, int village_gold, int xpmodifier,
@@ -43,7 +46,9 @@ public:
 	void start_game();
 
 private:
-	void set_area(const SDL_Rect& rect);
+	virtual void set_area(const SDL_Rect& rect);
+	virtual void clear_area();
+
 	lobby::RESULT process();
 	bool manages_network() const { return true; }
 	bool get_network_data(config& cfg);
@@ -56,6 +61,8 @@ private:
 	void update_network();
 	bool is_full();
 
+	size_t combo_index_to_team(size_t index) const;
+
 	display *disp_;
 
 	std::string era_;
@@ -84,24 +91,33 @@ private:
 
 	//std::vector<std::vector<std::string> > player_leaders_;
 	std::vector<leader_list_manager> player_leaders_;
+	std::vector<std::string> possible_faction_ids_;
 
+	std::vector<std::string> team_names_;
+	std::vector<int> team_indices_;
+
+	gui::scrollpane scroll_pane_;
+
+	std::vector<gui::label> player_numbers_;
 	std::vector<gui::combo> combos_type_;
 	std::vector<gui::combo> combos_race_;
 	std::vector<gui::combo> combos_leader_;
 	std::vector<gui::combo> combos_team_;
 	std::vector<gui::combo> combos_color_;
 	std::vector<gui::slider> sliders_gold_;
+	std::vector<gui::label> labels_gold_;
 
 	gui::button ai_;
 	gui::button launch_;
 	gui::button cancel_;
 
-	std::vector<surface_restorer> gold_bg_;
-
-	surface_restorer message_bg_;
+	gui::label waiting_label_;
 	bool message_full_;
 
 	std::deque<config> network_data_;
+
+	const std::string default_controller_;
+	const std::string team_prefix_;
 };
 
 #endif
