@@ -1,4 +1,4 @@
-/* $Id: playlevel.cpp,v 1.155 2004/10/03 18:00:15 gruikya Exp $ */
+/* $Id: playlevel.cpp,v 1.176 2005/02/06 10:40:12 isaaccp Exp $ */
 /*
    Copyright (C) 2003 by David White <davidnwhite@optusnet.com.au>
    Part of the Battle for Wesnoth Project http://wesnoth.whitevine.net
@@ -11,6 +11,8 @@
    See the COPYING file for more details.
 */
 
+#include "global.hpp"
+
 #include "cursor.hpp"
 #include "events.hpp"
 #include "filesystem.hpp"
@@ -37,6 +39,8 @@
 #include <iostream>
 #include <iterator>
 
+#define LOG_NG lg::info(lg::engine)
+
 namespace {
 	int placing_score(const config& side, const gamemap& map, const gamemap::location& pos)
 	{
@@ -93,7 +97,7 @@ namespace {
 				placed.insert(i->side);
 				positions_taken.insert(i->pos);
 				map.set_starting_position(i->side,i->pos);
-				std::cerr << "placing side " << i->side << " at " << i->pos.x << "," << i->pos.y << "\n";
+				LOG_NG << "placing side " << i->side << " at " << i->pos.x << "," << i->pos.y << "\n";
 			}
 		}
 	}
@@ -115,12 +119,15 @@ LEVEL_RESULT play_level(game_data& gameinfo, const config& game_config,
 		game_state& state_of_game,
 		const std::vector<config*>& story)
 {
+	//guarantee the cursor goes back to 'normal' at the end of the level
+	const cursor::setter cursor_setter(cursor::NORMAL);
+
 	const int ticks = SDL_GetTicks();
-	std::cerr << "in play_level()...\n";
+	LOG_NG << "in play_level()...\n";
 
 	//if the entire scenario should be randomly generated
 	if((*level)["scenario_generation"] != "") {
-		std::cerr << "randomly generating scenario...\n";
+		LOG_NG << "randomly generating scenario...\n";
 		const cursor::setter cursor_setter(cursor::WAIT);
 	
 		static config scenario;
@@ -152,7 +159,7 @@ LEVEL_RESULT play_level(game_data& gameinfo, const config& game_config,
 
 	const config& lvl = *level;
 
-	std::cerr << "generated map " << (SDL_GetTicks() - ticks) << "\n";
+	LOG_NG << "generated map " << (SDL_GetTicks() - ticks) << "\n";
 
 	const statistics::scenario_context statistics_context(lvl["name"]);
 
@@ -161,7 +168,7 @@ LEVEL_RESULT play_level(game_data& gameinfo, const config& game_config,
 
 	gamemap map(game_config,map_data);
 
-	std::cerr << "created objects... " << (SDL_GetTicks() - ticks) << "\n";
+	LOG_NG << "created objects... " << (SDL_GetTicks() - ticks) << "\n";
 
 	CKey key;
 	unit_map units;
@@ -180,12 +187,14 @@ LEVEL_RESULT play_level(game_data& gameinfo, const config& game_config,
 	const config::child_list& unit_cfg = level->get_children("side");
 
 	if(lvl["modify_placing"] == "true") {
-		std::cerr << "modifying placing...\n";
+		LOG_NG << "modifying placing...\n";
 		place_sides_in_preferred_locations(map,unit_cfg);
 	}
 
-	std::cerr << "initializing teams..." << unit_cfg.size() << "\n";;
-	std::cerr << (SDL_GetTicks() - ticks) << "\n";
+	LOG_NG << "initializing teams..." << unit_cfg.size() << "\n";;
+	LOG_NG << (SDL_GetTicks() - ticks) << "\n";
+
+	std::set<std::string> seen_save_ids;
 
 	for(config::child_list::const_iterator ui = unit_cfg.begin(); ui != unit_cfg.end(); ++ui) {
 		std::string save_id = (**ui)["save_id"];
@@ -194,6 +203,13 @@ LEVEL_RESULT play_level(game_data& gameinfo, const config& game_config,
 			save_id=(**ui)["description"];
 		}
 
+		//make sure the 'save_id' is unique
+		while(seen_save_ids.count(save_id)) {
+			save_id += "_";
+		}
+
+		seen_save_ids.insert(save_id);
+
 		player_info *player = NULL;
 
 		if((**ui)["controller"] == "human" ||
@@ -201,14 +217,14 @@ LEVEL_RESULT play_level(game_data& gameinfo, const config& game_config,
 		   (**ui)["persistent"] == "1") {
 			player = state_of_game.get_player(save_id);
 
-			if(!player && !save_id.empty()) {
-				player=&state_of_game.players[save_id];
+			if(player == NULL && !save_id.empty()) {
+				player = &state_of_game.players[save_id];
 			}
 		}
 
-		std::cerr << "initializing team...\n";
+		LOG_NG << "initializing team...\n";
 
-		if(first_human_team == -1 && (**ui)["controller"] == "human") {
+		if (first_human_team == -1 && ((**ui)["controller"] == "human" || (**ui)["persistent"] == "1")) {
 			first_human_team = ui - unit_cfg.begin();
 		}
 
@@ -216,14 +232,14 @@ LEVEL_RESULT play_level(game_data& gameinfo, const config& game_config,
 		if(gold.empty())
 			gold = "100";
 
-		std::cerr << "found gold: '" << gold << "'\n";
+		LOG_NG << "found gold: '" << gold << "'\n";
 
 		int ngold = lexical_cast_default<int>(gold);
-		if(player && player->gold >= ngold) {
+		if(player != NULL && player->gold >= ngold) {
 			ngold = player->gold;
 		}
 
-		std::cerr << "set gold to '" << ngold << "'\n";
+		LOG_NG << "set gold to '" << ngold << "'\n";
 
 		teams.push_back(team(**ui,ngold));
 
@@ -233,7 +249,7 @@ LEVEL_RESULT play_level(game_data& gameinfo, const config& game_config,
 
 			//search the recall list for leader units, and if there is
 			//one, use it in place of the config-described unit
-			if(player) {
+			if(player != NULL) {
 				for(std::vector<unit>::iterator it = player->available_units.begin(); it != player->available_units.end(); ++it) {
 					if(it->can_recruit()) {
 						new_unit = *it;
@@ -250,7 +266,8 @@ LEVEL_RESULT play_level(game_data& gameinfo, const config& game_config,
 
 			if(has_loc.empty()) {
 				start_pos = map.starting_position(new_unit.side());
-				std::cerr << "initializing side '" << (**ui)["side"] << "' at " << start_pos.x << "," << start_pos.y << "\n";
+				LOG_NG << "initializing side '" << (**ui)["side"] << "' at "
+				       << start_pos.x << "," << start_pos.y << "\n";
 			}
 
 			if(map.empty()) {
@@ -269,12 +286,12 @@ LEVEL_RESULT play_level(game_data& gameinfo, const config& game_config,
 
 		//if the game state specifies units that can be recruited for the player
 		//then add them
-		if(player && player->can_recruit.empty() == false) {
+		if(player != NULL && player->can_recruit.empty() == false) {
 			std::copy(player->can_recruit.begin(),player->can_recruit.end(),
 					std::inserter(teams.back().recruits(),teams.back().recruits().end()));
 		}
 		
-		if(player) {
+		if(player != NULL) {
 			player->can_recruit = teams.back().recruits();
 		}
 		
@@ -295,7 +312,7 @@ LEVEL_RESULT play_level(game_data& gameinfo, const config& game_config,
 				}
 			} else {
 				units.insert(std::pair<gamemap::location,unit>(loc,new_unit));
-				std::cerr << "inserting unit for side " << new_unit.side() << "\n";
+				LOG_NG << "inserting unit for side " << new_unit.side() << "\n";
 			}
 		}
 
@@ -305,16 +322,15 @@ LEVEL_RESULT play_level(game_data& gameinfo, const config& game_config,
 	// about them are displayed to the user in the help system.
 	for (std::vector<team>::const_iterator help_team_it = teams.begin();
 		 help_team_it != teams.end(); help_team_it++) {
-		std::cout << "Adding help units for team '" << help_team_it->name()
-				  << "'" << std::endl;
+		LOG_NG << "Adding help units for team '" << help_team_it->name() << "'\n";
 		const std::set<std::string> &recruitable = help_team_it->recruits();
 		std::set<std::string> &enc_units = preferences::encountered_units();
-		std::cout << "Adding recruitable units: " << std::endl;
+		LOG_NG << "Adding recruitable units: \n";
 		for (std::set<std::string>::const_iterator it = recruitable.begin();
 			 it != recruitable.end(); it++) {
-			std::cout << *it << std::endl;
+			LOG_NG << *it << std::endl;
 		}
-		std::cout << "Added all recruitable units" << std::endl;
+		LOG_NG << "Added all recruitable units\n";
 		std::copy(recruitable.begin(), recruitable.end(), 
 				  std::inserter(enc_units, enc_units.begin()));
 	}
@@ -344,7 +360,7 @@ LEVEL_RESULT play_level(game_data& gameinfo, const config& game_config,
 			preferences::encountered_terrains().insert(s);
 		}
 	}
-	std::cerr << "initialized teams... " << (SDL_GetTicks() - ticks) << "\n";
+	LOG_NG << "initialized teams... " << (SDL_GetTicks() - ticks) << "\n";
 
 	const config* theme_cfg = NULL;
 	if(lvl["theme"] != "") {
@@ -355,13 +371,13 @@ LEVEL_RESULT play_level(game_data& gameinfo, const config& game_config,
 		theme_cfg = game_config.find_child("theme","name",preferences::theme());
 	}
 
-	std::cerr << "initializing display... " << (SDL_GetTicks() - ticks) << "\n";
+	LOG_NG << "initializing display... " << (SDL_GetTicks() - ticks) << "\n";
 	const config dummy_cfg;
 	display gui(units,video,map,status,teams,theme_cfg != NULL ? *theme_cfg : dummy_cfg, game_config, *level);
 
-	std::cerr << "done initializing display... " << (SDL_GetTicks() - ticks) << "\n";
+	LOG_NG << "done initializing display... " << (SDL_GetTicks() - ticks) << "\n";
 
-	std::cerr << "a... " << (SDL_GetTicks() - ticks) << "\n";
+	LOG_NG << "a... " << (SDL_GetTicks() - ticks) << "\n";
 
 	if(first_human_team != -1) {
 		gui.set_team(first_human_team);
@@ -370,7 +386,7 @@ LEVEL_RESULT play_level(game_data& gameinfo, const config& game_config,
 	const preferences::display_manager prefs_disp_manager(&gui);
 	const tooltips::manager tooltips_manager(gui);
 
-	std::cerr << "b... " << (SDL_GetTicks() - ticks) << "\n";
+	LOG_NG << "b... " << (SDL_GetTicks() - ticks) << "\n";
 
 	//this *needs* to be created before the show_intro and show_map_scene
 	//as that functions use the manager state_of_game 
@@ -387,19 +403,19 @@ LEVEL_RESULT play_level(game_data& gameinfo, const config& game_config,
 	const font::floating_label_context labels_manager;
 	const halo::manager halo_manager(gui);
 	gui.labels().read(*level);
-	std::cerr << "c... " << (SDL_GetTicks() - ticks) << "\n";
+	LOG_NG << "c... " << (SDL_GetTicks() - ticks) << "\n";
 
 	const std::string& music = lvl["music"];
 	if(music != "") {
 		sound::play_music(music);
 	}
 
-	std::cerr << "d... " << (SDL_GetTicks() - ticks) << "\n";
+	LOG_NG << "d... " << (SDL_GetTicks() - ticks) << "\n";
 
 	victory_conditions::set_victory_when_enemies_defeated(
 						lvl["victory_when_enemies_defeated"] != "no");
 
-	std::cerr << "initializing events manager... " << (SDL_GetTicks() - ticks) << "\n";
+	LOG_NG << "initializing events manager... " << (SDL_GetTicks() - ticks) << "\n";
 
 	help::help_manager help_manager(&game_config, &gameinfo, &map);
 
@@ -413,7 +429,7 @@ LEVEL_RESULT play_level(game_data& gameinfo, const config& game_config,
 
 	turn_info::floating_textbox textbox_info;
 
-	std::cerr << "entering try... " << (SDL_GetTicks() - ticks) << "\n";
+	LOG_NG << "entering try... " << (SDL_GetTicks() - ticks) << "\n";
 
 	replay_network_sender replay_sender(recorder);
 
@@ -429,16 +445,17 @@ LEVEL_RESULT play_level(game_data& gameinfo, const config& game_config,
 			game_events::fire("prestart");
 		}
 
-		std::cerr << "scrolling... " << (SDL_GetTicks() - ticks) << "\n";
+		LOG_NG << "scrolling... " << (SDL_GetTicks() - ticks) << "\n";
 		if(first_human_team != -1) {
 			clear_shroud(gui,status,map,gameinfo,units,teams,first_human_team);
-			std::cerr << "b " << (SDL_GetTicks() - ticks) << "\n";
-			gui.scroll_to_tile(map.starting_position(first_human_team+1).x,map.starting_position(first_human_team+1).y,display::WARP);
-			std::cerr << "c " << (SDL_GetTicks() - ticks) << "\n";
+			LOG_NG << "b " << (SDL_GetTicks() - ticks) << "\n";
+			gui.scroll_to_tile(map.starting_position(first_human_team + 1).x,
+			                   map.starting_position(first_human_team + 1).y, display::WARP);
+			LOG_NG << "c " << (SDL_GetTicks() - ticks) << "\n";
 		}
 	
 		gui.scroll_to_tile(map.starting_position(1).x,map.starting_position(1).y,display::WARP);
-		std::cerr << "done scrolling... " << (SDL_GetTicks() - ticks) << "\n";
+		LOG_NG << "done scrolling... " << (SDL_GetTicks() - ticks) << "\n";
 
 		bool replaying = (recorder.at_end() == false);
 	
@@ -447,8 +464,7 @@ LEVEL_RESULT play_level(game_data& gameinfo, const config& game_config,
 			first_player = 0;
 		}
 
-		std::cerr << "starting main loop\n";
-		std::cerr << (SDL_GetTicks() - ticks) << "\n";
+		LOG_NG << "starting main loop\n" << (SDL_GetTicks() - ticks) << "\n";
 
 		std::deque<config> data_backlog;
 		
@@ -458,11 +474,12 @@ LEVEL_RESULT play_level(game_data& gameinfo, const config& game_config,
 			if(first_time) {
 				const hotkey::basic_handler key_events_handler(&gui);
 
-				std::cerr << "first_time..." << (recorder.skipping() ? "skipping" : "no skip") << "\n";
+				LOG_NG << "first_time..." << (recorder.skipping() ? "skipping" : "no skip") << "\n";
 				update_locker lock_display(gui,recorder.skipping());
 				events::raise_draw_event();
 				if(!loading_game) {
 					game_events::fire("start");
+					game_events::set_variable("turn_number", "1");
 				}
 
 				gui.draw();
@@ -478,7 +495,7 @@ LEVEL_RESULT play_level(game_data& gameinfo, const config& game_config,
 			gui.invalidate_game_status();
 			events::raise_draw_event();
 
-			std::cerr << "turn: " << turn++ << "\n";
+			LOG_NG << "turn: " << turn++ << "\n";
 
 			for(std::vector<team>::iterator team_it = teams.begin()+first_player; team_it != teams.end(); ++team_it) {
 				log_scope("player turn");
@@ -496,7 +513,11 @@ LEVEL_RESULT play_level(game_data& gameinfo, const config& game_config,
 				std::stringstream player_number_str;
 				player_number_str << player_number;
 				game_events::set_variable("side_number",player_number_str.str());
-				game_events::fire("side turn");
+
+				//fire side turn event only if real side change occurs not counting changes from void to a side
+				if (team_it != teams.begin()+first_player || !first_time) {
+					game_events::fire("side turn");
+				}
 
 				//we want to work out if units for this player should get healed, and the
 				//player should get income now. healing/income happen if it's not the first
@@ -540,21 +561,20 @@ LEVEL_RESULT play_level(game_data& gameinfo, const config& game_config,
 
 				if(replaying) {
 					const hotkey::basic_handler key_events_handler(&gui);
-					std::cerr << "doing replay " << player_number << "\n";
+					LOG_NG << "doing replay " << player_number << "\n";
 					try {
 						replaying = do_replay(gui,map,gameinfo,units,teams,
 						                      player_number,status,state_of_game);
-					} catch(replay::error& e) {
-						std::cerr << "caught replay::error\n";
+					} catch(replay::error&) {
 						gui::show_dialog(gui,NULL,"",_("The file you have tried to load is corrupt"),gui::OK_ONLY);
 
 						replaying = false;
 					}
-					std::cerr << "result of replay: " << (replaying?"true":"false") << "\n";
+					LOG_NG << "result of replay: " << (replaying?"true":"false") << "\n";
 				}
 
 				if(!replaying && team_it->music().empty() == false) {
-					std::cerr << "playing music: '" << team_it->music() << "'\n";
+					LOG_NG << "playing music: '" << team_it->music() << "'\n";
 					sound::play_music(team_it->music());
 				}
 
@@ -562,7 +582,7 @@ LEVEL_RESULT play_level(game_data& gameinfo, const config& game_config,
 redo_turn:
 
 				if(!replaying && team_it->is_human()) {
-					std::cerr << "is human...\n";
+					LOG_NG << "is human...\n";
 
 					if(first_time && team_it == teams.begin()) {
 						if(lvl["objectives"].empty() == false) {
@@ -570,17 +590,22 @@ redo_turn:
 						}
 					}
 
-					play_turn(gameinfo,state_of_game,status,game_config,
-					          level, video, key, gui, events_manager, map,
-							  teams, player_number, units, textbox_info, replay_sender);
+					try {
+						play_turn(gameinfo,state_of_game,status,game_config,
+						          level, key, gui, map, teams, player_number,
+						          units, textbox_info, replay_sender);
+					} catch(end_turn_exception& end_turn) {
+						if (end_turn.redo == player_number)
+							goto redo_turn;
+					}
 
 					if(game_config::debug)
 						display::clear_debug_highlights();
 
-					std::cerr << "human finished turn...\n";
+					LOG_NG << "human finished turn...\n";
 
 				} else if(!replaying && team_it->is_ai()) {
-					std::cerr << "is ai...\n";
+					LOG_NG << "is ai...\n";
 					gui.recalculate_minimap();
 
 					const cursor::setter cursor_setter(cursor::WAIT);
@@ -602,7 +627,7 @@ redo_turn:
 					gui.draw();
 					SDL_Delay(500);
 				} else if(!replaying && team_it->is_network()) {
-					std::cerr << "is networked...\n";
+					LOG_NG << "is networked...\n";
 
 					turn_info turn_data(gameinfo,state_of_game,status,
 					                    game_config,level,key,gui,
@@ -638,7 +663,7 @@ redo_turn:
 						gui.draw();
 					}
 
-					std::cerr << "finished networked...\n";
+					LOG_NG << "finished networked...\n";
 				}
 
 				for(unit_map::iterator uit = units.begin(); uit != units.end(); ++uit) {
@@ -664,9 +689,9 @@ redo_turn:
 					std::cout << "time over (draw)\n";
 				}
 
-				std::cerr << "firing time over event...\n";
+				LOG_NG << "firing time over event...\n";
 				game_events::fire("time over");
-				std::cerr << "done firing time over event...\n";
+				LOG_NG << "done firing time over event...\n";
 
 				throw end_level_exception(DEFEAT);
 			}
@@ -675,7 +700,7 @@ redo_turn:
 			event_stream << status.turn();
 
 			{
-				std::cerr << "turn event..." << (recorder.skipping() ? "skipping" : "no skip") << "\n";
+				LOG_NG << "turn event..." << (recorder.skipping() ? "skipping" : "no skip") << "\n";
 				update_locker lock_display(gui,recorder.skipping());
 				const std::string turn_num = event_stream.str();
 				game_events::set_variable("turn_number",turn_num);
@@ -685,11 +710,20 @@ redo_turn:
 		} //end for loop
 
 	} catch(end_level_exception& end_level) {
-
-		if((end_level.result == DEFEAT || end_level.result == VICTORY) && is_observer(teams)) {
-			gui::show_dialog(gui,NULL,_("Game Over"),
-			                          _("The game is over."), gui::OK_ONLY);
-			return end_level.result;
+		bool obs = is_observer(teams);
+		if (end_level.result == DEFEAT || end_level.result == VICTORY) {
+			// if we're a player, and the result is victory/defeat, then send a message to notify
+			// the server of the reason for the game ending
+			if (!obs) {
+				config cfg;
+				config& info = cfg.add_child("info");
+				info["type"] = "termination";
+				info["condition"] = "game over";
+				network::send_data(cfg);
+			} else
+				gui::show_dialog(gui, NULL, "",
+				                 _("Victory") + std::string(" / ") + _("Defeat"),
+				                 gui::OK_ONLY);
 		}
 
 		if(end_level.result == QUIT) {
@@ -700,17 +734,26 @@ redo_turn:
 			} catch(end_level_exception&) {
 			}
 
-			gui::show_dialog(gui,NULL,
-			                 _("Defeat"),
-			                 _("You have been defeated!"),
-			                 gui::OK_ONLY);
+			if (!obs)
+				gui::show_dialog(gui, NULL,
+				                 _("Defeat"),
+				                 _("You have been defeated!"),
+				                 gui::OK_ONLY);
 			return DEFEAT;
-		} else if(end_level.result == VICTORY || end_level.result == LEVEL_CONTINUE || end_level.result == LEVEL_CONTINUE_NO_SAVE) {
+		} else if (end_level.result == VICTORY || end_level.result == LEVEL_CONTINUE ||
+		           end_level.result == LEVEL_CONTINUE_NO_SAVE) {
 			try {
 				game_events::fire("victory");
 			} catch(end_level_exception&) {
 			}
 
+			if(state_of_game.scenario == (*level)["id"]) {
+				state_of_game.scenario = (*level)["next_scenario"];
+			}
+
+			const bool has_next_scenario = !state_of_game.scenario.empty() &&
+			                               state_of_game.scenario != "null";
+
 			//add all the units that survived the scenario
 			for(std::map<gamemap::location,unit>::iterator un = units.begin(); un != units.end(); ++un) {
 				player_info *player=state_of_game.get_player(teams[un->second.side()-1].save_id());
@@ -723,7 +766,7 @@ redo_turn:
 			}
 
 			//'continue' is like a victory, except it doesn't announce victory,
-			//and the player returns 100% of gold.
+			//and the player retains 100% of gold.
 			if(end_level.result == LEVEL_CONTINUE || end_level.result == LEVEL_CONTINUE_NO_SAVE) {
 				for(std::vector<team>::iterator i=teams.begin(); i!=teams.end(); ++i) {
 					player_info *player=state_of_game.get_player(i->save_id());
@@ -739,23 +782,28 @@ redo_turn:
 			std::stringstream report;
 
 			for(std::vector<team>::iterator i=teams.begin(); i!=teams.end(); ++i) {
+				if (!i->is_persistent())
+					continue;
+
 				player_info *player=state_of_game.get_player(i->save_id());
 
 				const int remaining_gold = i->gold();
-				const int finishing_bonus_per_turn = map.villages().size()*game_config::village_income + game_config::base_income;
+				const int finishing_bonus_per_turn =
+				             map.villages().size() * game_config::village_income +
+				             game_config::base_income;
 				const int turns_left = maximum<int>(0,status.number_of_turns() - status.turn());
 				const int finishing_bonus = end_level.gold_bonus ?
 				             (finishing_bonus_per_turn * turns_left) : 0;
 
 				if(player) {
-					player->gold = ((remaining_gold+finishing_bonus)*80)/100;
+					player->gold = ((remaining_gold + finishing_bonus) * 80) / 100;
 
 					if(state_of_game.players.size()>1) {
 						if(i!=teams.begin()) {
 							report << "\n";
 						}
 
-						report << i->save_id() << ": " << "\n";
+						report << font::BOLD_TEXT << i->save_id() << "\n";
 					}
 
 					report << _("Remaining gold") << ": "
@@ -773,21 +821,22 @@ redo_turn:
 					}
 
 					// xgettext:no-c-format
-					report << "\n" << _("80% of gold is retained for the next scenario") << "\n" << _("Retained Gold") << ": " << player->gold;
+					report << "\n" << _("80% of gold is retained for the next scenario") << "\n"
+					       << _("Retained Gold") << ": " << player->gold;
 				}
 			}
 
-			gui::show_dialog(gui,NULL,_("Victory"),
-			                 _("You have emerged victorious!"),gui::OK_ONLY);
+			if (!obs)
+				gui::show_dialog(gui, NULL, _("Victory"),
+				                 _("You have emerged victorious!"), gui::OK_ONLY);
+
+			if (state_of_game.players.size() > 0 && has_next_scenario)
+				gui::show_dialog(gui, NULL, _("Scenario Report"), report.str(), gui::OK_ONLY);
 
-			if(state_of_game.players.size()>0) {
-				gui::show_dialog(gui,NULL,"",report.str(),gui::OK_ONLY);
-			}
 			return VICTORY;
 		}
 	} //end catch
-	catch(replay::error& e) {
-		std::cerr << "caught replay::error\n";
+	catch(replay::error&) {
 		gui::show_dialog(gui,NULL,"",_("The file you have tried to load is corrupt"),
 		                 gui::OK_ONLY);
 		return QUIT;
