@@ -1,4 +1,4 @@
-/* $Id: playturn.hpp,v 1.52 2004/09/11 02:55:46 Sirp Exp $ */
+/* $Id: playturn.hpp,v 1.61 2005/02/06 10:40:12 isaaccp Exp $ */
 /*
    Copyright (C) 2003 by David White <davidnwhite@optusnet.com.au>
    Part of the Battle for Wesnoth Project http://wesnoth.whitevine.net
@@ -53,7 +53,7 @@ private:
 
 struct command_disabler
 {
-	command_disabler(display* disp);
+	command_disabler();
 	~command_disabler();
 };
 
@@ -179,6 +179,7 @@ private:
 
 	void handle_event(const SDL_Event& event);
 	void mouse_motion(const SDL_MouseMotionEvent& event);
+	void mouse_motion(int x, int y);
 	void mouse_press(const SDL_MouseButtonEvent& event);
 
 	void left_click(const SDL_MouseButtonEvent& event);
@@ -186,6 +187,14 @@ private:
 
 	void show_attack_options(unit_map::const_iterator u);
 
+	//function which, given the location of a potential enemy to attack, will return the location
+	//that the currently selected unit would move to and attack it from this turn. Returns an
+	//invalid location if not possible.
+	gamemap::location current_unit_attacks_from(const gamemap::location& loc, const gamemap::location* preferred) const;
+
+	bool attack_enemy(unit_map::iterator attacker, unit_map::iterator defender);
+	bool move_unit_along_current_route(bool check_shroud=true);
+
 	bool clear_shroud();
 	void clear_undo_stack();
 	
@@ -193,7 +202,7 @@ private:
 	
 	bool enemies_visible() const;
 
-	void change_side_controller(const std::string& side, const std::string& player);
+	void change_side_controller(const std::string& side, const std::string& player, bool orphan_side=false);
 
 	game_data& gameinfo_;
 	game_state& state_of_game_;
@@ -219,6 +228,7 @@ private:
 	paths::route current_route_;
 	bool enemy_paths_;
 	gamemap::location last_hex_;
+	gamemap::location::DIRECTION last_nearest_;
 	gamemap::location selected_hex_;
 	undo_list undo_stack_;
 	undo_list redo_stack_;
@@ -241,15 +251,17 @@ private:
 	void create_textbox(floating_textbox::MODE mode, const std::string& label, const std::string& check_label="", bool checked=false);
 	void close_textbox();
 	void enter_textbox();
+	void tab_textbox();
 
 	replay_network_sender& replay_sender_;
 };
 
 void play_turn(game_data& gameinfo, game_state& state_of_game,
                gamestatus& status, const config& terrain_config, config* level,
-			   CVideo& video, CKey& key, display& gui,
-               game_events::manager& events_manager, gamemap& map,
-			   std::vector<team>& teams, int team_num, unit_map& units,
-			   turn_info::floating_textbox& textbox, replay_network_sender& replay_sender);
+               CKey& key, display& gui, gamemap& map,
+               std::vector<team>& teams, int team_num,
+               std::map<gamemap::location,unit>& units,
+               turn_info::floating_textbox& textbox,
+               replay_network_sender& network_sender);
 
 #endif
