@@ -1,4 +1,4 @@
-/* $Id: preferences.cpp,v 1.114 2004/10/02 15:53:58 Sirp Exp $ */
+/* $Id: preferences.cpp,v 1.131 2005/02/06 10:40:12 isaaccp Exp $ */
 /*
    Copyright (C) 2003 by David White <davidnwhite@optusnet.com.au>
    Part of the Battle for Wesnoth Project http://wesnoth.whitevine.net
@@ -11,6 +11,8 @@
    See the COPYING file for more details.
 */
 
+#include "global.hpp"
+
 #define GETTEXT_DOMAIN "wesnoth-lib"
 
 #include "cursor.hpp"
@@ -25,14 +27,15 @@
 #include "sound.hpp"
 #include "util.hpp"
 #include "widgets/button.hpp"
-#include "widgets/slider.hpp"
+#include "widgets/label.hpp"
 #include "widgets/menu.hpp"
+#include "widgets/slider.hpp"
 #include "wesconfig.h"
 
 #include <cstdlib>
 #include <iostream>
-#include <sstream>
 #include <iterator>
+#include <sstream>
 
 namespace {
 
@@ -49,6 +52,8 @@ bool haloes = true;
 
 bool unit_genders = true;
 
+bool fps = false;
+
 std::set<std::string> encountered_units_set;
 std::set<std::string> encountered_terrains_set;
 
@@ -64,7 +69,6 @@ manager::manager()
 
 	set_colour_cursors(prefs["colour_cursors"] == "yes");
 	set_show_haloes(prefs["show_haloes"] != "no");
-	set_show_unit_genders(prefs["unit_genders"] != "no");
 
 	std::vector<std::string> v;
 	v = config::split(prefs["encountered_units"]);
@@ -98,7 +102,7 @@ display_manager::display_manager(display* d)
 {
 	disp = d;
 
-	hotkey::add_hotkeys(prefs,true);
+	hotkey::load_hotkeys(prefs);
 
 	set_grid(grid());
 	set_turbo(turbo());
@@ -158,12 +162,12 @@ std::pair<int,int> resolution()
 	const string_map::const_iterator y = prefs.values.find('y' + postfix);
 	if(x != prefs.values.end() && y != prefs.values.end() &&
 	   x->second.empty() == false && y->second.empty() == false) {
-		std::pair<int,int> res (maximum(atoi(x->second.c_str()),800),
-		                        maximum(atoi(y->second.c_str()),600));
+		std::pair<int,int> res (maximum(atoi(x->second.c_str()),min_allowed_width),
+		                        maximum(atoi(y->second.c_str()),min_allowed_height));
 
 		//make sure resolutions are always divisible by 4
-		res.first &= ~3;
-		res.second &= ~3;
+		//res.first &= ~3;
+		//res.second &= ~3;
 		return res;
 	} else {
 		return std::pair<int,int>(1024,768);
@@ -174,9 +178,14 @@ void set_resolution(const std::pair<int,int>& resolution)
 {
 	std::pair<int,int> res = resolution;
 
+	// - Ayin: disabled the following code. Why would one want to enforce that? 
+	// Some 16:9, or laptop screens, may have resolutions which do not
+	// comply to this rule (see bug 10630). I'm commenting this until it
+	// proves absolutely necessary.
+	//
 	//make sure resolutions are always divisible by 4
-	res.first &= ~3;
-	res.second &= ~3;
+	//res.first &= ~3;
+	//res.second &= ~3;
 
 	bool write_resolution = true;
 
@@ -219,12 +228,12 @@ void set_turbo(bool ison)
 	}
 }
 
-const std::string& locale()
+const std::string& language()
 {
 	return prefs["locale"];
 }
 
-void set_locale(const std::string& s)
+void set_language(const std::string& s)
 {
 	prefs["locale"] = s;
 }
@@ -449,6 +458,140 @@ bool show_combat()
 	return prefs["show_combat"] != "no";
 }
 
+bool allow_observers()
+{	
+	return prefs["allow_observers"] != "no";
+}
+
+void set_allow_observers(bool value)
+{	
+	prefs["allow_observers"] = value ? "yes" : "no";
+}
+
+bool fog()
+{	
+	return prefs["mp_fog"] != "no";
+}
+
+void set_fog(bool value)
+{	
+	prefs["mp_fog"] = value ? "yes" : "no";
+}
+
+bool shroud()
+{	
+	return prefs["mp_shroud"] != "no";
+}
+
+void set_shroud(bool value)
+{	
+	prefs["mp_shroud"] = value ? "yes" : "no";
+}
+
+int turns()
+{	
+	static const int default_value = 50;
+	int value = 0;
+	const string_map::const_iterator i = prefs.values.find("mp_turns");
+	if(i != prefs.values.end() && i->second.empty() == false) {
+		value = atoi(i->second.c_str());
+	}
+
+	if(value < 20 || value > 100) {
+		value = default_value;
+	}
+
+	return value;
+}
+
+void set_turns(int value)
+{	
+	std::stringstream stream;
+	stream << value;
+	prefs["mp_turns"] = stream.str();
+}
+
+int village_gold()
+{	
+	static const int default_value = 1;
+	int value = 0;
+	const string_map::const_iterator i = prefs.values.find("mp_village_gold");
+	if(i != prefs.values.end() && i->second.empty() == false) {
+		value = atoi(i->second.c_str());
+	}
+
+	if(value < 1 || value > 5) {
+		value = default_value;
+	}
+
+	return value;
+}
+
+void set_village_gold(int value)
+{	
+	std::stringstream stream;
+	stream << value;
+	prefs["mp_village_gold"] = stream.str();
+}
+
+int xp_modifier()
+{	
+	static const int default_value = 100;
+	int value = 0;
+	const string_map::const_iterator i = prefs.values.find("mp_xp_modifier");
+	if(i != prefs.values.end() && i->second.empty() == false) {
+		value = atoi(i->second.c_str());
+	}
+
+	if(value < 30 || value > 200) {
+		value = default_value;
+	}
+
+	return value;
+}
+
+void set_xp_modifier(int value)
+{	
+	std::stringstream stream;
+	stream << value;
+	prefs["mp_xp_modifier"] = stream.str();
+}
+
+int era()
+{	
+	int value = 0;
+	const string_map::const_iterator i = prefs.values.find("mp_era");
+	if(i != prefs.values.end() && i->second.empty() == false) {
+		value = atoi(i->second.c_str());
+	}
+
+	return value;
+}
+
+void set_era(int value)
+{	
+	std::stringstream stream;
+	stream << value;
+	prefs["mp_era"] = stream.str();
+}
+
+int map()
+{	
+	int value = 0;
+	const string_map::const_iterator i = prefs.values.find("mp_map");
+	if(i != prefs.values.end() && i->second.empty() == false) {
+		value = atoi(i->second.c_str());
+	}
+	return value;
+}
+
+void set_map(int value)
+{	
+	std::stringstream stream;
+	stream << value;
+	prefs["mp_map"] = stream.str();
+}
+
 bool show_ai_moves()
 {	
 	return prefs["show_ai_moves"] != "no";
@@ -466,7 +609,7 @@ void set_show_side_colours(bool value)
 
 bool show_side_colours()
 {
-	return prefs["show_side_colours"] == "yes";
+	return prefs["show_side_colours"] != "no";
 }
 
 void set_ask_delete_saves(bool value)
@@ -563,15 +706,14 @@ void set_show_haloes(bool value)
 	prefs["show_haloes"] = value ? "yes" : "no";
 }
 
-bool show_unit_genders()
+bool show_fps()
 {
-	return unit_genders;
+	return fps;
 }
 
-void set_show_unit_genders(bool value)
+void set_show_fps(bool value)
 {
-	prefs["unit_genders"] = value ? "yes" : "no";
-	unit_genders = value;
+	fps = value;
 }
 
 std::set<std::string> &encountered_units() {
@@ -610,9 +752,6 @@ void set_cache_saves(CACHE_SAVES_METHOD method)
 
 namespace {
 
-const SDL_Rect empty_rect = {0,0,0,0};
-const SDL_Rect preferences_dialog_area = {-400,-400,400,400};
-
 class preferences_dialog : public gui::preview_pane
 {
 public:
@@ -630,48 +769,50 @@ public:
 
 private:
 
-	void draw();
-	void process();
+	void process_event();
 	bool left_side() const { return false; }
 	void set_selection(int index);
+	void update_location(SDL_Rect const &rect);
 
 	gui::slider music_slider_, sound_slider_, scroll_slider_, gamma_slider_;
 	gui::button fullscreen_button_, turbo_button_, show_ai_moves_button_,
 	            show_grid_button_, show_floating_labels_button_, turn_dialog_button_,
-				turn_bell_button_, show_team_colours_button_, show_colour_cursors_button_,
-				show_haloing_button_, video_mode_button_, hotkeys_button_, gamma_button_;
-	std::string music_label_, sound_label_, scroll_label_, gamma_label_;
-	size_t slider_label_width_;
+	            turn_bell_button_, show_team_colours_button_, show_colour_cursors_button_,
+	            show_haloing_button_, video_mode_button_, hotkeys_button_, gamma_button_;
+	gui::label music_label_, sound_label_, scroll_label_, gamma_label_;
+	unsigned slider_label_width_;
 
 	enum TAB { GENERAL_TAB, DISPLAY_TAB, SOUND_TAB };
 	TAB tab_;
 };
 
-preferences_dialog::preferences_dialog(display& disp) : gui::preview_pane(disp),
-music_slider_(disp,empty_rect), sound_slider_(disp,empty_rect),
-scroll_slider_(disp,empty_rect), gamma_slider_(disp,empty_rect),
-fullscreen_button_(disp,_("Full Screen"),gui::button::TYPE_CHECK),
-turbo_button_(disp,_("Accelerated Speed"),gui::button::TYPE_CHECK),
-show_ai_moves_button_(disp,_("Skip AI Moves"),gui::button::TYPE_CHECK),
-show_grid_button_(disp,_("Show Grid"),gui::button::TYPE_CHECK),
-show_floating_labels_button_(disp,_("Show Floating Labels"),gui::button::TYPE_CHECK),
-turn_dialog_button_(disp,_("Turn Dialog"),gui::button::TYPE_CHECK),
-turn_bell_button_(disp,_("Turn Bell"),gui::button::TYPE_CHECK),
-show_team_colours_button_(disp,_("Show Team Colors"),gui::button::TYPE_CHECK),
-show_colour_cursors_button_(disp,_("Show Color Cursors"),gui::button::TYPE_CHECK),
-show_haloing_button_(disp,_("Show Haloing Effects"),gui::button::TYPE_CHECK),
-video_mode_button_(disp,_("Video Mode")),
-hotkeys_button_(disp,_("Hotkeys")),
-gamma_button_(disp,_("Adjust Gamma"),gui::button::TYPE_CHECK),
-music_label_(_("Music Volume:")), sound_label_(_("SFX Volume:")),
-scroll_label_(_("Scroll Speed:")), gamma_label_(_("Gamma:")),
-slider_label_width_(0), tab_(GENERAL_TAB)
+preferences_dialog::preferences_dialog(display& disp)
+	: gui::preview_pane(disp),
+	  music_slider_(disp), sound_slider_(disp),
+	  scroll_slider_(disp), gamma_slider_(disp),
+	  fullscreen_button_(disp, _("Full Screen"), gui::button::TYPE_CHECK),
+	  turbo_button_(disp, _("Accelerated Speed"), gui::button::TYPE_CHECK),
+	  show_ai_moves_button_(disp, _("Skip AI Moves"), gui::button::TYPE_CHECK),
+	  show_grid_button_(disp, _("Show Grid"), gui::button::TYPE_CHECK),
+	  show_floating_labels_button_(disp, _("Show Floating Labels"), gui::button::TYPE_CHECK),
+	  turn_dialog_button_(disp, _("Turn Dialog"), gui::button::TYPE_CHECK),
+	  turn_bell_button_(disp, _("Turn Bell"), gui::button::TYPE_CHECK),
+	  show_team_colours_button_(disp, _("Show Team Colors"), gui::button::TYPE_CHECK),
+	  show_colour_cursors_button_(disp, _("Show Color Cursors"), gui::button::TYPE_CHECK),
+	  show_haloing_button_(disp, _("Show Haloing Effects"), gui::button::TYPE_CHECK),
+	  video_mode_button_(disp, _("Video Mode")),
+	  hotkeys_button_(disp, _("Hotkeys")),
+	  gamma_button_(disp, _("Adjust Gamma"), gui::button::TYPE_CHECK),
+	  music_label_(disp, _("Music Volume:")), sound_label_(disp, _("SFX Volume:")),
+	  scroll_label_(disp, _("Scroll Speed:")), gamma_label_(disp, _("Gamma:")),
+	  slider_label_width_(0), tab_(GENERAL_TAB)
 {
-	set_location(preferences_dialog_area);
+	set_measurements(400, 400);
 
-	slider_label_width_ = maximum<size_t>(font::text_area(music_label_,font::SIZE_NORMAL).w,
-	                      maximum<size_t>(font::text_area(sound_label_,font::SIZE_NORMAL).w,
-						  maximum<size_t>(font::text_area(scroll_label_,font::SIZE_NORMAL).w,font::text_area(gamma_label_,font::SIZE_NORMAL).w)));
+	slider_label_width_ = maximum<unsigned>(music_label_.width(),
+	                      maximum<unsigned>(sound_label_.width(),
+	                      maximum<unsigned>(scroll_label_.width(),
+	                                        gamma_label_.width())));
 
 	sound_slider_.set_min(1);
 	sound_slider_.set_max(100);
@@ -731,189 +872,127 @@ slider_label_width_(0), tab_(GENERAL_TAB)
 	hotkeys_button_.set_help_string(_("View and configure keyboard shortcuts"));
 }
 
-void preferences_dialog::process()
+void preferences_dialog::update_location(SDL_Rect const &rect)
 {
-	if(turbo_button_.pressed()) {
+	bg_register(rect);
+	const int border = 10;
+
+	// General tab
+	int ypos = rect.y;
+	scroll_label_.set_location(rect.x, ypos);
+	SDL_Rect scroll_rect = { rect.x + slider_label_width_, ypos,
+	                         rect.w - slider_label_width_ - border, 0 };
+	scroll_slider_.set_location(scroll_rect);
+	ypos += 50; turbo_button_.set_location(rect.x, ypos);
+	ypos += 50; show_ai_moves_button_.set_location(rect.x, ypos);
+	ypos += 50; turn_dialog_button_.set_location(rect.x, ypos);
+	ypos += 50; turn_bell_button_.set_location(rect.x, ypos);
+	ypos += 50; show_team_colours_button_.set_location(rect.x, ypos);
+	ypos += 50; show_grid_button_.set_location(rect.x, ypos);
+	ypos += 50; hotkeys_button_.set_location(rect.x, ypos);
+
+	// Display tab
+	ypos = rect.y;
+	gamma_button_.set_location(rect.x, ypos);
+	ypos += 50;
+	gamma_label_.set_location(rect.x, ypos);
+	SDL_Rect gamma_rect = { rect.x + slider_label_width_, ypos,
+	                        rect.w - slider_label_width_ - border, 0 };
+	gamma_slider_.set_location(gamma_rect);
+	ypos += 50; show_floating_labels_button_.set_location(rect.x, ypos);
+	ypos += 50; show_colour_cursors_button_.set_location(rect.x, ypos);
+	ypos += 50; show_haloing_button_.set_location(rect.x, ypos);
+	ypos += 50; fullscreen_button_.set_location(rect.x, ypos);
+	ypos += 50; video_mode_button_.set_location(rect.x, ypos);
+
+	// Sound tab
+	ypos = rect.y;
+	music_label_.set_location(rect.x, ypos);
+	SDL_Rect music_rect = { rect.x + slider_label_width_, ypos,
+	                        rect.w - slider_label_width_ - border, 0 };
+	music_slider_.set_location(music_rect);
+	ypos += 50;
+	sound_label_.set_location(rect.x, ypos);
+	SDL_Rect sound_rect = { rect.x + slider_label_width_, ypos,
+				rect.w - slider_label_width_ - border, 0 };
+	sound_slider_.set_location(sound_rect);
+
+	set_selection(tab_);
+}
+
+void preferences_dialog::process_event()
+{
+	if (turbo_button_.pressed())
 		set_turbo(turbo_button_.checked());
-	}
-
-	if(show_ai_moves_button_.pressed()) {
+	if (show_ai_moves_button_.pressed())
 		set_show_ai_moves(!show_ai_moves_button_.checked());
-	}
-
-	if(show_grid_button_.pressed()) {
+	if (show_grid_button_.pressed())
 		set_grid(show_grid_button_.checked());
-	}
-
-	if(show_floating_labels_button_.pressed()) {
+	if (show_floating_labels_button_.pressed())
 		set_show_floating_labels(show_floating_labels_button_.checked());
-	}
-
-	if(video_mode_button_.pressed()) {
+	if (video_mode_button_.pressed())
 		throw video_mode_change_exception(video_mode_change_exception::CHANGE_RESOLUTION);
-	}
-
-	if(fullscreen_button_.pressed()) {
-		throw video_mode_change_exception(fullscreen_button_.checked() ? video_mode_change_exception::MAKE_FULLSCREEN
-		                                                               : video_mode_change_exception::MAKE_WINDOWED);
-	}
-
-	if(turn_bell_button_.pressed()) {
+	if (fullscreen_button_.pressed())
+		throw video_mode_change_exception(fullscreen_button_.checked()
+		                                  ? video_mode_change_exception::MAKE_FULLSCREEN
+		                                  : video_mode_change_exception::MAKE_WINDOWED);
+	if (turn_bell_button_.pressed())
 		set_turn_bell(turn_bell_button_.checked());
-	}
-
-	if(turn_dialog_button_.pressed()) {
+	if (turn_dialog_button_.pressed())
 		set_turn_dialog(turn_dialog_button_.checked());
-	}
-
-	if(show_team_colours_button_.pressed()) {
+	if (show_team_colours_button_.pressed())
 		set_show_side_colours(show_team_colours_button_.checked());
-	}
-
-	if(hotkeys_button_.pressed()) {
+	if (hotkeys_button_.pressed())
 		show_hotkeys_dialog(disp());
-	}
-
-	if(show_colour_cursors_button_.pressed()) {
+	if (show_colour_cursors_button_.pressed())
 		set_colour_cursors(show_colour_cursors_button_.checked());
-	}
-
-	if(show_haloing_button_.pressed()) {
+	if (show_haloing_button_.pressed())
 		set_show_haloes(show_haloing_button_.checked());
-	}
-
-	if(gamma_button_.pressed()) {
+	if (gamma_button_.pressed()) {
 		set_adjust_gamma(gamma_button_.checked());
-		set_selection(int(tab_));
+		bool hide_gamma = !adjust_gamma();
+		gamma_slider_.hide(hide_gamma);
+		gamma_label_.hide(hide_gamma);
 	}
-
 	set_sound_volume(sound_slider_.value());
 	set_music_volume(music_slider_.value());
 	set_scroll_speed(scroll_slider_.value());
 	set_gamma(gamma_slider_.value());
 }
 
-void preferences_dialog::draw()
-{
-	if(!dirty()) {
-		return;
-	}
-
-	bg_restore();
-
-	music_slider_.set_dirty();
-	sound_slider_.set_dirty();
-	scroll_slider_.set_dirty();
-	gamma_slider_.set_dirty();
-	fullscreen_button_.set_dirty();
-	turbo_button_.set_dirty();
-	show_ai_moves_button_.set_dirty();
-	show_grid_button_.set_dirty();
-	show_floating_labels_button_.set_dirty();
-	turn_dialog_button_.set_dirty();
-	turn_bell_button_.set_dirty();
-	show_team_colours_button_.set_dirty();
-	show_colour_cursors_button_.set_dirty();
-	show_haloing_button_.set_dirty();
-	video_mode_button_.set_dirty();
-	hotkeys_button_.set_dirty();
-	gamma_button_.set_dirty();
-
-	const int border = 10;
-
-	int ypos = location().y;
-	if(tab_ == GENERAL_TAB) {
-		font::draw_text(&disp(),location(),font::SIZE_NORMAL,font::NORMAL_COLOUR,scroll_label_,location().x,ypos);
-		const SDL_Rect scroll_rect = {location().x + slider_label_width_,ypos,location().w - slider_label_width_ - border,scroll_slider_.location().h};
-		scroll_slider_.set_location(scroll_rect);
-
-		ypos += 50;
-		turbo_button_.set_location(location().x,ypos);
-
-		ypos += 50;
-		show_ai_moves_button_.set_location(location().x,ypos);
-
-		ypos += 50;
-		turn_dialog_button_.set_location(location().x,ypos);
-
-		ypos += 50;
-		turn_bell_button_.set_location(location().x,ypos);
-
-		ypos += 50;
-		show_team_colours_button_.set_location(location().x,ypos);
-
-		ypos += 50;
-		show_grid_button_.set_location(location().x,ypos);
-
-		ypos += 50;
-		hotkeys_button_.set_location(location().x,ypos);
-
-	} else if(tab_ == DISPLAY_TAB) {
-		gamma_button_.set_location(location().x,ypos);
-
-		ypos += 50;
-
-		if(adjust_gamma()) {
-			font::draw_text(&disp(),location(),font::SIZE_NORMAL,font::NORMAL_COLOUR,gamma_label_,location().x,ypos);
-		}
-
-		const SDL_Rect gamma_rect = {location().x + slider_label_width_,ypos,location().w - slider_label_width_ - border,gamma_slider_.location().h};
-		gamma_slider_.set_location(gamma_rect);
-
-		ypos += 50;
-		show_floating_labels_button_.set_location(location().x,ypos);
-
-		ypos += 50;
-		show_colour_cursors_button_.set_location(location().x,ypos);
-
-		ypos += 50;
-		show_haloing_button_.set_location(location().x,ypos);
-
-		ypos += 50;
-		fullscreen_button_.set_location(location().x,ypos);
-
-		ypos += 50;
-		video_mode_button_.set_location(location().x,ypos);
-
-	} else if(tab_ == SOUND_TAB) {
-		font::draw_text(&disp(),location(),font::SIZE_NORMAL,font::NORMAL_COLOUR,music_label_,location().x,ypos);
-		const SDL_Rect music_rect = {location().x + slider_label_width_,ypos,location().w - slider_label_width_ - border,music_slider_.location().h};
-		music_slider_.set_location(music_rect);
-
-		ypos += 50;
-
-		font::draw_text(&disp(),location(),font::SIZE_NORMAL,font::NORMAL_COLOUR,sound_label_,location().x,ypos);
-		const SDL_Rect sound_rect = {location().x + slider_label_width_,ypos,location().w - slider_label_width_ - border,sound_slider_.location().h};
-		sound_slider_.set_location(sound_rect);
-	}
-
-	set_dirty(false);
-}
-
 void preferences_dialog::set_selection(int index)
 {
 	tab_ = TAB(index);
 	set_dirty();
+	bg_restore();
 
-	scroll_slider_.hide(tab_ != GENERAL_TAB);
-	gamma_slider_.hide(tab_ != DISPLAY_TAB || !adjust_gamma());
-	music_slider_.hide(tab_ != SOUND_TAB);
-	sound_slider_.hide(tab_ != SOUND_TAB);
-	turbo_button_.hide(tab_ != GENERAL_TAB);
-	show_ai_moves_button_.hide(tab_ != GENERAL_TAB);
-	turn_dialog_button_.hide(tab_ != GENERAL_TAB);
-	turn_bell_button_.hide(tab_ != GENERAL_TAB);
-	hotkeys_button_.hide(tab_ != GENERAL_TAB);
-	show_team_colours_button_.hide(tab_ != GENERAL_TAB);
-	show_grid_button_.hide(tab_ != GENERAL_TAB);
+	bool hide_general = tab_ != GENERAL_TAB;
+	scroll_label_.hide(hide_general);
+	scroll_slider_.hide(hide_general);
+	turbo_button_.hide(hide_general);
+	show_ai_moves_button_.hide(hide_general);
+	turn_dialog_button_.hide(hide_general);
+	turn_bell_button_.hide(hide_general);
+	hotkeys_button_.hide(hide_general);
+	show_team_colours_button_.hide(hide_general);
+	show_grid_button_.hide(hide_general);
 
-	gamma_button_.hide(tab_ != DISPLAY_TAB);
-	show_floating_labels_button_.hide(tab_ != DISPLAY_TAB);
-	show_colour_cursors_button_.hide(tab_ != DISPLAY_TAB);
-	show_haloing_button_.hide(tab_ != DISPLAY_TAB);
-	fullscreen_button_.hide(tab_ != DISPLAY_TAB);
-	video_mode_button_.hide(tab_ != DISPLAY_TAB);
-}                                          
+	bool hide_display = tab_ != DISPLAY_TAB, hide_gamma = hide_display || !adjust_gamma();
+	gamma_label_.hide(hide_gamma);
+	gamma_slider_.hide(hide_gamma);
+	gamma_button_.hide(hide_display);
+	show_floating_labels_button_.hide(hide_display);
+	show_colour_cursors_button_.hide(hide_display);
+	show_haloing_button_.hide(hide_display);
+	fullscreen_button_.hide(hide_display);
+	video_mode_button_.hide(hide_display);
+
+	bool hide_sound = tab_ != SOUND_TAB;
+	music_label_.hide(hide_sound);
+	music_slider_.hide(hide_sound);
+	sound_label_.hide(hide_sound);
+	sound_slider_.hide(hide_sound);
+}
 
 }
 
@@ -921,9 +1000,11 @@ void show_preferences_dialog(display& disp)
 {
 	std::vector<std::string> items;
 
-	items.push_back(std::string("&icons/icon-general.png,") + dsgettext(GETTEXT_DOMAIN,"Prefs section^General"));
-	items.push_back(std::string("&icons/icon-display.png,") + dsgettext(GETTEXT_DOMAIN,"Prefs section^Display"));
-	items.push_back(std::string("&icons/icon-music.png,") + dsgettext(GETTEXT_DOMAIN,"Prefs section^Sound"));
+	std::string const pre = IMAGE_PREFIX + std::string("icons/icon-");
+	char const sep = COLUMN_SEPARATOR;
+	items.push_back(pre + "general.png" + sep + dsgettext(GETTEXT_DOMAIN,"Prefs section^General"));
+	items.push_back(pre + "display.png" + sep + dsgettext(GETTEXT_DOMAIN,"Prefs section^Display"));
+	items.push_back(pre + "music.png" + sep + dsgettext(GETTEXT_DOMAIN,"Prefs section^Sound"));
 	
 	for(;;) {
 		try {
@@ -986,7 +1067,7 @@ bool show_video_mode_dialog(display& disp)
 	std::vector<std::pair<int,int> > resolutions;
 
 	for(int i = 0; modes[i] != NULL; ++i) {
-		if(modes[i]->w >= 800 && modes[i]->h >= 600) {
+		if(modes[i]->w >= min_allowed_width && modes[i]->h >= min_allowed_height) {
 			resolutions.push_back(std::pair<int,int>(modes[i]->w,modes[i]->h));
 		}
 	}
@@ -1000,9 +1081,8 @@ bool show_video_mode_dialog(display& disp)
 	std::vector<std::string> options;
 	for(std::vector<std::pair<int,int> >::const_iterator j = resolutions.begin(); j != resolutions.end(); ++j) {
 		std::ostringstream option;
-		if(*j == current_res) {
-			option << char(gui::menu::DEFAULT_ITEM);
-		}
+		if (*j == current_res)
+			option << DEFAULT_ITEM;
 
 		option << j->first << "x" << j->second;
 		options.push_back(option.str());
@@ -1046,19 +1126,21 @@ void show_hotkeys_dialog (display & disp, config *save_config)
 
 	std::vector<std::string> menu_items;
 
-	std::vector<hotkey::hotkey_item> hotkeys = hotkey::get_hotkeys();
+	std::vector<hotkey::hotkey_item>& hotkeys = hotkey::get_hotkeys();
 	for(std::vector<hotkey::hotkey_item>::iterator i = hotkeys.begin(); i != hotkeys.end(); ++i) {
+		if(i->hidden())
+			continue;
 		std::stringstream str,name;
-		name<< hotkey::command_to_description(i->action);
+		name << i->get_description();
 		str << name.str();
-		str << ",  :  ,";
-		str << hotkey::get_hotkey_name(*i); 
+		str << COLUMN_SEPARATOR << "  :  " << COLUMN_SEPARATOR;
+		str << i->get_name();
 		menu_items.push_back (str.str ());
 	}
 
-	gui::menu menu_ (disp, menu_items, false, height);
+	gui::menu menu_(disp, menu_items, false, height);
 	menu_.set_width(400);	
-	menu_.set_loc (xpos + 20, ypos);
+	menu_.set_location(xpos + 20, ypos);
 	
 	gui::button change_button (disp, _("Change Hotkey"));
 	change_button.set_location(xpos + width - change_button.width () -30,ypos + 80);
@@ -1066,28 +1148,12 @@ void show_hotkeys_dialog (display & disp, config *save_config)
 	gui::button save_button (disp, _("Save Hotkeys"));
 	save_button.set_location(xpos + width - save_button.width () - 30,ypos + 130);
 
-	bool redraw_all = true;
-
 	for(;;) {
 
-		int mousex, mousey;
-		const int mouse_flags = SDL_GetMouseState (&mousex, &mousey);
-		const bool left_button = mouse_flags & SDL_BUTTON_LMASK;
-
-		if(redraw_all) {
-			menu_.redraw();
-			close_button.draw ();
-			change_button.draw();
-			save_button.draw();
-						
-			redraw_all = false;
-		};
-
-		if(close_button.process (mousex, mousey, left_button)) {
+		if (close_button.pressed())
 			break;
-		}
 
-		if(change_button.process (mousex, mousey, left_button)) {
+		if (change_button.pressed ()) {
 			// Lets change this hotkey......
 			SDL_Rect dlgr = {centerx-text_size.w/2-30,
 								centery-text_size.h/2 - 16,
@@ -1106,7 +1172,6 @@ void show_hotkeys_dialog (display & disp, config *save_config)
 			event.type = 0;
 			int key=0; //just to avoid warning
 			int mod=0;
-			bool used = false;
 			while (event.type!=SDL_KEYDOWN) SDL_PollEvent(&event);
 			do {
 				if (event.type==SDL_KEYDOWN)
@@ -1120,44 +1185,29 @@ void show_hotkeys_dialog (display & disp, config *save_config)
 			} while (event.type!=SDL_KEYUP);
 			restorer.restore();
 			disp.update_display();
-			for (std::vector < hotkey::hotkey_item >::iterator i =
-	     		hotkeys.begin (); i != hotkeys.end (); i++)
-			{ 
-				if((i->keycode == key) 
-					&& (i->alt == ((mod&KMOD_ALT) != 0))
-					&& (i->ctrl == ((mod&KMOD_CTRL) != 0))
-					&& (i->shift == ((mod&KMOD_SHIFT) != 0))
-					&& (i->command == ((mod&KMOD_LMETA) != 0))) {
-					used = true;
-				}
-			}
-			if(used) {
+
+			const hotkey::hotkey_item& oldhk = hotkey::get_hotkey(key, (mod & KMOD_SHIFT) != 0, 
+					(mod & KMOD_CTRL) != 0, (mod & KMOD_ALT) != 0, (mod & KMOD_LMETA) != 0);
+			hotkey::hotkey_item& newhk = hotkey::get_visible_hotkey(menu_.selection());
+
+			if(oldhk.get_id() != newhk.get_id() && !oldhk.null()) {
 				gui::show_dialog(disp,NULL,"",_("This HotKey is already in use."),gui::MESSAGE);
 			} else {
-				hotkeys[menu_.selection()].alt =  ((mod&KMOD_ALT) != 0);
-				hotkeys[menu_.selection()].ctrl = ((mod&KMOD_CTRL) != 0);
-				hotkeys[menu_.selection()].shift = ((mod&KMOD_SHIFT) != 0);
-				hotkeys[menu_.selection()].command = ((mod&KMOD_LMETA) != 0);
-				hotkeys[menu_.selection()].keycode = key;
-				hotkey::change_hotkey(hotkeys[menu_.selection()]);
-				menu_.change_item(menu_.selection(),2,
-							hotkey::get_hotkey_name(hotkeys[menu_.selection()]));
+				newhk.set_key(key, (mod & KMOD_SHIFT) != 0, 
+						(mod & KMOD_CTRL) != 0, (mod & KMOD_ALT) != 0, (mod & KMOD_LMETA) != 0);
+
+				menu_.change_item(menu_.selection(), 2, newhk.get_name());
 			};
-			redraw_all = true;
 		}
-		if (save_button.process (mousex, mousey, left_button))
-		{
+		if (save_button.pressed()) {
 			if (save_config == NULL) {
 				hotkey::save_hotkeys(prefs);
-			}
-			else {
+			} else {
 				hotkey::save_hotkeys(*save_config);
 			}
-			redraw_all = true;
 		}
 
-		menu_.process (mousex, mousey, left_button, false,
-			       false, false, false);
+		menu_.process();
 
 		events::pump();
 		events::raise_process_event();
