@@ -1,4 +1,4 @@
-/* $Id: replay.cpp,v 1.90 2005/01/28 20:17:46 silene Exp $ */
+/* $Id: replay.cpp,v 1.91 2005/02/17 23:47:12 j_daniel Exp $ */
 /*
    Copyright (C) 2003 by David White <davidnwhite@optusnet.com.au>
    Part of the Battle for Wesnoth Project http://wesnoth.whitevine.net
@@ -788,7 +788,13 @@ bool do_replay(display& disp, const gamemap& map, const game_data& gameinfo,
 			const gamemap::location src(*source);
 			const gamemap::location dst(*destination);
 
-			std::map<gamemap::location,unit>::iterator u = units.find(src);
+			std::map<gamemap::location,unit>::iterator u = units.find(dst);
+			if(u != units.end()) {
+				std::cerr << "destination already occupied: "
+						  << (dst.x+1) << "," << (dst.y+1) << "\n";
+				throw replay::error();
+			}
+			u = units.find(src);
 			if(u == units.end()) {
 				std::cerr << "unfound location for source of movement: "
 				          << (src.x+1) << "," << (src.y+1) << "-"
