@@ -1,4 +1,4 @@
-/* $Id: replay.hpp,v 1.27 2004/10/03 19:23:10 Sirp Exp $ */
+/* $Id: replay.hpp,v 1.28 2004/11/21 22:00:06 silene Exp $ */
 /*
    Copyright (C) 2003 by David White <davidnwhite@optusnet.com.au>
    Part of the Battle for Wesnoth Project http://wesnoth.whitevine.net
@@ -44,7 +44,8 @@ public:
 	void next_skip();
 	bool skipping() const;
 
-	void save_game(game_data& data, const std::string& label, const config& snapshot, const config& starting_pos, bool include_replay=true);
+	void save_game(const std::string& label, const config& snapshot,
+	               const config& starting_pos, bool include_replay = true);
 
 	void add_recruit(int unit_index, const gamemap::location& loc);
 	void add_recall(int unit_index, const gamemap::location& loc);
