@@ -1,10 +1,12 @@
+#include "global.hpp"
+
 #include "actions.hpp"
 #include "font.hpp"
 #include "game_config.hpp"
 #include "language.hpp"
 #include "reports.hpp"
+#include "wassert.hpp"
 
-#include <cassert>
 #include <map>
 #include <set>
 #include <sstream>
@@ -23,8 +25,8 @@ namespace reports {
 
 const std::string& report_name(TYPE type)
 {
-	assert(sizeof(report_names)/sizeof(*report_names) == NUM_REPORTS);
-	assert(type < NUM_REPORTS);
+	wassert(sizeof(report_names)/sizeof(*report_names) == NUM_REPORTS);
+	wassert(type < NUM_REPORTS);
 
 	return report_names[type];
 }
@@ -52,11 +54,10 @@ void report::add_image(const std::string& image, const std::string& tooltip) {
 }
 
 report generate_report(TYPE type, const gamemap& map, const unit_map& units,
-						const std::vector<team>& teams,
-                  const team& current_team, int current_side, int playing_side,
-					   const gamemap::location& loc, const gamemap::location& mouseover,
-					   const gamestatus& status, const std::set<std::string>& observers,
-					   const std::string* format_string)
+                       const std::vector<team>& teams, const team& current_team,
+                       int current_side, int playing_side,
+                       const gamemap::location& loc, const gamemap::location& mouseover,
+                       const gamestatus& status, const std::set<std::string>& observers)
 {
 	unit_map::const_iterator u = units.end();
 	
@@ -128,18 +129,18 @@ Units cannot be killed by poison alone. The poison will not reduce it below 1 HP
 	case UNIT_ALIGNMENT: {
 		const std::string& align = unit_type::alignment_description(u->second.type().alignment());
 		const std::string& align_id = unit_type::alignment_id(u->second.type().alignment());
-		return report(align,"",sgettext(string_table[align_id + "_description"].c_str()));
+		return report(align, "", string_table[align_id + "_description"]);
 	}
 	case UNIT_ABILITIES: {
 		report res;
 		std::stringstream tooltip;
 		const std::vector<std::string>& abilities = u->second.type().abilities();
 		for(std::vector<std::string>::const_iterator i = abilities.begin(); i != abilities.end(); ++i) {
-			str << sgettext(i->c_str());
+			str << gettext(i->c_str());
 			if(i+1 != abilities.end())
 				str << ",";
 
-			tooltip << sgettext(string_table[*i + "_description"].c_str());
+			tooltip << string_table[*i + "_description"];
 			res.add_text(str,tooltip);
 		}
 
@@ -184,14 +185,12 @@ Units cannot be killed by poison alone. The poison will not reduce it below 1 HP
 		const std::vector<attack_type>& attacks = u->second.attacks();
 		for(std::vector<attack_type>::const_iterator at_it = attacks.begin();
 		    at_it != attacks.end(); ++at_it) {
-			const std::string& lang_weapon = string_table["weapon_name_" + at_it->name()];
-			const std::string& lang_type = string_table["weapon_type_" + at_it->type()];
-			const std::string& lang_special = string_table["weapon_special_" + at_it->special()];
+			const std::string& lang_weapon = gettext(at_it->name().c_str());
+			const std::string& lang_type = gettext(at_it->type().c_str());
 			
-			str << (lang_weapon.empty() ? at_it->name():lang_weapon) << " ("
-				<< (lang_type.empty() ? at_it->type():lang_type) << ")\n";
+			str << lang_weapon << " (" << lang_type << ")\n";
 
-			tooltip << (lang_weapon.empty() ? at_it->name():lang_weapon) << "\n";
+			tooltip << lang_weapon << " (" << lang_type << ")\n";
 
 			//find all the unit types on the map, and show this weapon's bonus against all the different units
 			std::set<const unit_type*> seen_units;
@@ -221,9 +220,11 @@ Units cannot be killed by poison alone. The poison will not reduce it below 1 HP
 
 			res.add_text(str,tooltip);
 			
-			str << (lang_special.empty() ? at_it->special():lang_special) << "\n";
-			tooltip << string_table["weapon_special_" + at_it->special() + "_description"];
-			res.add_text(str,tooltip);
+			if (!at_it->special().empty()) {
+				str << gettext(at_it->special().c_str()) << "\n";
+				tooltip << string_table["weapon_special_" + at_it->special() + "_description"];
+				res.add_text(str,tooltip);
+			}
 			
 			str << at_it->damage() << "-" << at_it->num_attacks() << " -- "
 		        << (at_it->range() == attack_type::SHORT_RANGE ?
@@ -232,10 +233,6 @@ Units cannot be killed by poison alone. The poison will not reduce it below 1 HP
 			tooltip << at_it->damage() << " " << _("damage") << ", "
 					<< at_it->num_attacks() << " " << _("attacks");
 			
-			if(at_it->hexes() > 1) {
-				str << " (" << at_it->hexes() << ")";
-				tooltip << ", " << at_it->hexes() << " " << _("hexes");
-			}
 			str << "\n";
 			res.add_text(str,tooltip);
 		}
@@ -301,12 +298,11 @@ Units cannot be killed by poison alone. The poison will not reduce it below 1 HP
 			break;
 
 		const gamemap::TERRAIN terrain = map.get_terrain(mouseover);
-		const std::string& name = string_table[map.terrain_name(terrain)];
-		const std::vector<std::string>& underlying_names = map.underlying_terrain_name(terrain);
+		const std::string& underlying = map.underlying_terrain(terrain);
 
 		if(map.is_village(mouseover)) {
 			const int owner = village_owner(mouseover,teams)+1;
-			if(owner == 0) {
+			if(owner == 0 || current_team.fogged(mouseover.x,mouseover.y)) {
 				str << _("Village");
 			} else if(owner == current_side) {
 				str << _("Owned village");
@@ -317,16 +313,16 @@ Units cannot be killed by poison alone. The poison will not reduce it below 1 HP
 			}
 
 			str << " ";
-		}else{
-			str << name;
+		} else {
+			str << map.get_terrain_info(terrain).name();
 		}
 
-		if(underlying_names.size() != 1 || string_table[underlying_names.front()] != name) {
+		if(underlying.size() != 1 || underlying[0] != terrain) {
 			str << " (";
 			
-			for(std::vector<std::string>::const_iterator i = underlying_names.begin(); i != underlying_names.end(); ++i) {
-				str << string_table[*i];
-				if(i+1 != underlying_names.end()) {
+			for(std::string::const_iterator i = underlying.begin(); i != underlying.end(); ++i) {
+				str << map.get_terrain_info(*i).name();
+				if(i+1 != underlying.end()) {
 					str << ",";
 				}
 			}
@@ -401,7 +397,9 @@ Units cannot be killed by poison alone. The poison will not reduce it below 1 HP
 			return report();
 		}
 	}
-		
+	default:
+		wassert(false);
+		break;
 	}
 	return report(str.str());
 }
