@@ -1,4 +1,4 @@
-/* $Id: sdl_utils.hpp,v 1.51 2005/01/09 00:02:52 silene Exp $ */
+/* $Id: sdl_utils.hpp,v 1.52 2005/02/09 23:32:01 ydirson Exp $ */
 /*
    Copyright (C) 2003 by David White <davidnwhite@optusnet.com.au>
    Part of the Battle for Wesnoth Project http://wesnoth.whitevine.net
@@ -14,6 +14,7 @@
 #define SDL_UTILS_INCLUDED
 
 #include "scoped_resource.hpp"
+#include "util.hpp"
 
 #include "SDL.h"
 
@@ -103,9 +104,9 @@ surface scale_surface(surface const &surf, int w, int h);
 surface scale_surface_blended(surface const &surf, int w, int h);
 surface adjust_surface_colour(surface const &surf, int r, int g, int b);
 surface greyscale_image(surface const &surf);
-surface brighten_image(surface const &surf, double amount);
+surface brighten_image(surface const &surf, fixed_t amount);
 surface get_surface_portion(surface const &surf, SDL_Rect &rect);
-surface adjust_surface_alpha(surface const &surf, double amount);
+surface adjust_surface_alpha(surface const &surf, fixed_t amount);
 surface adjust_surface_alpha_add(surface const &surf, int amount);
 surface mask_surface(surface const &surf, surface const &mask);
 surface blur_surface(surface const &surf, int depth = 1);
