@@ -1,7 +1,10 @@
+#include "../global.hpp"
+
 #include "../config.hpp"
 #include "../game_config.hpp"
 #include "../network.hpp"
 #include "../util.hpp"
+#include "../wassert.hpp"
 
 #include "SDL.h"
 
@@ -11,7 +14,6 @@
 #include "player.hpp"
 
 #include <algorithm>
-#include <cassert>
 #include <cstdlib>
 #include <iostream>
 #include <map>
@@ -95,7 +97,7 @@ private:
 	std::vector<std::string> bans_;
 };
 
-server::server(int port, input_stream& input) : net_manager_(), server_(port), not_logged_in_(players_), lobby_players_(players_), last_stats_(time(NULL)), input_(input)
+server::server(int port, input_stream& input) : net_manager_(5), server_(port), not_logged_in_(players_), lobby_players_(players_), last_stats_(time(NULL)), input_(input)
 {
 	login_response_.add_child("mustlogin");
 	login_response_["version"] = game_config::version;
@@ -274,7 +276,7 @@ void server::run()
 			}
 
 			config data;
-			while((sock = network::receive_data(data)) != NULL) {
+			while((sock = network::receive_data(data)) != network::null_connection) {
 
 				metrics_.service_request();
 
@@ -350,6 +352,18 @@ void server::run()
 						g->send_data_observers(construct_server_message(username + " has logged into the lobby",*g));
 					}
 
+				} else if(const config* query = data.child("query")) {
+
+					//process queries from clients in here
+					std::ostringstream response;
+					if((*query)["type"] == "metrics") {
+						//a query for server data from a player
+						response << metrics_;	
+					} else {
+						response << "Error: unrecognized query";
+					}
+					
+					network::send_data(construct_server_message(response.str(),lobby_players_),sock);
 				} else if(lobby_players_.is_member(sock)) {
 					const config* const create_game = data.child("create_game");
 					if(create_game != NULL) {
@@ -427,7 +441,7 @@ void server::run()
 					config* const message = data.child("message");
 					if(message != NULL) {
 						const player_map::const_iterator p = players_.find(sock);
-						assert(p != players_.end());
+						wassert(p != players_.end());
 						(*message)["sender"] = p->second.name();
 
 						truncate_message((*message)["message"]);
@@ -446,6 +460,14 @@ void server::run()
 						continue;
 					}
 
+					//if info is being provided about the game state
+					if(data.child("info") != NULL) {
+						const config& info = *data.child("info");
+						if(info["type"] == "termination") {
+							g->set_termination_reason(info["condition"]);
+						}
+					}
+
 					//if the owner is changing the controller for a side
 					if(g->is_owner(sock) && data.child("change_controller") != NULL) {
 						const config& change = *data.child("change_controller");
@@ -457,6 +479,8 @@ void server::run()
 							const config& msg = construct_server_message(result,*g);
 							network::send_data(msg,sock);
 						}
+
+						continue;
 					}
 
 					//if the owner is banning someone from the game
@@ -597,7 +621,7 @@ void server::run()
 
 							//delete the game's description
 							config* const gamelist = initial_response_.child("gamelist");
-							assert(gamelist != NULL);
+							wassert(gamelist != NULL);
 							const config::child_itors vg = gamelist->child_range("game");
 
 							const config::child_iterator desc = std::find(vg.first,vg.second,g->description());
@@ -620,6 +644,7 @@ void server::run()
 							//put the players back in the lobby and send
 							//them the game list and user list again
 							g->send_data(initial_response_);
+							metrics_.game_terminated(g->termination_reason());
 							lobby_players_.add_players(*g);
 							games_.erase(g);
 
@@ -684,7 +709,7 @@ void server::run()
 							//force the description to be correct to prevent
 							//spoofing of messages
 							const player_map::const_iterator pl = players_.find(sock);
-							assert(pl != players_.end());
+							wassert(pl != players_.end());
 							(*speak)["description"] = pl->second.name();
 
 							if((*speak)["team_name"] == "") {
@@ -770,9 +795,11 @@ void server::run()
 
 void server::delete_game(std::vector<game>::iterator i)
 {
+	metrics_.game_terminated(i->termination_reason());
+
 	//delete the game's configuration
 	config* const gamelist = initial_response_.child("gamelist");
-	assert(gamelist != NULL);
+	wassert(gamelist != NULL);
 	const config::child_itors vg = gamelist->child_range("game");
 	const config::child_list::iterator g = std::find(vg.first,vg.second,i->description());
 	if(g != vg.second) {
