@@ -1,3 +1,5 @@
+#include "global.hpp"
+
 #include "statistics.hpp"
 #include "util.hpp"
 
@@ -222,7 +224,7 @@ void stats::read(const config& cfg)
 	}
 
 	if(cfg.child("defends")) {
-		attacks = read_battle_result_map(*cfg.child("attacks"));
+		defends = read_battle_result_map(*cfg.child("defends"));
 	}
 
 	recruit_cost = atoi(cfg["recruit_cost"].c_str());
@@ -306,7 +308,7 @@ void attack_context::defend_result(attack_context::ATTACK_RESULT res)
 
 	if(res != MISSES) {
 		attacker_stats().damage_taken += bat_stats.damage_attacker_takes;
-		defender_stats().damage_inflicted += bat_stats.damage_defender_takes;
+		defender_stats().damage_inflicted += bat_stats.damage_attacker_takes;
 	}
 	attacker_stats().expected_damage_taken +=
 		bat_stats.damage_attacker_takes * bat_stats.chance_to_hit_attacker;
