@@ -1,4 +1,4 @@
-/* $Id: team.hpp,v 1.50 2004/09/13 03:16:19 Sirp Exp $ */
+/* $Id: team.hpp,v 1.52 2005/01/22 10:47:17 silene Exp $ */
 /*
    Copyright (C) 2003 by David White <davidnwhite@optusnet.com.au>
    Part of the Battle for Wesnoth Project http://wesnoth.whitevine.net
@@ -16,7 +16,6 @@
 #include "config.hpp"
 #include "map.hpp"
 
-#include <cassert>
 #include <set>
 #include <string>
 #include <vector>
@@ -76,6 +75,7 @@ public:
 
 		enum CONTROLLER { HUMAN, AI, NETWORK, EMPTY };
 		CONTROLLER controller;
+		bool persistent;
 		std::string ai_algorithm;
 
 		std::vector<config> ai_params;
@@ -133,6 +133,8 @@ public:
 	bool is_ai() const;
 	bool is_empty() const;
 
+	bool is_persistent() const;
+
 	void make_human();
 	void make_network();
 	void make_ai();
