@@ -1,3 +1,6 @@
+#include "global.hpp"
+
+#include "config.hpp"
 #include "cursor.hpp"
 #include "display.hpp"
 #include "events.hpp"
@@ -6,6 +9,7 @@
 #include "hotkeys.hpp"
 #include "key.hpp"
 #include "language.hpp"
+#include "log.hpp"
 #include "preferences.hpp"
 #include "sdl_utils.hpp"
 #include "show_dialog.hpp"
@@ -15,13 +19,16 @@
 
 #include "SDL_ttf.h"
 
+#define LOG_DP lg::info(lg::display)
+#define ERR_DP lg::err(lg::display)
+
 namespace {
 
 void fade_logo(display& screen, int xpos, int ypos)
 {
 	const surface logo(image::get_image(game_config::game_logo,image::UNSCALED));
 	if(logo == NULL) {
-		std::cerr << "Could not find game logo\n";
+		ERR_DP << "Could not find game logo\n";
 		return;
 	}
 
@@ -37,11 +44,9 @@ void fade_logo(display& screen, int xpos, int ypos)
 	CKey key;
 	bool last_button = key[SDLK_ESCAPE] || key[SDLK_SPACE];
 
-	//std::cerr << "fading logo in....\n";
+	LOG_DP << "fading logo in....\n";
 
-	//std::cerr << "logo size: " << logo->w << "," << logo->h << "\n";
-
-	const video_change_detector disp_change_detector(screen.video());
+	LOG_DP << "logo size: " << logo->w << "," << logo->h << "\n";
 
 	for(int x = 0; x != logo->w; ++x) {
 		SDL_Rect srcrect = {x,0,1,logo->h};
@@ -65,7 +70,7 @@ void fade_logo(display& screen, int xpos, int ypos)
 			SDL_Delay(10);
 
 			events::pump();
-			if(disp_change_detector.changed()) {
+			if(screen.video().modeChanged()) {
 				faded_in = true;
 				fade_logo(screen,xpos,ypos);
 				return;
@@ -74,73 +79,88 @@ void fade_logo(display& screen, int xpos, int ypos)
 
 	}
 
-	//std::cerr << "logo faded in\n";
+	LOG_DP << "logo faded in\n";
 
 	faded_in = true;
 }
 
-const std::string& get_tip_of_day(int* ntip)
+const std::string& get_tip_of_day(const config& tips,int* ntip)
 {
 	static const std::string empty_string;
+	string_map::const_iterator it;
+
 	if(preferences::show_tip_of_day() == false) {
 		return empty_string;
 	}
 
-	int ntips = 0;
-	while(ntips < 1000 && string_table["tip_of_day" + str_cast(ntips+1)] != "") {
-		++ntips;
-	}
-
+	int ntips = tips.values.size();
 	if(ntips == 0) {
 		return empty_string;
 	}
 
 	if(ntip != NULL && *ntip > 0) {
-		if(*ntip > ntips) {
+		if(*ntip >= ntips) {
 			*ntip -= ntips;
 		}
 
-		return string_table["tip_of_day" + str_cast(*ntip)];
+		it = tips.values.begin();
+		for(int i = 0; i < *ntip; i++,it++);
+		return it->second;
 	}
 
-	const int tip = (rand()%ntips) + 1;
+	const int tip = (rand()%ntips);
 	if(ntip != NULL) {
 		*ntip = tip;
 	}
 
-	return string_table["tip_of_day" + str_cast(tip)];
+	it = tips.values.begin();
+	for(int i = 0; i < tip; i++,it++);
+	return it->second;
 }
 
+const config get_tips_of_day()
+{
+	config cfg;
+
+	std::cerr << "Loading tips of day\n";
+	try {
+		cfg.read(preprocess_file("data/tips.cfg"));
+	} catch(config::error&) {
+		std::cerr << "Could not read tips.cfg\n";
+	}
+
+	return cfg;
 }
 
+} //end anonymous namespace
+
 namespace gui {
 
-TITLE_RESULT show_title(display& screen, int* ntip)
+TITLE_RESULT show_title(display& screen, config& tips_of_day, int* ntip)
 {
 	cursor::set(cursor::NORMAL);
 
 	const preferences::display_manager disp_manager(&screen);
 	const hotkey::basic_handler key_handler(&screen);
 
-	const video_change_detector disp_change_detector(screen.video());
-
 	const font::floating_label_context label_manager;
 	
 	const surface title_surface_unscaled(image::get_image(game_config::game_title,image::UNSCALED));
 	const surface title_surface(scale_surface(title_surface_unscaled,screen.x(),screen.y()));
+	screen.video().modeChanged(); // resets modeChanged value
 
 	if(title_surface == NULL) {
-		std::cerr << "Could not find title image\n";
+		ERR_DP << "Could not find title image\n";
 	} else {
 		screen.blit_surface(0,0,title_surface);
 		update_rect(screen.screen_area());
 
-		//std::cerr << "displayed title image\n";
+		LOG_DP << "displayed title image\n";
 	}
 
 	fade_logo(screen,(game_config::title_logo_x*screen.x())/1024,(game_config::title_logo_y*screen.y())/768);
 
-	//std::cerr << "faded logo\n";
+	LOG_DP << "faded logo\n";
 
 	const std::string& version_str = _("Version") + std::string(" ") +
 	                                 game_config::version;
@@ -156,7 +176,7 @@ TITLE_RESULT show_title(display& screen, int* ntip)
 				font::NORMAL_COLOUR,version_str,0,versiony);
 	}
 
-	//std::cerr << "drew version number\n";
+	LOG_DP << "drew version number\n";
 
 	//members of this array must correspond to the enumeration TITLE_RESULT
 	static const char* button_labels[] = { N_("TitleScreen button^Tutorial"),
@@ -165,7 +185,7 @@ TITLE_RESULT show_title(display& screen, int* ntip)
 					       N_("TitleScreen button^Load"),
 					       N_("TitleScreen button^Language"),
 					       N_("TitleScreen button^Preferences"),
-					       N_("TitleScreen button^About"),
+					       N_("About"),
 					       N_("TitleScreen button^Quit") };
 	static const char* help_button_labels[] = { N_("Start a tutorial to familiarize yourself with the game"),
 						    N_("Start a new single player campaign"),
@@ -181,16 +201,18 @@ TITLE_RESULT show_title(display& screen, int* ntip)
 	const int menu_xbase = (game_config::title_buttons_x*screen.x())/1024;
 	const int menu_xincr = 0;
 	const int menu_ybase = (game_config::title_buttons_y*screen.y())/768;
+#ifdef USE_TINY_GUI
+	const int menu_yincr = 15;
+#else
 	const int menu_yincr = 40;
+#endif
 	const int padding = game_config::title_buttons_padding;
 	
 	std::vector<button> buttons;
 	size_t b, max_width = 0;
 	for(b = 0; b != nbuttons; ++b) {
 		buttons.push_back(button(screen,sgettext(button_labels[b])));
-		buttons.back().set_location(menu_xbase + b*menu_xincr, menu_ybase + b*menu_yincr);
 		buttons.back().set_help_string(sgettext(help_button_labels[b]));
-		//std::cerr << "set help string for '" << button_labels[b] << "' -> '" << sgettext(help_button_labels[b]) << "'\n";
 		max_width = maximum<size_t>(max_width,buttons.back().width());
 	}
 
@@ -198,9 +220,17 @@ TITLE_RESULT show_title(display& screen, int* ntip)
 	std::string style = "mainmenu";
 	draw_dialog_frame(main_dialog_area.x,main_dialog_area.y,main_dialog_area.w,main_dialog_area.h,screen,&style);
 
+	for(b = 0; b != nbuttons; ++b) {
+		buttons[b].set_width(max_width);
+		buttons[b].set_location(menu_xbase + b*menu_xincr, menu_ybase + b*menu_yincr);
+	}
+
 	gui::button next_tip_button(screen,_("More"),button::TYPE_PRESS,"lite_small");
 
-	std::string tip_of_day = get_tip_of_day(ntip);
+	if(tips_of_day.empty()) {
+		tips_of_day = get_tips_of_day();
+	}
+	std::string tip_of_day = get_tip_of_day(tips_of_day,ntip);
 	if(tip_of_day.empty() == false) {
 		tip_of_day = font::word_wrap_text(tip_of_day,font::SIZE_NORMAL,
 						  (game_config::title_tip_width*screen.x())/1024);
@@ -224,20 +254,22 @@ TITLE_RESULT show_title(display& screen, int* ntip)
 		draw_dialog_frame(area.x,area.y,area.w,area.h,screen,&style);
 
 		font::draw_text(&screen,area,font::SIZE_NORMAL,font::NORMAL_COLOUR,tip_of_day,area.x+pad,area.y+pad);
-		font::draw_text(&screen,area,font::SIZE_NORMAL,font::NORMAL_COLOUR,tome,area.x+area.w-tome_area.w-pad,next_tip_button.location().y-tome_area.h-pad,NULL,false,font::NO_MARKUP,TTF_STYLE_ITALIC);
+		font::draw_text(&screen, area, font::SIZE_NORMAL, font::NORMAL_COLOUR,
+		                tome, area.x + area.w - tome_area.w - pad,
+		                next_tip_button.location().y - tome_area.h - pad, false, TTF_STYLE_ITALIC);
 	}
 
 	events::raise_draw_event();
 
-	//std::cerr << "drew buttons dialog\n";
+	LOG_DP << "drew buttons dialog\n";
 
 	CKey key;
 
-	bool last_escape = key[SDLK_ESCAPE];
+	bool last_escape = key[SDLK_ESCAPE] != 0;
 
 	update_whole_screen();
 
-	std::cerr << "entering interactive loop...\n";
+	LOG_DP << "entering interactive loop...\n";
 
 	for(;;) {
 		for(size_t b = 0; b != buttons.size(); ++b) {
@@ -262,13 +294,13 @@ TITLE_RESULT show_title(display& screen, int* ntip)
 		if(!last_escape && key[SDLK_ESCAPE])
 			return QUIT_GAME;
 
-		last_escape = key[SDLK_ESCAPE];
+		last_escape = key[SDLK_ESCAPE] != 0;
 
 		events::pump();
 
 		//if the resolution has changed due to the user resizing the screen,
 		//or from changing between windowed and fullscreen
-		if(disp_change_detector.changed()) {
+		if(screen.video().modeChanged()) {
 			return TITLE_CONTINUE;
 		}
 
