@@ -1,4 +1,4 @@
-/* $Id: unit.cpp,v 1.120 2005/01/22 12:09:36 silene Exp $ */
+/* $Id: unit.cpp,v 1.121 2005/02/09 23:32:01 ydirson Exp $ */
 /*
    Copyright (C) 2003 by David White <davidnwhite@optusnet.com.au>
    Part of the Battle for Wesnoth Project http://wesnoth.whitevine.net
@@ -236,7 +236,7 @@ bool unit::unrenamable() const
 	return unrenamable_;
 }
 
-double unit::alpha() const
+fixed_t unit::alpha() const
 {
 	return type().alpha();
 }
