@@ -9,8 +9,10 @@
 ///attacking, and dying
 namespace unit_display
 {
+bool unit_visible_on_path(display& disp, const gamemap& map, const std::vector<gamemap::location>& path, unit& u, const time_of_day& tod, const unit_map& units, const std::vector<team>& teams);
+
 ///a function to display a unit moving along a given path
-void move_unit(display& disp, const gamemap& map, const std::vector<gamemap::location>& path, unit& u);
+void move_unit(display& disp, const gamemap& map, const std::vector<gamemap::location>& path, unit& u, const time_of_day& tod, const unit_map& units, const std::vector<team>& teams);
 
 ///a function to show a unit fading out. Note that this only shows the effect, it doesn't
 ///actually kill the unit.
