@@ -1,4 +1,4 @@
-/* $Id: unit_types.cpp,v 1.76 2005/02/06 10:40:12 isaaccp Exp $ */
+/* $Id: unit_types.cpp,v 1.79 2005/02/19 09:26:31 isaaccp Exp $ */
 /*
    Copyright (C) 2003 by David White <davidnwhite@optusnet.com.au>
    Part of the Battle for Wesnoth Project http://wesnoth.whitevine.net
@@ -142,7 +142,18 @@ attack_type::attack_type(const config& cfg)
 {
 	const config::child_list& animations = cfg.get_children("animation");
 	for(config::child_list::const_iterator an = animations.begin(); an != animations.end(); ++an) {
-		animation_.push_back(unit_animation(**an));
+		const std::string& dir = (**an)["direction"];
+		if(dir == "") {
+			animation_.push_back(unit_animation(**an));
+		} else {
+			const std::vector<std::string>& directions = config::split(dir);
+			for(std::vector<std::string>::const_iterator i = directions.begin(); i != directions.end(); ++i) {
+				const gamemap::location::DIRECTION d = gamemap::location::parse_direction(*i);
+				if(d != gamemap::location::NDIRECTIONS) {
+					direction_animation_[d].push_back(unit_animation(**an));
+				}
+			}
+		}
 	}
 
 	if(animation_.empty()) {
@@ -225,10 +236,16 @@ bool attack_type::slow() const
 	return slow_;
 }
 
-const unit_animation& attack_type::animation() const
+const unit_animation& attack_type::animation(const gamemap::location::DIRECTION dir) const
 {
-	wassert(animation_.empty() == false);
-	return animation_[rand()%animation_.size()];
+	const std::vector<unit_animation>* animation = &animation_;
+	if(dir < sizeof(direction_animation_)/sizeof(*direction_animation_) &&
+	   direction_animation_[dir].empty() == false) {
+		animation = &direction_animation_[dir];
+	}
+
+	wassert(animation->empty() == false);
+	return (*animation)[rand()%animation->size()];
 }
 
 bool attack_type::matches_filter(const config& cfg) const
@@ -532,7 +549,7 @@ unit_type::unit_type(const unit_type& o)
 
 unit_type::unit_type(const config& cfg, const movement_type_map& mv_types,
                      const race_map& races, const std::vector<config*>& traits)
-                : cfg_(cfg), alpha_(1.0), movementType_(cfg), possibleTraits_(traits)
+	: cfg_(cfg), alpha_(ftofxp(1.0)), movementType_(cfg), possibleTraits_(traits)
 {
 	const config::child_list& variations = cfg.get_children("variation");
 	for(config::child_list::const_iterator var = variations.begin(); var != variations.end(); ++var) {
@@ -602,7 +619,7 @@ unit_type::unit_type(const config& cfg, const movement_type_map& mv_types,
 
 	const std::string& alpha_blend = cfg_["alpha"];
 	if(alpha_blend.empty() == false) {
-		alpha_ = atof(alpha_blend.c_str());
+		alpha_ = ftofxp(atof(alpha_blend.c_str()));
 	}
 
 	const std::string& move_type = cfg_["movement_type"];
@@ -896,7 +913,7 @@ const char* unit_type::alignment_id(unit_type::ALIGNMENT align)
 	return (aligns[align]);
 }
 
-double unit_type::alpha() const
+fixed_t unit_type::alpha() const
 {
 	return alpha_;
 }
