@@ -1,4 +1,4 @@
-/* $Id: unit_types.hpp,v 1.56 2005/02/06 10:40:12 isaaccp Exp $ */
+/* $Id: unit_types.hpp,v 1.59 2005/02/19 09:26:31 isaaccp Exp $ */
 /*
    Copyright (C) 2003 by David White <davidnwhite@optusnet.com.au>
    Part of the Battle for Wesnoth Project http://wesnoth.whitevine.net
@@ -94,12 +94,13 @@ public:
 	//this function returns a random animation out of the possible
 	//animations for this attack. It will not return the same attack
 	//each time.
-	const unit_animation& animation() const;
+	const unit_animation& animation(gamemap::location::DIRECTION dir=gamemap::location::NDIRECTIONS) const;
 
 	bool matches_filter(const config& cfg) const;
 	bool apply_modification(const config& cfg,std::string* description);
 private:
 	std::vector<unit_animation> animation_;
+	std::vector<unit_animation> direction_animation_[6];
 	std::string name_;
 	std::string type_;
 	std::string special_;
@@ -212,7 +213,7 @@ public:
 	static const char* alignment_description(ALIGNMENT align);
 	static const char* alignment_id(ALIGNMENT align);
 
-	double alpha() const;
+	fixed_t alpha() const;
 
 	const std::vector<std::string>& abilities() const;
 
@@ -256,7 +257,7 @@ private:
 
 	const unit_race* race_;
 
-	double alpha_;
+	fixed_t alpha_;
 
 	std::vector<std::string> abilities_;
 
