@@ -1,4 +1,4 @@
-/* $Id: video.cpp,v 1.48 2004/08/23 06:41:00 gakusho Exp $ */
+/* $Id: video.cpp,v 1.55 2005/02/06 10:40:12 isaaccp Exp $ */
 /*
    Copyright (C) 2003 by David White <davidnwhite@optusnet.com.au>
    Part of the Battle for Wesnoth Project http://wesnoth.whitevine.net
@@ -11,10 +11,7 @@
    See the COPYING file for more details.
 */
 
-//disable the very annoying VC++ warning 4786
-#ifdef WIN32
-#pragma warning(disable:4786)
-#endif
+#include "global.hpp"
 
 #include <stdio.h>
 #include <iostream>
@@ -25,10 +22,14 @@
 #include "font.hpp"
 #include "halo.hpp"
 #include "image.hpp"
+#include "log.hpp"
 #include "mouse.hpp"
 #include "preferences.hpp"
 #include "video.hpp"
 
+#define LOG_DP lg::info(lg::display)
+#define ERR_DP lg::err(lg::display)
+
 #define TEST_VIDEO_ON 0
 
 #if (TEST_VIDEO_ON==1)
@@ -202,7 +203,7 @@ CVideo::CVideo() : bpp(0), fake_screen(false)
 	const int res = SDL_Init(SDL_INIT_VIDEO | SDL_INIT_AUDIO | SDL_INIT_NOPARACHUTE);
 
 	if(res < 0) {
-		std::cerr << "Could not initialize SDL: " << SDL_GetError() << "\n";
+		ERR_DP << "Could not initialize SDL: " << SDL_GetError() << "\n";
 		throw CVideo::error();
 	}
 }
@@ -212,22 +213,22 @@ CVideo::CVideo( int x, int y, int bits_per_pixel, int flags)
 {
 	const int res = SDL_Init( SDL_INIT_VIDEO | SDL_INIT_AUDIO | SDL_INIT_NOPARACHUTE);
 	if(res < 0) {
-		std::cerr << "Could not initialize SDL: " << SDL_GetError() << "\n";
+		ERR_DP << "Could not initialize SDL: " << SDL_GetError() << "\n";
 		throw CVideo::error();
 	}
 
 	const int mode_res = setMode( x, y, bits_per_pixel, flags );
 	if (mode_res == 0) {
-		std::cerr << "Could not set Video Mode\n";
+		ERR_DP << "Could not set Video Mode\n";
 		throw CVideo::error();
 	}
 }
 
 CVideo::~CVideo()
 {
-	std::cerr << "calling SDL_Quit()\n";
+	LOG_DP << "calling SDL_Quit()\n";
 	SDL_Quit();
-	std::cerr << "called SDL_Quit()\n";
+	LOG_DP << "called SDL_Quit()\n";
 }
 
 void CVideo::make_fake()
@@ -245,6 +246,7 @@ int CVideo::modePossible( int x, int y, int bits_per_pixel, int flags )
 int CVideo::setMode( int x, int y, int bits_per_pixel, int flags )
 {
 	update_rects.clear();
+	mode_changed_ = true;
 
 	flags = get_flags(flags);
 	const int res = SDL_VideoModeOK( x, y, bits_per_pixel, flags );
@@ -261,6 +263,13 @@ int CVideo::setMode( int x, int y, int bits_per_pixel, int flags )
 	} else	return 0;
 }
 
+bool CVideo::modeChanged()
+{
+	bool ret = mode_changed_;
+	mode_changed_ = false;
+	return ret;
+}
+
 int CVideo::setGamma(float gamma)
 {
 	SDL_SetGamma(gamma, gamma, gamma);
@@ -309,8 +318,8 @@ void CVideo::flip()
 		return;
 
 	halo::render();
-	events::raise_volatile_draw_event();
 	font::draw_floating_labels(frameBuffer);
+	events::raise_volatile_draw_event();
 	cursor::draw(frameBuffer);
 	if(update_all) {
 		::SDL_Flip(frameBuffer);
@@ -321,8 +330,8 @@ void CVideo::flip()
 	clear_updates();
 
 	cursor::undraw(frameBuffer);
-	font::undraw_floating_labels(frameBuffer);
 	events::raise_volatile_undraw_event();
+	font::undraw_floating_labels(frameBuffer);
 	halo::unrender();
 }
 
