@@ -1,4 +1,4 @@
-/* $Id: button.hpp,v 1.26 2004/07/18 19:02:25 gruikya Exp $ */
+/* $Id: button.hpp,v 1.29 2004/11/06 13:13:16 silene Exp $ */
 /*
    Copyright (C) 2003 by David White <davidnwhite@optusnet.com.au>
    Part of the Battle for Wesnoth Project http://wesnoth.whitevine.net
@@ -32,7 +32,7 @@ class button : public widget
 public:
 	struct error {};
 
-	enum TYPE { TYPE_PRESS, TYPE_CHECK };
+	enum TYPE { TYPE_PRESS, TYPE_CHECK, TYPE_TURBO };
 
 	enum SPACE_CONSUMPTION { DEFAULT_SPACE, MINIMUM_SPACE };
 
@@ -40,15 +40,11 @@ public:
 	       std::string button_image="", SPACE_CONSUMPTION spacing=DEFAULT_SPACE);
 
 	virtual ~button() {}
-
 	void set_check(bool check);
 	bool checked() const;
 
-	void draw();
-
 	void set_label(const std::string& val);
 
-	bool process(int mousex, int mousey, bool button);
 	bool pressed();
 
 	void enable(bool new_val);
@@ -59,11 +55,11 @@ protected:
 	virtual void mouse_motion(const SDL_MouseMotionEvent& event);
 	virtual void mouse_down(const SDL_MouseButtonEvent& event);
 	virtual void mouse_up(const SDL_MouseButtonEvent& event);
+	virtual void draw_contents();
 
 private:
 
 	std::string label_;
-	display* display_;
 	surface image_, pressedImage_, activeImage_, pressedActiveImage_;
 	SDL_Rect textRect_;
 
