@@ -1,4 +1,4 @@
-/* $Id: combo.hpp,v 1.17 2004/08/29 23:28:26 Sirp Exp $ */
+/* $Id: combo.hpp,v 1.19 2005/01/12 21:33:58 silene Exp $ */
 /*
    Copyright (C) 2003 by David White <davidnwhite@optusnet.com.au>
    Part of the Battle for Wesnoth Project http://wesnoth.whitevine.net
@@ -20,35 +20,23 @@
 
 namespace gui {
 
-class combo
+class combo : public button
 {
 public:
 	combo(display& disp, const std::vector<std::string>& items);
-	void draw();
 
-	void set_location(int valx, int valy);
-	void set_width(int new_width);
 	void set_selected(int val);
 	void set_items(const std::vector<std::string>& items);
-
-	int width() const;
-	int height() const;
 	int selected() const;
+	bool changed();
 
-	bool process(int mousex, int mousey, bool button);
-
-	void enable(bool new_val);
-	bool enabled() const;
-
-	void set_dirty() { button_.set_dirty(); }
+protected:
+	virtual void process_event();
 
 private:
+	void set_selected_internal(int val);
 	std::vector<std::string> items_;
-	int selected_;
-	display *display_;
-	gui::button button_;
-
-
+	int selected_, oldSelected_;
 }; //end class combo
 
 }
