@@ -1,4 +1,4 @@
-/* $Id: textbox.hpp,v 1.30 2004/07/18 19:02:25 gruikya Exp $ */
+/* $Id: textbox.hpp,v 1.36 2004/11/13 00:27:26 isaaccp Exp $ */
 /*
    Copyright (C) 2003 by David White <davidnwhite@optusnet.com.au>
    Part of the Battle for Wesnoth Project http://wesnoth.whitevine.net
@@ -19,21 +19,20 @@
 #include "../language.hpp"
 #include "../sdl_utils.hpp"
 
-#include "button.hpp"
-#include "scrollbar.hpp"
-#include "widget.hpp"
+#include "scrollarea.hpp"
 
 #include "SDL.h"
 
 namespace gui {
 
-class textbox : public widget, public scrollable
+class textbox : public scrollarea
 {
 public:
-	textbox(display& d, int width, const std::string& text="", bool editable=true, size_t max_size = 256);
+	textbox(display& d, int width, const std::string& text="", bool editable=true, size_t max_size = 256, double alpha = 0.4, double alpha_focus = 0.2);
 
 	const std::string text() const;
-	void set_text(std::string text);
+	void set_text(const std::string& text);
+	void append_text(const std::string& text);
 	void clear();
 	void process();
 
@@ -44,15 +43,16 @@ public:
 
 	void set_wrap(bool val);
 
-	void draw();
+protected:
+	virtual void draw_contents();
+	virtual void set_inner_location(SDL_Rect const &);
+	virtual void scroll(int pos);
 
 private:
 	size_t max_size_;
 
-	void scroll(int pos);
-
 	wide_string text_;
-	
+
 	// mutable unsigned int firstOnScreen_;
 	int cursor_;
 	int selstart_;
@@ -72,22 +72,19 @@ private:
 	//this will be reset when keyboard input events occur
 	int show_cursor_at_;
 	surface text_image_;
-	SDL_Rect text_size_;
-
-	//variables used for multi-line textboxes which support scrolling
-	scrollbar scrollbar_;
-	button uparrow_, downarrow_;
-
-	bool scroll_bottom_;
 
 	bool wrap_;
 
 	size_t line_height_, yscroll_;
 
+	double alpha_;
+	double alpha_focus_;
+
 	void handle_event(const SDL_Event& event);
 
 	void draw_cursor(int pos, display &disp) const;
 	void update_text_cache(bool reset = false);
+	surface add_text_line(const wide_string& text);
 	bool is_selection();
 	void erase_selection();
 
